/* Generated by Cython 3.0a6 */

#define PY_SSIZE_T_CLEAN
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"

    #if PY_MAJOR_VERSION <= 2
    #define PyDict_GetItemWithError _PyDict_GetItemWithError
    #endif
    
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#define CYTHON_ABI "3_0a6"
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030000A6
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP487_INIT_SUBCLASS
  #define CYTHON_PEP487_INIT_SUBCLASS 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(CYTHON_LIMITED_API)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030800B2
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#elif PY_VERSION_HEX >= 0x030800A4
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS(n)
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((n) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET)
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  (n)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static inline void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
#else
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__cysignals__tests
#define __PYX_HAVE_API__cysignals__tests
/* Early includes */
#include <signal.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/types.h>
#include <stdio.h>
#include "pythread.h"
#include "struct_signals.h"
#include <pthread.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "src/cysignals/tests.pyx",
  "stringsource",
  "src/cysignals/memory.pxd",
  ".eggs/Cython-3.0a6-py2.7.egg/Cython/Includes/cpython/type.pxd",
  ".eggs/Cython-3.0a6-py2.7.egg/Cython/Includes/cpython/bool.pxd",
  ".eggs/Cython-3.0a6-py2.7.egg/Cython/Includes/cpython/complex.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9cysignals_5tests_DeallocDebug;

/* "libc/signal.pxd":3
 * # 7.14 Signal handling <signal.h>
 * 
 * ctypedef void (*sighandler_t)(int SIGNUM) nogil             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "<signal.h>" nogil:
 */
typedef void (*__pyx_t_4libc_6signal_sighandler_t)(int);
struct __pyx_opt_args_9cysignals_5tests_stack_overflow;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults2;
typedef struct __pyx_defaults2 __pyx_defaults2;
struct __pyx_defaults3;
typedef struct __pyx_defaults3 __pyx_defaults3;
struct __pyx_defaults4;
typedef struct __pyx_defaults4 __pyx_defaults4;
struct __pyx_defaults5;
typedef struct __pyx_defaults5 __pyx_defaults5;
struct __pyx_defaults6;
typedef struct __pyx_defaults6 __pyx_defaults6;
struct __pyx_defaults7;
typedef struct __pyx_defaults7 __pyx_defaults7;
struct __pyx_defaults8;
typedef struct __pyx_defaults8 __pyx_defaults8;
struct __pyx_defaults9;
typedef struct __pyx_defaults9 __pyx_defaults9;
struct __pyx_defaults10;
typedef struct __pyx_defaults10 __pyx_defaults10;
struct __pyx_defaults11;
typedef struct __pyx_defaults11 __pyx_defaults11;
struct __pyx_defaults12;
typedef struct __pyx_defaults12 __pyx_defaults12;
struct __pyx_defaults13;
typedef struct __pyx_defaults13 __pyx_defaults13;
struct __pyx_defaults14;
typedef struct __pyx_defaults14 __pyx_defaults14;
struct __pyx_defaults15;
typedef struct __pyx_defaults15 __pyx_defaults15;
struct __pyx_defaults16;
typedef struct __pyx_defaults16 __pyx_defaults16;
struct __pyx_defaults17;
typedef struct __pyx_defaults17 __pyx_defaults17;
struct __pyx_defaults18;
typedef struct __pyx_defaults18 __pyx_defaults18;
struct __pyx_defaults19;
typedef struct __pyx_defaults19 __pyx_defaults19;
struct __pyx_defaults20;
typedef struct __pyx_defaults20 __pyx_defaults20;
struct __pyx_defaults21;
typedef struct __pyx_defaults21 __pyx_defaults21;
struct __pyx_defaults22;
typedef struct __pyx_defaults22 __pyx_defaults22;
struct __pyx_defaults23;
typedef struct __pyx_defaults23 __pyx_defaults23;
struct __pyx_defaults24;
typedef struct __pyx_defaults24 __pyx_defaults24;
struct __pyx_defaults25;
typedef struct __pyx_defaults25 __pyx_defaults25;
struct __pyx_defaults26;
typedef struct __pyx_defaults26 __pyx_defaults26;
struct __pyx_defaults27;
typedef struct __pyx_defaults27 __pyx_defaults27;

/* "cysignals/tests.pyx":116
 * 
 * 
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:             # <<<<<<<<<<<<<<
 *     cdef volatile_int a = 0
 *     if x is not NULL:
 */
struct __pyx_opt_args_9cysignals_5tests_stack_overflow {
  int __pyx_n;
  volatile int *x;
};
struct __pyx_defaults {
  long __pyx_arg_delay;
};
struct __pyx_defaults1 {
  long __pyx_arg_delay;
};
struct __pyx_defaults2 {
  long __pyx_arg_delay;
};
struct __pyx_defaults3 {
  long __pyx_arg_delay;
};
struct __pyx_defaults4 {
  long __pyx_arg_delay;
};
struct __pyx_defaults5 {
  long __pyx_arg_delay;
};
struct __pyx_defaults6 {
  long __pyx_arg_delay;
};
struct __pyx_defaults7 {
  long __pyx_arg_delay;
};
struct __pyx_defaults8 {
  long __pyx_arg_delay;
};
struct __pyx_defaults9 {
  long __pyx_arg_delay;
};
struct __pyx_defaults10 {
  long __pyx_arg_delay;
};
struct __pyx_defaults11 {
  long __pyx_arg_delay;
};
struct __pyx_defaults12 {
  long __pyx_arg_delay;
};
struct __pyx_defaults13 {
  long __pyx_arg_delay;
};
struct __pyx_defaults14 {
  long __pyx_arg_delay;
};
struct __pyx_defaults15 {
  long __pyx_arg_delay;
};
struct __pyx_defaults16 {
  long __pyx_arg_delay;
};
struct __pyx_defaults17 {
  long __pyx_arg_delay;
};
struct __pyx_defaults18 {
  long __pyx_arg_delay;
};
struct __pyx_defaults19 {
  long __pyx_arg_delay;
};
struct __pyx_defaults20 {
  long __pyx_arg_delay;
};
struct __pyx_defaults21 {
  long __pyx_arg_delay;
};
struct __pyx_defaults22 {
  long __pyx_arg_delay;
};
struct __pyx_defaults23 {
  long __pyx_arg_delay;
};
struct __pyx_defaults24 {
  long __pyx_arg_delay;
};
struct __pyx_defaults25 {
  long __pyx_arg_delay;
};
struct __pyx_defaults26 {
  long __pyx_arg_delay;
};
struct __pyx_defaults27 {
  long __pyx_arg_delay;
};

/* "cysignals/tests.pyx":1058
 * 
 * 
 * cdef class DeallocDebug:             # <<<<<<<<<<<<<<
 *     def __dealloc__(self):
 *         sys.stdout.write("__dealloc__: ")
 */
struct __pyx_obj_9cysignals_5tests_DeallocDebug {
  PyObject_HEAD
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) (&args[nargs])
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, nargs, NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_long(long value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#if CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, CYTHON_UNUSED PyObject *typ) {
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, Py_ssize_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__pyx_CyFunctionType = 0;
#endif
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_IsCyOrPyCFunction(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func.vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* None.proto */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void); /* proto */

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_volatile__int(volatile int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_Occurred(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str);
#else
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);
#endif

/* #### Code section: module_declarations ### */
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self); /* proto*/

/* Module declarations from "libc.signal" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "libc.string" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "libc.stdlib" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "libc.errno" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "posix.types" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "posix.signal" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.version" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "__builtin__" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.type" */
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;
#endif

/* Module declarations from "libc.stdio" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.object" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.ref" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.exc" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.module" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.mem" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.tuple" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.list" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.sequence" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.mapping" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.iterator" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.number" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.int" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "__builtin__" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.bool" */
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__pyx_ptype_7cpython_4bool_bool = 0;
#endif

/* Module declarations from "cpython.long" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.float" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "__builtin__" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.complex" */
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__pyx_ptype_7cpython_7complex_complex = 0;
#endif

/* Module declarations from "cpython.string" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.unicode" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.pyport" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.dict" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.instance" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.function" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.method" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.weakref" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.getargs" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.pythread" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.pystate" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.cobject" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.oldbuffer" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.set" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.buffer" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.bytes" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython.pycapsule" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cpython" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cysignals.signals" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif
static cysigs_t *__pyx_vp_9cysignals_7signals_cysigs = 0;
#define cysigs (*__pyx_vp_9cysignals_7signals_cysigs)
static CYTHON_INLINE void __pyx_f_9cysignals_7signals_cython_check_exception(void); /*proto*/
static void (*__pyx_f_9cysignals_7signals_verify_exc_value)(void); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_9cysignals_7signals_sig_occurred(void); /*proto*/
static void (*_sig_on_interrupt_received)(void); /*proto*/
static void (*_sig_on_recover)(void); /*proto*/
static void (*_sig_off_warning)(char const *, int); /*proto*/
static void (*print_backtrace)(void); /*proto*/

/* Module declarations from "cython" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif

/* Module declarations from "cysignals.memory" */
#if !CYTHON_COMPILING_IN_LIMITED_API
#endif
static CYTHON_INLINE void *sig_malloc(size_t); /*proto*/
static CYTHON_INLINE void *sig_realloc(void *, size_t); /*proto*/
static CYTHON_INLINE void *sig_calloc(size_t, size_t); /*proto*/
static CYTHON_INLINE void sig_free(void *); /*proto*/
static CYTHON_INLINE size_t __pyx_f_9cysignals_6memory_mul_overflowcheck(size_t, size_t); /*proto*/

/* Module declarations from "cysignals.tests" */
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__pyx_ptype_9cysignals_5tests_DeallocDebug = 0;
#endif
static long __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
static void __pyx_f_9cysignals_5tests_infinite_loop(void); /*proto*/
static void __pyx_f_9cysignals_5tests_infinite_malloc_loop(void); /*proto*/
static void __pyx_f_9cysignals_5tests_dereference_null_pointer(void); /*proto*/
static int __pyx_f_9cysignals_5tests_stack_overflow(struct __pyx_opt_args_9cysignals_5tests_stack_overflow *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9cysignals_5tests_c_test_sig_on_cython(void); /*proto*/
static int __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except(void); /*proto*/
static void __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except_all(void); /*proto*/
static void *__pyx_f_9cysignals_5tests_func_thread_sig_block(void *); /*proto*/
static PyObject *__pyx_f_9cysignals_5tests___pyx_unpickle_DeallocDebug__set_state(struct __pyx_obj_9cysignals_5tests_DeallocDebug *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "cysignals.tests"
extern int __pyx_module_is_main_cysignals__tests;
int __pyx_module_is_main_cysignals__tests = 0;

/* Implementation of "cysignals.tests" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_BaseException;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_KeyboardInterrupt;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_MemoryError;
/* #### Code section: string_decls ### */
static const char __pyx_k_P[] = "P";
static const char __pyx_k_c[] = "-c";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_GO[] = "GO";
static const char __pyx_k__2[] = "/";
static const char __pyx_k__4[] = ": ";
static const char __pyx_k__6[] = "*";
static const char __pyx_k_t1[] = "t1";
static const char __pyx_k_t2[] = "t2";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_err[] = "err";
static const char __pyx_k_exc[] = "exc";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_ptr[] = "ptr";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_PIPE[] = "PIPE";
static const char __pyx_k__113[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_argv[] = "argv";
static const char __pyx_k_call[] = "__call__";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_kwds[] = "kwds";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_Popen[] = "Popen";
static const char __pyx_k_delay[] = "delay";
static const char __pyx_k_flush[] = "flush";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_atexit[] = "atexit";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_sig_on[] = "_sig_on";
static const char __pyx_k_stderr[] = "stderr";
static const char __pyx_k_stdout[] = "stdout";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_Goodbye[] = "Goodbye!";
static const char __pyx_k_Success[] = "Success";
static const char __pyx_k_command[] = "command";
static const char __pyx_k_dealloc[] = "__dealloc__: ";
static const char __pyx_k_goodbye[] = "goodbye";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_signals[] = "signals";
static const char __pyx_k_Received[] = "Received ";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_ms_delay[] = "ms_delay";
static const char __pyx_k_on_stack[] = "on_stack";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_base_delay[] = "base_delay";
static const char __pyx_k_executable[] = "executable";
static const char __pyx_k_interrupts[] = " interrupts";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_subprocess[] = "subprocess";
static const char __pyx_k_test_abort[] = "test_abort";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_communicate[] = "communicate";
static const char __pyx_k_test_sig_on[] = "test_sig_on";
static const char __pyx_k_test_sighup[] = "test_sighup";
static const char __pyx_k_DeallocDebug[] = "DeallocDebug";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_sig_on_bench[] = "sig_on_bench";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_test_bad_str[] = "test_bad_str";
static const char __pyx_k_test_sig_off[] = "test_sig_off";
static const char __pyx_k_test_sig_str[] = "test_sig_str";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_BaseException[] = "BaseException";
static const char __pyx_k_Everything_ok[] = "Everything ok!";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_subpython_err[] = "subpython_err";
static const char __pyx_k_test_sig_block[] = "test_sig_block";
static const char __pyx_k_test_sig_check[] = "test_sig_check";
static const char __pyx_k_test_sig_error[] = "test_sig_error";
static const char __pyx_k_test_sig_retry[] = "test_sig_retry";
static const char __pyx_k_cysignals_tests[] = "cysignals.tests";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_set_debug_level[] = "set_debug_level";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_sig_check_bench[] = "sig_check_bench";
static const char __pyx_k_test_signal_bus[] = "test_signal_bus";
static const char __pyx_k_test_signal_fpe[] = "test_signal_fpe";
static const char __pyx_k_test_signal_ill[] = "test_signal_ill";
static const char __pyx_k_unguarded_abort[] = "unguarded_abort";
static const char __pyx_k_return_exception[] = "return_exception";
static const char __pyx_k_test_signal_abrt[] = "test_signal_abrt";
static const char __pyx_k_test_signal_quit[] = "test_signal_quit";
static const char __pyx_k_test_signal_segv[] = "test_signal_segv";
static const char __pyx_k_KeyboardInterrupt[] = "KeyboardInterrupt";
static const char __pyx_k_mmap_failed_errno[] = "mmap() failed; errno: ";
static const char __pyx_k_on_stack_line_182[] = "on_stack (line 182)";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_print_sig_occurred[] = "print_sig_occurred";
static const char __pyx_k_test_graceful_exit[] = "test_graceful_exit";
static const char __pyx_k_test_sig_on_cython[] = "test_sig_on_cython";
static const char __pyx_k_universal_newlines[] = "universal_newlines";
static const char __pyx_k_munmap_failed_errno[] = "munmap() failed; errno: ";
static const char __pyx_k_test_abort_line_633[] = "test_abort (line 633)";
static const char __pyx_k_test_interrupt_bomb[] = "test_interrupt_bomb";
static const char __pyx_k_test_stack_overflow[] = "test_stack_overflow";
static const char __pyx_k_No_current_exception[] = "No current exception";
static const char __pyx_k_test_sig_on_line_232[] = "test_sig_on (line 232)";
static const char __pyx_k_interrupt_after_delay[] = "interrupt_after_delay";
static const char __pyx_k_test_bad_str_line_726[] = "test_bad_str (line 726)";
static const char __pyx_k_test_sig_block_nested[] = "test_sig_block_nested";
static const char __pyx_k_test_sig_off_line_220[] = "test_sig_off (line 220)";
static const char __pyx_k_test_sig_on_no_except[] = "test_sig_on_no_except";
static const char __pyx_k_test_sig_str_line_247[] = "test_sig_str (line 247)";
static const char __pyx_k_test_sighup_line_1212[] = "test_sighup (line 1212)";
static const char __pyx_k_test_thread_sig_block[] = "test_thread_sig_block";
static const char __pyx_k_sig_on_bench_line_1177[] = "sig_on_bench (line 1177)";
static const char __pyx_k_test_sig_on_inside_try[] = "test_sig_on_inside_try";
static const char __pyx_k_test_sig_str_no_except[] = "test_sig_str_no_except";
static const char __pyx_k_test_sighup_and_sigint[] = "test_sighup_and_sigint";
static const char __pyx_k_test_try_finally_raise[] = "test_try_finally_raise";
static const char __pyx_k_return_exception___call[] = "return_exception.__call__";
static const char __pyx_k_return_exception___init[] = "return_exception.__init__";
static const char __pyx_k_src_cysignals_tests_pyx[] = "src/cysignals/tests.pyx";
static const char __pyx_k_test_sig_check_line_316[] = "test_sig_check (line 316)";
static const char __pyx_k_test_sig_error_line_390[] = "test_sig_error (line 390)";
static const char __pyx_k_test_sig_retry_line_351[] = "test_sig_retry (line 351)";
static const char __pyx_k_test_try_finally_return[] = "test_try_finally_return";
static const char __pyx_k_test_try_finally_signal[] = "test_try_finally_signal";
static const char __pyx_k_test_sig_block_line_1067[] = "test_sig_block (line 1067)";
static const char __pyx_k_test_sig_check_no_except[] = "test_sig_check_no_except";
static const char __pyx_k_test_signal_bus_line_546[] = "test_signal_bus (line 546)";
static const char __pyx_k_test_signal_fpe_line_498[] = "test_signal_fpe (line 498)";
static const char __pyx_k_test_signal_ill_line_514[] = "test_signal_ill (line 514)";
static const char __pyx_k_unguarded_abort_line_648[] = "unguarded_abort (line 648)";
static const char __pyx_k_unguarded_stack_overflow[] = "unguarded_stack_overflow";
static const char __pyx_k_pyx_unpickle_DeallocDebug[] = "__pyx_unpickle_DeallocDebug";
static const char __pyx_k_sig_check_bench_line_1193[] = "sig_check_bench (line 1193)";
static const char __pyx_k_test_sig_occurred_dealloc[] = "test_sig_occurred_dealloc";
static const char __pyx_k_test_sig_occurred_finally[] = "test_sig_occurred_finally";
static const char __pyx_k_test_sig_on_cython_except[] = "test_sig_on_cython_except";
static const char __pyx_k_test_sig_retry_and_signal[] = "test_sig_retry_and_signal";
static const char __pyx_k_test_signal_abrt_line_530[] = "test_signal_abrt (line 530)";
static const char __pyx_k_test_signal_during_malloc[] = "test_signal_during_malloc";
static const char __pyx_k_test_signal_quit_line_562[] = "test_signal_quit (line 562)";
static const char __pyx_k_test_signal_segv_line_482[] = "test_signal_segv (line 482)";
static const char __pyx_k_failed_to_allocate_s_bytes[] = "failed to allocate %s bytes";
static const char __pyx_k_test_access_mmap_noreserve[] = "test_access_mmap_noreserve";
static const char __pyx_k_print_sig_occurred_line_886[] = "print_sig_occurred (line 886)";
static const char __pyx_k_test_sig_on_cython_line_267[] = "test_sig_on_cython (line 267)";
static const char __pyx_k_DeallocDebug___reduce_cython[] = "DeallocDebug.__reduce_cython__";
static const char __pyx_k_failed_to_allocate_s_s_bytes[] = "failed to allocate %s * %s bytes";
static const char __pyx_k_test_graceful_exit_line_1255[] = "test_graceful_exit (line 1255)";
static const char __pyx_k_test_interrupt_bomb_line_785[] = "test_interrupt_bomb (line 785)";
static const char __pyx_k_test_sig_check_inside_sig_on[] = "test_sig_check_inside_sig_on";
static const char __pyx_k_test_stack_overflow_line_668[] = "test_stack_overflow (line 668)";
static const char __pyx_k_test_dereference_null_pointer[] = "test_dereference_null_pointer";
static const char __pyx_k_test_sig_block_outside_sig_on[] = "test_sig_block_outside_sig_on";
static const char __pyx_k_test_sig_on_cython_except_all[] = "test_sig_on_cython_except_all";
static const char __pyx_k_Call_sig_check_1_million_times[] = "\n    Call ``sig_check()`` 1 million times.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> sig_check_bench()\n\n    ";
static const char __pyx_k_DeallocDebug___setstate_cython[] = "DeallocDebug.__setstate_cython__";
static const char __pyx_k_Start_a_subprocess_set_up_some[] = "\n    Start a subprocess, set up some ``atexit`` handler and kill the\n    process with ``SIGHUP``. Then the process should exit gracefully,\n    running the ``atexit`` handler::\n\n        >>> from sys import executable\n        >>> from subprocess import *\n        >>> A = Popen([executable], stdin=PIPE, stdout=PIPE, stderr=PIPE)\n        >>> _ = A.stdin.write(b'from cysignals.tests import test_graceful_exit\\n')\n        >>> _ = A.stdin.write(b'test_graceful_exit()\\n')\n        >>> A.stdin.close()\n\n    Now read from the child until we read ``\"GO\"``.  This ensures that\n    the child process has properly started before we kill it::\n\n        >>> while b'GO' not in A.stdout.readline(): pass\n        >>> import os, signal, sys\n        >>> os.kill(A.pid, signal.SIGHUP)\n        >>> _ = sys.stdout.write(A.stdout.read().decode(\"utf-8\"))\n        Goodbye!\n        >>> A.wait()\n        0\n\n    ";
static const char __pyx_k_interrupt_after_delay_line_154[] = "interrupt_after_delay (line 154)";
static const char __pyx_k_test_sig_on_cython_after_delay[] = "test_sig_on_cython_after_delay";
static const char __pyx_k_test_sig_on_no_except_line_409[] = "test_sig_on_no_except (line 409)";
static const char __pyx_k_Are_we_currently_on_the_alterna[] = "\n    Are we currently on the alternate signal stack (see sigaltstack(2))?\n\n    EXAMPLES::\n\n        >>> from cysignals.tests import on_stack\n        >>> on_stack()\n        False\n\n    ";
static const char __pyx_k_Call_sig_on_and_sig_off_1_milli[] = "\n    Call ``sig_on()`` and ``sig_off()`` 1 million times.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> sig_on_bench()\n\n    ";
static const char __pyx_k_Decorator_class_which_makes_a_f[] = "\n    Decorator class which makes a function *return* an exception which\n    is raised, to simplify doctests raising exceptions.\n\n    EXAMPLES::\n\n        >>> from cysignals.tests import return_exception\n        >>> @return_exception\n        ... def raise_interrupt():\n        ...     raise KeyboardInterrupt(\"just\", \"testing\")\n        >>> raise_interrupt()\n        KeyboardInterrupt('just', 'testing')\n\n    ";
static const char __pyx_k_Have_p_processes_each_sending_n[] = "\n    Have `p` processes each sending `n` interrupts in very quick\n    succession and see what happens :-)\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_interrupt_bomb()  # doctest: +SKIP_CYGWIN\n        Received ... interrupts\n\n    ";
static const char __pyx_k_Print_the_exception_which_is_cu[] = "\n    Print the exception which is currently being handled.\n\n    Note that we print instead of return the exception to mess as little\n    as possible with refcounts.\n\n    EXAMPLES::\n\n        >>> from cysignals.tests import *\n        >>> print_sig_occurred()\n        No current exception\n\n    In Python 3 and in Cython, the exception remains alive only inside\n    the ``except`` clause handling the exception. In Python 2, it stays\n    alive as long as the stack frame where it was raised is still running\n    and calling ``sys.exc_clear()`` clears it::\n\n        >>> import sys\n        >>> from cysignals.alarm import alarm\n        >>> if hasattr(sys, \"exc_clear\"):\n        ...     # Python 2\n        ...     def testfunc():\n        ...         try:\n        ...             alarm(0.1)\n        ...             while True:\n        ...                pass\n        ...         except KeyboardInterrupt:\n        ...             pass\n        ...         print_sig_occurred()\n        ...         sys.exc_clear()\n        ...         print_sig_occurred()\n        ... else:\n        ...     # Python 3\n        ...     def testfunc():\n        ...         try:\n        ...             alarm(0.1)\n        ...             while True:\n        ...                pass\n        ...         except KeyboardInterrupt:\n        ...             print_sig_occurred()\n        ...         print_sig_occurred()\n        >>> testfunc()\n        AlarmInterrupt\n        No current exception\n\n    ";
static const char __pyx_k_Regression_test_for_https_githu[] = "\n    Regression test for https://github.com/sagemath/cysignals/issues/126\n\n    TESTS:\n\n    The first part of this is similar to ``test_sig_occurred_dealloc()`` but we\n    keep a reference to the exception so it doesn't go away right away::\n\n        >>> from cysignals.tests import *\n        >>> import sys\n        >>> e = None\n        >>> try:\n        ...     test_sig_occurred_dealloc_in_gc()\n        ... except RuntimeError as exc:\n        ...     e = exc\n        >>> print_sig_occurred()\n        RuntimeError: test_sig_occurred_dealloc_in_gc()\n\n    Python 2 keeps the target of the \"except as\" in local scope, so make sure\n    to delete it as well::\n\n        >>> if sys.version_info[0] < 3: del exc\n\n    Put the exception into a list containing a reference to itself, so that\n    when the garbage collector runs (in ``verify_exc_value``) its reference\n    count drops to 1.  Also include a ``DeallocDebug`` so that\n    ``sig_occurred()`` is called during GC.\n\n    We also temporarily disable automatic GC to ensure that the garbage\n    collector is not called except by ``verify_exc_value()``::\n\n        >>> import gc\n        >>> l = [DeallocDebug(), e]\n        >>> l.append(l)\n        >>> gc.disable()\n        >>> try:\n        ...     del l, e\n        ...     print_sig_occurred()\n        ... finally:\n        ...     gc.enable()\n        __dealloc__: No current exception\n        No current exception\n\n    ";
static const char __pyx_k_Send_an_interrupt_signal_SIGINT[] = "\n    Send an interrupt signal (``SIGINT``) to the process after a delay of\n    ``ms_delay`` milliseconds.\n\n    INPUT:\n\n        - ``ms_delay`` -- (default: 500) a nonnegative integer indicating how\n          many milliseconds to wait before raising the interrupt signal.\n\n    EXAMPLES:\n\n    This function is meant to test interrupt functionality.  We demonstrate here\n    how to test that an infinite loop can be interrupted::\n\n        >>> import cysignals.tests\n        >>> try:\n        ...     cysignals.tests.interrupt_after_delay()\n        ...     while True:\n        ...         pass\n        ... except KeyboardInterrupt:\n        ...     print(\"Caught KeyboardInterrupt\")\n        Caught KeyboardInterrupt\n\n    ";
static const char __pyx_k_TESTS_Regression_test_for_https[] = "\n    TESTS:\n\n    Regression test for https://github.com/sagemath/cysignals/pull/108; if\n    the issue is fixed then ``test_access_mmap_noreserve()`` should have no\n    output.  Otherwise the subprocess will exit and report an error occurred\n    during signal handling::\n\n        >>> from cysignals.tests import test_access_mmap_noreserve\n        >>> test_access_mmap_noreserve()\n\n    ";
static const char __pyx_k_TESTS_This_test_should_result_i[] = "\n    TESTS:\n\n    This test should result in either a Segmentation Fault or a Bus\n    Error. ::\n\n        >>> from cysignals.tests import *\n        >>> test_dereference_null_pointer()\n        Traceback (most recent call last):\n        ...\n        SignalError: ...\n        >>> on_stack()\n        False\n\n    ";
static const char __pyx_k_TESTS_We_run_Python_in_a_subpro[] = "\n    TESTS:\n\n    We run Python in a subprocess and make it raise a SIGQUIT under\n    ``sig_on()``.  This should cause Python to exit::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; test_signal_quit()')\n        ---------------------------------------------------------------------...\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_off()\n\n    ";
static const char __pyx_k_Test_a_SIGHUP_and_a_SIGINT_arri[] = "\n    Test a SIGHUP and a SIGINT arriving at essentially the same time.\n    The SIGINT should be ignored and we should get a ``SystemExit``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sighup_and_sigint()\n        SystemExit()\n\n    ";
static const char __pyx_k_Test_a_basic_SIGHUP_signal_whic[] = "\n    Test a basic SIGHUP signal, which would normally exit the Python interpreter\n    by raising ``SystemExit``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sighup()\n        SystemExit()\n\n    ";
static const char __pyx_k_Test_a_signal_arriving_during_a[] = "\n    Test a signal arriving during a sig_malloc() or sig_free() call.\n    Since these are wrapped with sig_block()/sig_unblock(), we should\n    safely be able to interrupt them.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> for i in range(5):  # Several times to reduce chances of false positive\n        ...     test_signal_during_malloc()\n\n    ";
static const char __pyx_k_Test_a_try_finally_construct_fo[] = "\n    Test a try/finally construct for sig_on() and sig_off(), raising\n    a signal inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_signal()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ";
static const char __pyx_k_Test_interrupt_and_signal_handl[] = "\nTest interrupt and signal handling\n\nTESTS:\n\nWe disable crash debugging for this test run::\n\n    >>> import os\n    >>> os.environ[\"CYSIGNALS_CRASH_NDEBUG\"] = \"\"\n\nVerify that the doctester was set up correctly::\n\n    >>> import os\n    >>> os.name == \"posix\"  # doctest: +SKIP_POSIX\n    False\n    >>> os.name == \"nt\"     # doctest: +SKIP_WINDOWS\n    False\n\n";
static const char __pyx_k_Test_that_calling_sig_block_sig[] = "\n    Test that calling ``sig_block``/``sig_unblock`` is thread-safe.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_thread_sig_block()\n\n    ";
static const char __pyx_k_test_access_mmap_noreserve_line[] = "test_access_mmap_noreserve (line 703)";
static const char __pyx_k_test_sig_block_nested_line_1093[] = "test_sig_block_nested (line 1093)";
static const char __pyx_k_test_sig_occurred_dealloc_in_gc[] = "test_sig_occurred_dealloc_in_gc";
static const char __pyx_k_test_sig_on_inside_try_line_768[] = "test_sig_on_inside_try (line 768)";
static const char __pyx_k_test_sig_str_no_except_line_438[] = "test_sig_str_no_except (line 438)";
static const char __pyx_k_test_thread_sig_block_line_1299[] = "test_thread_sig_block (line 1299)";
static const char __pyx_k_test_try_finally_raise_line_843[] = "test_try_finally_raise (line 843)";
static const char __pyx_k_Incompatible_checksums_s_vs_0xda[] = "Incompatible checksums (%s vs 0xda39a3e = ())";
static const char __pyx_k_Unexpected_zero_returned_from_si[] = "Unexpected zero returned from sig_on_no_except()";
static const char __pyx_k_test_dereference_null_pointer_li[] = "test_dereference_null_pointer (line 584)";
static const char __pyx_k_test_graceful_exit_locals_goodby[] = "test_graceful_exit.<locals>.goodbye";
static const char __pyx_k_test_sig_block_outside_sig_on_li[] = "test_sig_block_outside_sig_on (line 1126)";
static const char __pyx_k_test_sig_check_inside_sig_on_lin[] = "test_sig_check_inside_sig_on (line 331)";
static const char __pyx_k_test_sig_check_no_except_line_46[] = "test_sig_check_no_except (line 461)";
static const char __pyx_k_test_sig_occurred_dealloc_line_9[] = "test_sig_occurred_dealloc (line 990)";
static const char __pyx_k_test_sig_occurred_finally_line_9[] = "test_sig_occurred_finally (line 947)";
static const char __pyx_k_test_sig_occurred_live_exception[] = "test_sig_occurred_live_exception";
static const char __pyx_k_test_sig_on_cython_after_delay_l[] = "test_sig_on_cython_after_delay (line 752)";
static const char __pyx_k_test_sig_on_cython_except_all_li[] = "test_sig_on_cython_except_all (line 302)";
static const char __pyx_k_test_sig_on_cython_except_line_2[] = "test_sig_on_cython_except (line 284)";
static const char __pyx_k_test_sig_retry_and_signal_line_3[] = "test_sig_retry_and_signal (line 370)";
static const char __pyx_k_test_sighup_and_sigint_line_1230[] = "test_sighup_and_sigint (line 1230)";
static const char __pyx_k_test_signal_during_malloc_line_1[] = "test_signal_during_malloc (line 1152)";
static const char __pyx_k_test_try_finally_return_line_863[] = "test_try_finally_return (line 863)";
static const char __pyx_k_test_try_finally_signal_line_822[] = "test_try_finally_signal (line 822)";
static const char __pyx_k_unguarded_dereference_null_point[] = "unguarded_dereference_null_pointer";
static const char __pyx_k_unguarded_stack_overflow_line_68[] = "unguarded_stack_overflow (line 683)";
static const char __pyx_k_TESTS_We_run_Python_in_a_subpro_2[] = "\n    TESTS:\n\n    We run Python in a subprocess and dereference a NULL pointer without\n    using ``sig_on()``. This will crash Python::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_dereference_null_pointer()')\n        ---------------------------------------------------------------------...\n        Unhandled SIG...\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    The same but with ``CYSIGNALS_CRASH_QUIET`` set. This will crash\n    Python silently::\n\n        >>> import os\n        >>> env = dict(os.environ)\n        >>> env[\"CYSIGNALS_CRASH_QUIET\"] = \"\"\n        >>> subpython_err('from cysignals.tests import *; unguarded_dereference_null_pointer()', env=env)\n\n    ";
static const char __pyx_k_TESTS_We_run_Python_in_a_subpro_3[] = "\n    TESTS:\n\n    We run Python in a subprocess and make it call abort()::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_abort()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGABRT: An abort() occurred.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ";
static const char __pyx_k_TESTS_We_run_Python_in_a_subpro_4[] = "\n    TESTS:\n\n    We run Python in a subprocess and overflow the stack::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_stack_overflow()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGSEGV: A segmentation fault occurred.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ";
static const char __pyx_k_TESTS_We_run_Python_in_a_subpro_5[] = "\n    TESTS:\n\n    We run Python in a subprocess and induce an error during the signal handler::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; test_bad_str()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGSEGV during signal handling.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_2[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_3[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_str()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_4[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_5[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_except()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_6[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_except_all()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_7[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_8[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check_inside_sig_on()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_9[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_retry()\n        10\n\n    ";
static const char __pyx_k_Test_a_try_finally_construct_fo_2[] = "\n    Test a try/finally construct for sig_on() and sig_off(), raising\n    a Python exception inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_raise()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ";
static const char __pyx_k_Test_a_try_finally_construct_fo_3[] = "\n    Test a try/finally construct for sig_on() and sig_off(), doing a\n    normal ``return`` inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_return()\n        'Everything ok!'\n\n    ";
static const char __pyx_k_test_sig_occurred_dealloc_in_gc_2[] = "test_sig_occurred_dealloc_in_gc (line 1009)";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_10[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_retry_and_signal()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_11[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_error()\n        Traceback (most recent call last):\n        ...\n        ValueError: some error\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_12[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_no_except()\n        42\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_13[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_str_no_except()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_14[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check_no_except()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_15[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_segv()\n        Traceback (most recent call last):\n        ...\n        SignalError: Segmentation fault\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_16[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_fpe()\n        Traceback (most recent call last):\n        ...\n        FloatingPointError: Floating point exception\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_17[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_ill()\n        Traceback (most recent call last):\n        ...\n        SignalError: Illegal instruction\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_18[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_abrt()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_19[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_bus()\n        Traceback (most recent call last):\n        ...\n        SignalError: Bus error\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_20[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_abort()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_21[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_stack_overflow()\n        Traceback (most recent call last):\n        ...\n        SignalError: Segmentation fault\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_22[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_after_delay()\n        KeyboardInterrupt()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_23[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_inside_try()\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_24[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_occurred_finally()\n        No current exception\n        RuntimeError: test_sig_occurred_finally()\n        RuntimeError: test_sig_occurred_finally()\n        No current exception\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_25[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> try:\n        ...     test_sig_occurred_live_exception()\n        ... except RuntimeError:\n        ...     pass\n        RuntimeError: Aborted\n        >>> print_sig_occurred()\n        No current exception\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_26[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> try:\n        ...     test_sig_occurred_dealloc()\n        ... except RuntimeError:\n        ...     pass\n        __dealloc__: RuntimeError: test_sig_occurred_dealloc()\n        >>> print_sig_occurred()\n        No current exception\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_27[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block()\n        42\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_28[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block_nested()\n        42\n\n    ";
static const char __pyx_k_TESTS_from_cysignals_tests_impo_29[] = "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block_outside_sig_on()\n        'Success'\n\n    ";
static const char __pyx_k_test_sig_occurred_live_exception_2[] = "test_sig_occurred_live_exception (line 971)";
static const char __pyx_k_unguarded_dereference_null_point_2[] = "unguarded_dereference_null_pointer (line 604)";
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__pyx_kp_u_Are_we_currently_on_the_alterna;
static PyObject *__pyx_n_s_BaseException;
static PyObject *__pyx_kp_u_Call_sig_check_1_million_times;
static PyObject *__pyx_kp_u_Call_sig_on_and_sig_off_1_milli;
static PyObject *__pyx_n_s_DeallocDebug;
static PyObject *__pyx_n_s_DeallocDebug___reduce_cython;
static PyObject *__pyx_n_s_DeallocDebug___setstate_cython;
static PyObject *__pyx_kp_s_Decorator_class_which_makes_a_f;
static PyObject *__pyx_kp_s_Everything_ok;
static PyObject *__pyx_n_s_GO;
static PyObject *__pyx_kp_s_Goodbye;
static PyObject *__pyx_kp_u_Have_p_processes_each_sending_n;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xda;
static PyObject *__pyx_n_s_KeyboardInterrupt;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_s_No_current_exception;
static PyObject *__pyx_n_s_P;
static PyObject *__pyx_n_s_PIPE;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_Popen;
static PyObject *__pyx_kp_u_Print_the_exception_which_is_cu;
static PyObject *__pyx_kp_u_Received;
static PyObject *__pyx_kp_u_Regression_test_for_https_githu;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_kp_u_Send_an_interrupt_signal_SIGINT;
static PyObject *__pyx_kp_u_Start_a_subprocess_set_up_some;
static PyObject *__pyx_n_s_Success;
static PyObject *__pyx_kp_u_TESTS_Regression_test_for_https;
static PyObject *__pyx_kp_u_TESTS_This_test_should_result_i;
static PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro;
static PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2;
static PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3;
static PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4;
static PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_10;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_11;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_12;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_13;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_14;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_15;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_16;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_17;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_18;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_19;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_2;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_20;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_21;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_22;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_23;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_24;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_25;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_26;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_27;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_28;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_29;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_3;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_4;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_5;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_6;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_7;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_8;
static PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_9;
static PyObject *__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri;
static PyObject *__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic;
static PyObject *__pyx_kp_u_Test_a_signal_arriving_during_a;
static PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo;
static PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo_2;
static PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo_3;
static PyObject *__pyx_kp_u_Test_that_calling_sig_block_sig;
static PyObject *__pyx_kp_s_Unexpected_zero_returned_from_si;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s__113;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_s__4;
static PyObject *__pyx_n_s__6;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_argv;
static PyObject *__pyx_n_s_atexit;
static PyObject *__pyx_n_s_base_delay;
static PyObject *__pyx_kp_s_c;
static PyObject *__pyx_n_s_call;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_command;
static PyObject *__pyx_n_s_communicate;
static PyObject *__pyx_n_s_cysignals_tests;
static PyObject *__pyx_kp_s_dealloc;
static PyObject *__pyx_n_s_delay;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_dict_2;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_e;
static PyObject *__pyx_n_s_err;
static PyObject *__pyx_n_s_exc;
static PyObject *__pyx_n_s_executable;
static PyObject *__pyx_kp_s_failed_to_allocate_s_bytes;
static PyObject *__pyx_kp_s_failed_to_allocate_s_s_bytes;
static PyObject *__pyx_n_s_flush;
static PyObject *__pyx_n_s_func;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_goodbye;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_init_subclass;
static PyObject *__pyx_n_s_initializing;
static PyObject *__pyx_n_s_interrupt_after_delay;
static PyObject *__pyx_kp_u_interrupt_after_delay_line_154;
static PyObject *__pyx_kp_u_interrupts;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_kwds;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_kp_u_mmap_failed_errno;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_ms_delay;
static PyObject *__pyx_kp_u_munmap_failed_errno;
static PyObject *__pyx_n_s_n;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_n_s_on_stack;
static PyObject *__pyx_kp_u_on_stack_line_182;
static PyObject *__pyx_n_s_out;
static PyObject *__pyx_n_s_p;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_print_sig_occurred;
static PyObject *__pyx_kp_u_print_sig_occurred_line_886;
static PyObject *__pyx_n_s_ptr;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_DeallocDebug;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_register;
static PyObject *__pyx_n_s_return_exception;
static PyObject *__pyx_n_s_return_exception___call;
static PyObject *__pyx_n_s_return_exception___init;
static PyObject *__pyx_n_s_s;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_set_debug_level;
static PyObject *__pyx_n_s_set_name;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_sig_check_bench;
static PyObject *__pyx_kp_u_sig_check_bench_line_1193;
static PyObject *__pyx_n_s_sig_on;
static PyObject *__pyx_n_s_sig_on_bench;
static PyObject *__pyx_kp_u_sig_on_bench_line_1177;
static PyObject *__pyx_n_s_signals;
static PyObject *__pyx_n_s_spec;
static PyObject *__pyx_kp_s_src_cysignals_tests_pyx;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_stderr;
static PyObject *__pyx_n_s_stdout;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_subprocess;
static PyObject *__pyx_n_s_subpython_err;
static PyObject *__pyx_n_s_super;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_t;
static PyObject *__pyx_n_s_t1;
static PyObject *__pyx_n_s_t2;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_test_abort;
static PyObject *__pyx_kp_u_test_abort_line_633;
static PyObject *__pyx_n_s_test_access_mmap_noreserve;
static PyObject *__pyx_kp_u_test_access_mmap_noreserve_line;
static PyObject *__pyx_n_s_test_bad_str;
static PyObject *__pyx_kp_u_test_bad_str_line_726;
static PyObject *__pyx_n_s_test_dereference_null_pointer;
static PyObject *__pyx_kp_u_test_dereference_null_pointer_li;
static PyObject *__pyx_n_s_test_graceful_exit;
static PyObject *__pyx_kp_u_test_graceful_exit_line_1255;
static PyObject *__pyx_n_s_test_graceful_exit_locals_goodby;
static PyObject *__pyx_n_s_test_interrupt_bomb;
static PyObject *__pyx_kp_u_test_interrupt_bomb_line_785;
static PyObject *__pyx_n_s_test_sig_block;
static PyObject *__pyx_kp_u_test_sig_block_line_1067;
static PyObject *__pyx_n_s_test_sig_block_nested;
static PyObject *__pyx_kp_u_test_sig_block_nested_line_1093;
static PyObject *__pyx_n_s_test_sig_block_outside_sig_on;
static PyObject *__pyx_kp_u_test_sig_block_outside_sig_on_li;
static PyObject *__pyx_n_s_test_sig_check;
static PyObject *__pyx_n_s_test_sig_check_inside_sig_on;
static PyObject *__pyx_kp_u_test_sig_check_inside_sig_on_lin;
static PyObject *__pyx_kp_u_test_sig_check_line_316;
static PyObject *__pyx_n_s_test_sig_check_no_except;
static PyObject *__pyx_kp_u_test_sig_check_no_except_line_46;
static PyObject *__pyx_n_s_test_sig_error;
static PyObject *__pyx_kp_u_test_sig_error_line_390;
static PyObject *__pyx_n_s_test_sig_occurred_dealloc;
static PyObject *__pyx_n_s_test_sig_occurred_dealloc_in_gc;
static PyObject *__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2;
static PyObject *__pyx_kp_u_test_sig_occurred_dealloc_line_9;
static PyObject *__pyx_n_s_test_sig_occurred_finally;
static PyObject *__pyx_kp_u_test_sig_occurred_finally_line_9;
static PyObject *__pyx_n_s_test_sig_occurred_live_exception;
static PyObject *__pyx_kp_u_test_sig_occurred_live_exception_2;
static PyObject *__pyx_n_s_test_sig_off;
static PyObject *__pyx_kp_u_test_sig_off_line_220;
static PyObject *__pyx_n_s_test_sig_on;
static PyObject *__pyx_n_s_test_sig_on_cython;
static PyObject *__pyx_n_s_test_sig_on_cython_after_delay;
static PyObject *__pyx_kp_u_test_sig_on_cython_after_delay_l;
static PyObject *__pyx_n_s_test_sig_on_cython_except;
static PyObject *__pyx_n_s_test_sig_on_cython_except_all;
static PyObject *__pyx_kp_u_test_sig_on_cython_except_all_li;
static PyObject *__pyx_kp_u_test_sig_on_cython_except_line_2;
static PyObject *__pyx_kp_u_test_sig_on_cython_line_267;
static PyObject *__pyx_n_s_test_sig_on_inside_try;
static PyObject *__pyx_kp_u_test_sig_on_inside_try_line_768;
static PyObject *__pyx_kp_u_test_sig_on_line_232;
static PyObject *__pyx_n_s_test_sig_on_no_except;
static PyObject *__pyx_kp_u_test_sig_on_no_except_line_409;
static PyObject *__pyx_n_s_test_sig_retry;
static PyObject *__pyx_n_s_test_sig_retry_and_signal;
static PyObject *__pyx_kp_u_test_sig_retry_and_signal_line_3;
static PyObject *__pyx_kp_u_test_sig_retry_line_351;
static PyObject *__pyx_n_s_test_sig_str;
static PyObject *__pyx_kp_u_test_sig_str_line_247;
static PyObject *__pyx_n_s_test_sig_str_no_except;
static PyObject *__pyx_kp_u_test_sig_str_no_except_line_438;
static PyObject *__pyx_n_s_test_sighup;
static PyObject *__pyx_n_s_test_sighup_and_sigint;
static PyObject *__pyx_kp_u_test_sighup_and_sigint_line_1230;
static PyObject *__pyx_kp_u_test_sighup_line_1212;
static PyObject *__pyx_n_s_test_signal_abrt;
static PyObject *__pyx_kp_u_test_signal_abrt_line_530;
static PyObject *__pyx_n_s_test_signal_bus;
static PyObject *__pyx_kp_u_test_signal_bus_line_546;
static PyObject *__pyx_n_s_test_signal_during_malloc;
static PyObject *__pyx_kp_u_test_signal_during_malloc_line_1;
static PyObject *__pyx_n_s_test_signal_fpe;
static PyObject *__pyx_kp_u_test_signal_fpe_line_498;
static PyObject *__pyx_n_s_test_signal_ill;
static PyObject *__pyx_kp_u_test_signal_ill_line_514;
static PyObject *__pyx_n_s_test_signal_quit;
static PyObject *__pyx_kp_u_test_signal_quit_line_562;
static PyObject *__pyx_n_s_test_signal_segv;
static PyObject *__pyx_kp_u_test_signal_segv_line_482;
static PyObject *__pyx_n_s_test_stack_overflow;
static PyObject *__pyx_kp_u_test_stack_overflow_line_668;
static PyObject *__pyx_n_s_test_thread_sig_block;
static PyObject *__pyx_kp_u_test_thread_sig_block_line_1299;
static PyObject *__pyx_n_s_test_try_finally_raise;
static PyObject *__pyx_kp_u_test_try_finally_raise_line_843;
static PyObject *__pyx_n_s_test_try_finally_return;
static PyObject *__pyx_kp_u_test_try_finally_return_line_863;
static PyObject *__pyx_n_s_test_try_finally_signal;
static PyObject *__pyx_kp_u_test_try_finally_signal_line_822;
static PyObject *__pyx_n_s_unguarded_abort;
static PyObject *__pyx_kp_u_unguarded_abort_line_648;
static PyObject *__pyx_n_s_unguarded_dereference_null_point;
static PyObject *__pyx_kp_u_unguarded_dereference_null_point_2;
static PyObject *__pyx_n_s_unguarded_stack_overflow;
static PyObject *__pyx_kp_u_unguarded_stack_overflow_line_68;
static PyObject *__pyx_n_s_universal_newlines;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_use_setstate;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_x;
#endif
/* #### Code section: decls ### */
static PyObject *__pyx_pf_9cysignals_5tests_16return_exception___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_func); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_16return_exception_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_interrupt_after_delay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_ms_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_2on_stack(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_4_sig_on(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_6subpython_err(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_command, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_8test_sig_off(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_108__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_10test_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_110__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_12test_sig_str(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_112__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_14test_sig_on_cython(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_114__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_16test_sig_on_cython_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_116__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_18test_sig_on_cython_except_all(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_118__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_20test_sig_check(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_120__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_22test_sig_check_inside_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_24test_sig_retry(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_122__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_26test_sig_retry_and_signal(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_28test_sig_error(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_124__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_30test_sig_on_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_126__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_32test_sig_str_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_128__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_34test_sig_check_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_130__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_36test_signal_segv(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_132__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_38test_signal_fpe(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_134__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_40test_signal_ill(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_136__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_42test_signal_abrt(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_138__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_44test_signal_bus(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_140__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_46test_signal_quit(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_48test_dereference_null_pointer(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_50unguarded_dereference_null_pointer(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_52test_abort(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_54unguarded_abort(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_56test_stack_overflow(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_58unguarded_stack_overflow(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_60test_access_mmap_noreserve(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_142__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_62test_bad_str(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_144__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_64test_sig_on_cython_after_delay(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_146__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_66test_sig_on_inside_try(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_68test_interrupt_bomb(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_n, long __pyx_v_p); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_148__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_70test_try_finally_signal(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_72test_try_finally_raise(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_74test_try_finally_return(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_76print_sig_occurred(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_78test_sig_occurred_finally(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_80test_sig_occurred_live_exception(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_82test_sig_occurred_dealloc(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_84test_sig_occurred_dealloc_in_gc(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static void __pyx_pf_9cysignals_5tests_12DeallocDebug___dealloc__(CYTHON_UNUSED struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_12DeallocDebug_2__reduce_cython__(struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_12DeallocDebug_4__setstate_cython__(struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_150__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_86test_sig_block(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_152__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_88test_sig_block_nested(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_154__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_90test_sig_block_outside_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_156__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_92test_signal_during_malloc(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_94sig_on_bench(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_96sig_check_bench(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_158__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_98test_sighup(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_160__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_100test_sighup_and_sigint(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_18test_graceful_exit_goodbye(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_102test_graceful_exit(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_162__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_104test_thread_sig_block(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED long __pyx_v_delay); /* proto */
static PyObject *__pyx_pf_9cysignals_5tests_106__pyx_unpickle_DeallocDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9cysignals_5tests_DeallocDebug(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_42;
static PyObject *__pyx_int_500;
static PyObject *__pyx_int_228825662;
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_codeobj__7;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__109;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_codeobj__12;
static PyObject *__pyx_codeobj__14;
static PyObject *__pyx_codeobj__16;
static PyObject *__pyx_codeobj__18;
static PyObject *__pyx_codeobj__19;
static PyObject *__pyx_codeobj__21;
static PyObject *__pyx_codeobj__22;
static PyObject *__pyx_codeobj__24;
static PyObject *__pyx_codeobj__26;
static PyObject *__pyx_codeobj__28;
static PyObject *__pyx_codeobj__30;
static PyObject *__pyx_codeobj__32;
static PyObject *__pyx_codeobj__34;
static PyObject *__pyx_codeobj__36;
static PyObject *__pyx_codeobj__38;
static PyObject *__pyx_codeobj__40;
static PyObject *__pyx_codeobj__41;
static PyObject *__pyx_codeobj__43;
static PyObject *__pyx_codeobj__45;
static PyObject *__pyx_codeobj__47;
static PyObject *__pyx_codeobj__49;
static PyObject *__pyx_codeobj__51;
static PyObject *__pyx_codeobj__53;
static PyObject *__pyx_codeobj__55;
static PyObject *__pyx_codeobj__57;
static PyObject *__pyx_codeobj__59;
static PyObject *__pyx_codeobj__60;
static PyObject *__pyx_codeobj__61;
static PyObject *__pyx_codeobj__62;
static PyObject *__pyx_codeobj__63;
static PyObject *__pyx_codeobj__64;
static PyObject *__pyx_codeobj__65;
static PyObject *__pyx_codeobj__67;
static PyObject *__pyx_codeobj__69;
static PyObject *__pyx_codeobj__71;
static PyObject *__pyx_codeobj__73;
static PyObject *__pyx_codeobj__75;
static PyObject *__pyx_codeobj__77;
static PyObject *__pyx_codeobj__78;
static PyObject *__pyx_codeobj__79;
static PyObject *__pyx_codeobj__81;
static PyObject *__pyx_codeobj__82;
static PyObject *__pyx_codeobj__83;
static PyObject *__pyx_codeobj__85;
static PyObject *__pyx_codeobj__86;
static PyObject *__pyx_codeobj__88;
static PyObject *__pyx_codeobj__90;
static PyObject *__pyx_codeobj__92;
static PyObject *__pyx_codeobj__94;
static PyObject *__pyx_codeobj__96;
static PyObject *__pyx_codeobj__98;
static PyObject *__pyx_codeobj__100;
static PyObject *__pyx_codeobj__102;
static PyObject *__pyx_codeobj__104;
static PyObject *__pyx_codeobj__106;
static PyObject *__pyx_codeobj__108;
static PyObject *__pyx_codeobj__110;
static PyObject *__pyx_codeobj__112;
#endif
/* #### Code section: late_includes ### */
#include "macros.h"
#include "tests_helper.c"
/* #### Code section: module_state ### */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_7cpython_4bool_bool;
  PyTypeObject *__pyx_ptype_7cpython_7complex_complex;
  PyTypeObject *__pyx_ptype_9cysignals_5tests_DeallocDebug;
  PyObject *__pyx_type_9cysignals_5tests_DeallocDebug;
  PyObject *__pyx_kp_u_Are_we_currently_on_the_alterna;
  PyObject *__pyx_n_s_BaseException;
  PyObject *__pyx_kp_u_Call_sig_check_1_million_times;
  PyObject *__pyx_kp_u_Call_sig_on_and_sig_off_1_milli;
  PyObject *__pyx_n_s_DeallocDebug;
  PyObject *__pyx_n_s_DeallocDebug___reduce_cython;
  PyObject *__pyx_n_s_DeallocDebug___setstate_cython;
  PyObject *__pyx_kp_s_Decorator_class_which_makes_a_f;
  PyObject *__pyx_kp_s_Everything_ok;
  PyObject *__pyx_n_s_GO;
  PyObject *__pyx_kp_s_Goodbye;
  PyObject *__pyx_kp_u_Have_p_processes_each_sending_n;
  PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xda;
  PyObject *__pyx_n_s_KeyboardInterrupt;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_kp_s_No_current_exception;
  PyObject *__pyx_n_s_P;
  PyObject *__pyx_n_s_PIPE;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_Popen;
  PyObject *__pyx_kp_u_Print_the_exception_which_is_cu;
  PyObject *__pyx_kp_u_Received;
  PyObject *__pyx_kp_u_Regression_test_for_https_githu;
  PyObject *__pyx_n_s_RuntimeError;
  PyObject *__pyx_kp_u_Send_an_interrupt_signal_SIGINT;
  PyObject *__pyx_kp_u_Start_a_subprocess_set_up_some;
  PyObject *__pyx_n_s_Success;
  PyObject *__pyx_kp_u_TESTS_Regression_test_for_https;
  PyObject *__pyx_kp_u_TESTS_This_test_should_result_i;
  PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro;
  PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2;
  PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3;
  PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4;
  PyObject *__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_10;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_11;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_12;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_13;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_14;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_15;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_16;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_17;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_18;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_19;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_2;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_20;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_21;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_22;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_23;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_24;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_25;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_26;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_27;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_28;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_29;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_3;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_4;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_5;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_6;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_7;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_8;
  PyObject *__pyx_kp_u_TESTS_from_cysignals_tests_impo_9;
  PyObject *__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri;
  PyObject *__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic;
  PyObject *__pyx_kp_u_Test_a_signal_arriving_during_a;
  PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo;
  PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo_2;
  PyObject *__pyx_kp_u_Test_a_try_finally_construct_fo_3;
  PyObject *__pyx_kp_u_Test_that_calling_sig_block_sig;
  PyObject *__pyx_kp_s_Unexpected_zero_returned_from_si;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s__113;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_s__4;
  PyObject *__pyx_n_s__6;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_argv;
  PyObject *__pyx_n_s_atexit;
  PyObject *__pyx_n_s_base_delay;
  PyObject *__pyx_kp_s_c;
  PyObject *__pyx_n_s_call;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_command;
  PyObject *__pyx_n_s_communicate;
  PyObject *__pyx_n_s_cysignals_tests;
  PyObject *__pyx_kp_s_dealloc;
  PyObject *__pyx_n_s_delay;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_n_s_e;
  PyObject *__pyx_n_s_err;
  PyObject *__pyx_n_s_exc;
  PyObject *__pyx_n_s_executable;
  PyObject *__pyx_kp_s_failed_to_allocate_s_bytes;
  PyObject *__pyx_kp_s_failed_to_allocate_s_s_bytes;
  PyObject *__pyx_n_s_flush;
  PyObject *__pyx_n_s_func;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_goodbye;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_interrupt_after_delay;
  PyObject *__pyx_kp_u_interrupt_after_delay_line_154;
  PyObject *__pyx_kp_u_interrupts;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_kwds;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_kp_u_mmap_failed_errno;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_ms_delay;
  PyObject *__pyx_kp_u_munmap_failed_errno;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_on_stack;
  PyObject *__pyx_kp_u_on_stack_line_182;
  PyObject *__pyx_n_s_out;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_print_sig_occurred;
  PyObject *__pyx_kp_u_print_sig_occurred_line_886;
  PyObject *__pyx_n_s_ptr;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_DeallocDebug;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_return_exception;
  PyObject *__pyx_n_s_return_exception___call;
  PyObject *__pyx_n_s_return_exception___init;
  PyObject *__pyx_n_s_s;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_s_set_debug_level;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_sig_check_bench;
  PyObject *__pyx_kp_u_sig_check_bench_line_1193;
  PyObject *__pyx_n_s_sig_on;
  PyObject *__pyx_n_s_sig_on_bench;
  PyObject *__pyx_kp_u_sig_on_bench_line_1177;
  PyObject *__pyx_n_s_signals;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_kp_s_src_cysignals_tests_pyx;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_stderr;
  PyObject *__pyx_n_s_stdout;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_subprocess;
  PyObject *__pyx_n_s_subpython_err;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_t;
  PyObject *__pyx_n_s_t1;
  PyObject *__pyx_n_s_t2;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_test_abort;
  PyObject *__pyx_kp_u_test_abort_line_633;
  PyObject *__pyx_n_s_test_access_mmap_noreserve;
  PyObject *__pyx_kp_u_test_access_mmap_noreserve_line;
  PyObject *__pyx_n_s_test_bad_str;
  PyObject *__pyx_kp_u_test_bad_str_line_726;
  PyObject *__pyx_n_s_test_dereference_null_pointer;
  PyObject *__pyx_kp_u_test_dereference_null_pointer_li;
  PyObject *__pyx_n_s_test_graceful_exit;
  PyObject *__pyx_kp_u_test_graceful_exit_line_1255;
  PyObject *__pyx_n_s_test_graceful_exit_locals_goodby;
  PyObject *__pyx_n_s_test_interrupt_bomb;
  PyObject *__pyx_kp_u_test_interrupt_bomb_line_785;
  PyObject *__pyx_n_s_test_sig_block;
  PyObject *__pyx_kp_u_test_sig_block_line_1067;
  PyObject *__pyx_n_s_test_sig_block_nested;
  PyObject *__pyx_kp_u_test_sig_block_nested_line_1093;
  PyObject *__pyx_n_s_test_sig_block_outside_sig_on;
  PyObject *__pyx_kp_u_test_sig_block_outside_sig_on_li;
  PyObject *__pyx_n_s_test_sig_check;
  PyObject *__pyx_n_s_test_sig_check_inside_sig_on;
  PyObject *__pyx_kp_u_test_sig_check_inside_sig_on_lin;
  PyObject *__pyx_kp_u_test_sig_check_line_316;
  PyObject *__pyx_n_s_test_sig_check_no_except;
  PyObject *__pyx_kp_u_test_sig_check_no_except_line_46;
  PyObject *__pyx_n_s_test_sig_error;
  PyObject *__pyx_kp_u_test_sig_error_line_390;
  PyObject *__pyx_n_s_test_sig_occurred_dealloc;
  PyObject *__pyx_n_s_test_sig_occurred_dealloc_in_gc;
  PyObject *__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2;
  PyObject *__pyx_kp_u_test_sig_occurred_dealloc_line_9;
  PyObject *__pyx_n_s_test_sig_occurred_finally;
  PyObject *__pyx_kp_u_test_sig_occurred_finally_line_9;
  PyObject *__pyx_n_s_test_sig_occurred_live_exception;
  PyObject *__pyx_kp_u_test_sig_occurred_live_exception_2;
  PyObject *__pyx_n_s_test_sig_off;
  PyObject *__pyx_kp_u_test_sig_off_line_220;
  PyObject *__pyx_n_s_test_sig_on;
  PyObject *__pyx_n_s_test_sig_on_cython;
  PyObject *__pyx_n_s_test_sig_on_cython_after_delay;
  PyObject *__pyx_kp_u_test_sig_on_cython_after_delay_l;
  PyObject *__pyx_n_s_test_sig_on_cython_except;
  PyObject *__pyx_n_s_test_sig_on_cython_except_all;
  PyObject *__pyx_kp_u_test_sig_on_cython_except_all_li;
  PyObject *__pyx_kp_u_test_sig_on_cython_except_line_2;
  PyObject *__pyx_kp_u_test_sig_on_cython_line_267;
  PyObject *__pyx_n_s_test_sig_on_inside_try;
  PyObject *__pyx_kp_u_test_sig_on_inside_try_line_768;
  PyObject *__pyx_kp_u_test_sig_on_line_232;
  PyObject *__pyx_n_s_test_sig_on_no_except;
  PyObject *__pyx_kp_u_test_sig_on_no_except_line_409;
  PyObject *__pyx_n_s_test_sig_retry;
  PyObject *__pyx_n_s_test_sig_retry_and_signal;
  PyObject *__pyx_kp_u_test_sig_retry_and_signal_line_3;
  PyObject *__pyx_kp_u_test_sig_retry_line_351;
  PyObject *__pyx_n_s_test_sig_str;
  PyObject *__pyx_kp_u_test_sig_str_line_247;
  PyObject *__pyx_n_s_test_sig_str_no_except;
  PyObject *__pyx_kp_u_test_sig_str_no_except_line_438;
  PyObject *__pyx_n_s_test_sighup;
  PyObject *__pyx_n_s_test_sighup_and_sigint;
  PyObject *__pyx_kp_u_test_sighup_and_sigint_line_1230;
  PyObject *__pyx_kp_u_test_sighup_line_1212;
  PyObject *__pyx_n_s_test_signal_abrt;
  PyObject *__pyx_kp_u_test_signal_abrt_line_530;
  PyObject *__pyx_n_s_test_signal_bus;
  PyObject *__pyx_kp_u_test_signal_bus_line_546;
  PyObject *__pyx_n_s_test_signal_during_malloc;
  PyObject *__pyx_kp_u_test_signal_during_malloc_line_1;
  PyObject *__pyx_n_s_test_signal_fpe;
  PyObject *__pyx_kp_u_test_signal_fpe_line_498;
  PyObject *__pyx_n_s_test_signal_ill;
  PyObject *__pyx_kp_u_test_signal_ill_line_514;
  PyObject *__pyx_n_s_test_signal_quit;
  PyObject *__pyx_kp_u_test_signal_quit_line_562;
  PyObject *__pyx_n_s_test_signal_segv;
  PyObject *__pyx_kp_u_test_signal_segv_line_482;
  PyObject *__pyx_n_s_test_stack_overflow;
  PyObject *__pyx_kp_u_test_stack_overflow_line_668;
  PyObject *__pyx_n_s_test_thread_sig_block;
  PyObject *__pyx_kp_u_test_thread_sig_block_line_1299;
  PyObject *__pyx_n_s_test_try_finally_raise;
  PyObject *__pyx_kp_u_test_try_finally_raise_line_843;
  PyObject *__pyx_n_s_test_try_finally_return;
  PyObject *__pyx_kp_u_test_try_finally_return_line_863;
  PyObject *__pyx_n_s_test_try_finally_signal;
  PyObject *__pyx_kp_u_test_try_finally_signal_line_822;
  PyObject *__pyx_n_s_unguarded_abort;
  PyObject *__pyx_kp_u_unguarded_abort_line_648;
  PyObject *__pyx_n_s_unguarded_dereference_null_point;
  PyObject *__pyx_kp_u_unguarded_dereference_null_point_2;
  PyObject *__pyx_n_s_unguarded_stack_overflow;
  PyObject *__pyx_kp_u_unguarded_stack_overflow_line_68;
  PyObject *__pyx_n_s_universal_newlines;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_x;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_42;
  PyObject *__pyx_int_500;
  PyObject *__pyx_int_228825662;
  PyObject *__pyx_tuple_;
  PyObject *__pyx_tuple__3;
  PyObject *__pyx_tuple__5;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__17;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__31;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__37;
  PyObject *__pyx_tuple__39;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__44;
  PyObject *__pyx_tuple__46;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__66;
  PyObject *__pyx_tuple__68;
  PyObject *__pyx_tuple__70;
  PyObject *__pyx_tuple__72;
  PyObject *__pyx_tuple__74;
  PyObject *__pyx_tuple__76;
  PyObject *__pyx_tuple__80;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__87;
  PyObject *__pyx_tuple__89;
  PyObject *__pyx_tuple__91;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_codeobj__7;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__105;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__111;
  PyObject *__pyx_codeobj__12;
  PyObject *__pyx_codeobj__14;
  PyObject *__pyx_codeobj__16;
  PyObject *__pyx_codeobj__18;
  PyObject *__pyx_codeobj__19;
  PyObject *__pyx_codeobj__21;
  PyObject *__pyx_codeobj__22;
  PyObject *__pyx_codeobj__24;
  PyObject *__pyx_codeobj__26;
  PyObject *__pyx_codeobj__28;
  PyObject *__pyx_codeobj__30;
  PyObject *__pyx_codeobj__32;
  PyObject *__pyx_codeobj__34;
  PyObject *__pyx_codeobj__36;
  PyObject *__pyx_codeobj__38;
  PyObject *__pyx_codeobj__40;
  PyObject *__pyx_codeobj__41;
  PyObject *__pyx_codeobj__43;
  PyObject *__pyx_codeobj__45;
  PyObject *__pyx_codeobj__47;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__60;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__62;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__64;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__67;
  PyObject *__pyx_codeobj__69;
  PyObject *__pyx_codeobj__71;
  PyObject *__pyx_codeobj__73;
  PyObject *__pyx_codeobj__75;
  PyObject *__pyx_codeobj__77;
  PyObject *__pyx_codeobj__78;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__82;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__86;
  PyObject *__pyx_codeobj__88;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__102;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__110;
  PyObject *__pyx_codeobj__112;
} __pyx_mstate;

#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_CLEAR(clear_module_state->__pyx_ptype_9cysignals_5tests_DeallocDebug);
  Py_CLEAR(clear_module_state->__pyx_type_9cysignals_5tests_DeallocDebug);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Are_we_currently_on_the_alterna);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseException);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Call_sig_check_1_million_times);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Call_sig_on_and_sig_off_1_milli);
  Py_CLEAR(clear_module_state->__pyx_n_s_DeallocDebug);
  Py_CLEAR(clear_module_state->__pyx_n_s_DeallocDebug___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_DeallocDebug___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Decorator_class_which_makes_a_f);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Everything_ok);
  Py_CLEAR(clear_module_state->__pyx_n_s_GO);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Goodbye);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Have_p_processes_each_sending_n);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_s_vs_0xda);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_No_current_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_P);
  Py_CLEAR(clear_module_state->__pyx_n_s_PIPE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Popen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Print_the_exception_which_is_cu);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Received);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Regression_test_for_https_githu);
  Py_CLEAR(clear_module_state->__pyx_n_s_RuntimeError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Send_an_interrupt_signal_SIGINT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Start_a_subprocess_set_up_some);
  Py_CLEAR(clear_module_state->__pyx_n_s_Success);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_Regression_test_for_https);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_This_test_should_result_i);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_10);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_11);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_12);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_13);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_14);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_15);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_16);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_17);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_18);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_19);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_20);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_21);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_22);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_23);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_24);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_25);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_26);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_27);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_28);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_29);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_6);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_8);
  Py_CLEAR(clear_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_9);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_signal_arriving_during_a);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Test_that_calling_sig_block_sig);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unexpected_zero_returned_from_si);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s__113);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_s__4);
  Py_CLEAR(clear_module_state->__pyx_n_s__6);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_argv);
  Py_CLEAR(clear_module_state->__pyx_n_s_atexit);
  Py_CLEAR(clear_module_state->__pyx_n_s_base_delay);
  Py_CLEAR(clear_module_state->__pyx_kp_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_command);
  Py_CLEAR(clear_module_state->__pyx_n_s_communicate);
  Py_CLEAR(clear_module_state->__pyx_n_s_cysignals_tests);
  Py_CLEAR(clear_module_state->__pyx_kp_s_dealloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_delay);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_err);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc);
  Py_CLEAR(clear_module_state->__pyx_n_s_executable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_failed_to_allocate_s_bytes);
  Py_CLEAR(clear_module_state->__pyx_kp_s_failed_to_allocate_s_s_bytes);
  Py_CLEAR(clear_module_state->__pyx_n_s_flush);
  Py_CLEAR(clear_module_state->__pyx_n_s_func);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_goodbye);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_interrupt_after_delay);
  Py_CLEAR(clear_module_state->__pyx_kp_u_interrupt_after_delay_line_154);
  Py_CLEAR(clear_module_state->__pyx_kp_u_interrupts);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_kp_u_mmap_failed_errno);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_ms_delay);
  Py_CLEAR(clear_module_state->__pyx_kp_u_munmap_failed_errno);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_on_stack);
  Py_CLEAR(clear_module_state->__pyx_kp_u_on_stack_line_182);
  Py_CLEAR(clear_module_state->__pyx_n_s_out);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_print_sig_occurred);
  Py_CLEAR(clear_module_state->__pyx_kp_u_print_sig_occurred_line_886);
  Py_CLEAR(clear_module_state->__pyx_n_s_ptr);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_DeallocDebug);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_return_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_return_exception___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_return_exception___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_debug_level);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_sig_check_bench);
  Py_CLEAR(clear_module_state->__pyx_kp_u_sig_check_bench_line_1193);
  Py_CLEAR(clear_module_state->__pyx_n_s_sig_on);
  Py_CLEAR(clear_module_state->__pyx_n_s_sig_on_bench);
  Py_CLEAR(clear_module_state->__pyx_kp_u_sig_on_bench_line_1177);
  Py_CLEAR(clear_module_state->__pyx_n_s_signals);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_kp_s_src_cysignals_tests_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_stderr);
  Py_CLEAR(clear_module_state->__pyx_n_s_stdout);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_subprocess);
  Py_CLEAR(clear_module_state->__pyx_n_s_subpython_err);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_t1);
  Py_CLEAR(clear_module_state->__pyx_n_s_t2);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_abort);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_abort_line_633);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_access_mmap_noreserve);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_access_mmap_noreserve_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_bad_str);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_bad_str_line_726);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_dereference_null_pointer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_dereference_null_pointer_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_graceful_exit);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_graceful_exit_line_1255);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_graceful_exit_locals_goodby);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_interrupt_bomb);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_interrupt_bomb_line_785);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_block);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_block_line_1067);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_block_nested);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_block_nested_line_1093);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_block_outside_sig_on);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_block_outside_sig_on_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_check);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_check_inside_sig_on);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_check_inside_sig_on_lin);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_check_line_316);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_check_no_except);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_check_no_except_line_46);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_error);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_error_line_390);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_occurred_dealloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_occurred_dealloc_in_gc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_occurred_dealloc_line_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_occurred_finally);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_occurred_finally_line_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_occurred_live_exception);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_occurred_live_exception_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_off);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_off_line_220);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_cython_after_delay);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_cython_after_delay_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_cython_except);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_cython_except_all);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_cython_except_all_li);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_cython_except_line_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_cython_line_267);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_inside_try);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_inside_try_line_768);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_line_232);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_on_no_except);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_on_no_except_line_409);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_retry);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_retry_and_signal);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_retry_and_signal_line_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_retry_line_351);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_str);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_str_line_247);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sig_str_no_except);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sig_str_no_except_line_438);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sighup);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_sighup_and_sigint);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sighup_and_sigint_line_1230);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_sighup_line_1212);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_abrt);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_abrt_line_530);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_bus);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_bus_line_546);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_during_malloc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_during_malloc_line_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_fpe);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_fpe_line_498);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_ill);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_ill_line_514);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_quit);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_quit_line_562);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_signal_segv);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_signal_segv_line_482);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_stack_overflow);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_stack_overflow_line_668);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_thread_sig_block);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_thread_sig_block_line_1299);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_try_finally_raise);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_try_finally_raise_line_843);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_try_finally_return);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_try_finally_return_line_863);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_try_finally_signal);
  Py_CLEAR(clear_module_state->__pyx_kp_u_test_try_finally_signal_line_822);
  Py_CLEAR(clear_module_state->__pyx_n_s_unguarded_abort);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unguarded_abort_line_648);
  Py_CLEAR(clear_module_state->__pyx_n_s_unguarded_dereference_null_point);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unguarded_dereference_null_point_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_unguarded_stack_overflow);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unguarded_stack_overflow_line_68);
  Py_CLEAR(clear_module_state->__pyx_n_s_universal_newlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_x);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_42);
  Py_CLEAR(clear_module_state->__pyx_int_500);
  Py_CLEAR(clear_module_state->__pyx_int_228825662);
  Py_CLEAR(clear_module_state->__pyx_tuple_);
  Py_CLEAR(clear_module_state->__pyx_tuple__3);
  Py_CLEAR(clear_module_state->__pyx_tuple__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__17);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__31);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__37);
  Py_CLEAR(clear_module_state->__pyx_tuple__39);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__44);
  Py_CLEAR(clear_module_state->__pyx_tuple__46);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__66);
  Py_CLEAR(clear_module_state->__pyx_tuple__68);
  Py_CLEAR(clear_module_state->__pyx_tuple__70);
  Py_CLEAR(clear_module_state->__pyx_tuple__72);
  Py_CLEAR(clear_module_state->__pyx_tuple__74);
  Py_CLEAR(clear_module_state->__pyx_tuple__76);
  Py_CLEAR(clear_module_state->__pyx_tuple__80);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__87);
  Py_CLEAR(clear_module_state->__pyx_tuple__89);
  Py_CLEAR(clear_module_state->__pyx_tuple__91);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_codeobj__7);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__105);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__111);
  Py_CLEAR(clear_module_state->__pyx_codeobj__12);
  Py_CLEAR(clear_module_state->__pyx_codeobj__14);
  Py_CLEAR(clear_module_state->__pyx_codeobj__16);
  Py_CLEAR(clear_module_state->__pyx_codeobj__18);
  Py_CLEAR(clear_module_state->__pyx_codeobj__19);
  Py_CLEAR(clear_module_state->__pyx_codeobj__21);
  Py_CLEAR(clear_module_state->__pyx_codeobj__22);
  Py_CLEAR(clear_module_state->__pyx_codeobj__24);
  Py_CLEAR(clear_module_state->__pyx_codeobj__26);
  Py_CLEAR(clear_module_state->__pyx_codeobj__28);
  Py_CLEAR(clear_module_state->__pyx_codeobj__30);
  Py_CLEAR(clear_module_state->__pyx_codeobj__32);
  Py_CLEAR(clear_module_state->__pyx_codeobj__34);
  Py_CLEAR(clear_module_state->__pyx_codeobj__36);
  Py_CLEAR(clear_module_state->__pyx_codeobj__38);
  Py_CLEAR(clear_module_state->__pyx_codeobj__40);
  Py_CLEAR(clear_module_state->__pyx_codeobj__41);
  Py_CLEAR(clear_module_state->__pyx_codeobj__43);
  Py_CLEAR(clear_module_state->__pyx_codeobj__45);
  Py_CLEAR(clear_module_state->__pyx_codeobj__47);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__60);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__62);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__64);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__67);
  Py_CLEAR(clear_module_state->__pyx_codeobj__69);
  Py_CLEAR(clear_module_state->__pyx_codeobj__71);
  Py_CLEAR(clear_module_state->__pyx_codeobj__73);
  Py_CLEAR(clear_module_state->__pyx_codeobj__75);
  Py_CLEAR(clear_module_state->__pyx_codeobj__77);
  Py_CLEAR(clear_module_state->__pyx_codeobj__78);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__82);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__86);
  Py_CLEAR(clear_module_state->__pyx_codeobj__88);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__110);
  Py_CLEAR(clear_module_state->__pyx_codeobj__112);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_VISIT(traverse_module_state->__pyx_ptype_9cysignals_5tests_DeallocDebug);
  Py_VISIT(traverse_module_state->__pyx_type_9cysignals_5tests_DeallocDebug);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Are_we_currently_on_the_alterna);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseException);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Call_sig_check_1_million_times);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Call_sig_on_and_sig_off_1_milli);
  Py_VISIT(traverse_module_state->__pyx_n_s_DeallocDebug);
  Py_VISIT(traverse_module_state->__pyx_n_s_DeallocDebug___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_DeallocDebug___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Decorator_class_which_makes_a_f);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Everything_ok);
  Py_VISIT(traverse_module_state->__pyx_n_s_GO);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Goodbye);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Have_p_processes_each_sending_n);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_s_vs_0xda);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_No_current_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_P);
  Py_VISIT(traverse_module_state->__pyx_n_s_PIPE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Popen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Print_the_exception_which_is_cu);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Received);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Regression_test_for_https_githu);
  Py_VISIT(traverse_module_state->__pyx_n_s_RuntimeError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Send_an_interrupt_signal_SIGINT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Start_a_subprocess_set_up_some);
  Py_VISIT(traverse_module_state->__pyx_n_s_Success);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_Regression_test_for_https);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_This_test_should_result_i);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_10);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_11);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_12);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_13);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_14);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_15);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_16);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_17);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_18);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_19);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_20);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_21);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_22);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_23);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_24);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_25);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_26);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_27);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_28);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_29);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_6);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_8);
  Py_VISIT(traverse_module_state->__pyx_kp_u_TESTS_from_cysignals_tests_impo_9);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_signal_arriving_during_a);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_a_try_finally_construct_fo_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Test_that_calling_sig_block_sig);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unexpected_zero_returned_from_si);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s__113);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_s__4);
  Py_VISIT(traverse_module_state->__pyx_n_s__6);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_argv);
  Py_VISIT(traverse_module_state->__pyx_n_s_atexit);
  Py_VISIT(traverse_module_state->__pyx_n_s_base_delay);
  Py_VISIT(traverse_module_state->__pyx_kp_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_command);
  Py_VISIT(traverse_module_state->__pyx_n_s_communicate);
  Py_VISIT(traverse_module_state->__pyx_n_s_cysignals_tests);
  Py_VISIT(traverse_module_state->__pyx_kp_s_dealloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_delay);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_err);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc);
  Py_VISIT(traverse_module_state->__pyx_n_s_executable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_failed_to_allocate_s_bytes);
  Py_VISIT(traverse_module_state->__pyx_kp_s_failed_to_allocate_s_s_bytes);
  Py_VISIT(traverse_module_state->__pyx_n_s_flush);
  Py_VISIT(traverse_module_state->__pyx_n_s_func);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_goodbye);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_interrupt_after_delay);
  Py_VISIT(traverse_module_state->__pyx_kp_u_interrupt_after_delay_line_154);
  Py_VISIT(traverse_module_state->__pyx_kp_u_interrupts);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_kp_u_mmap_failed_errno);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_ms_delay);
  Py_VISIT(traverse_module_state->__pyx_kp_u_munmap_failed_errno);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_on_stack);
  Py_VISIT(traverse_module_state->__pyx_kp_u_on_stack_line_182);
  Py_VISIT(traverse_module_state->__pyx_n_s_out);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_print_sig_occurred);
  Py_VISIT(traverse_module_state->__pyx_kp_u_print_sig_occurred_line_886);
  Py_VISIT(traverse_module_state->__pyx_n_s_ptr);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_DeallocDebug);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_return_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_return_exception___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_return_exception___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_debug_level);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_sig_check_bench);
  Py_VISIT(traverse_module_state->__pyx_kp_u_sig_check_bench_line_1193);
  Py_VISIT(traverse_module_state->__pyx_n_s_sig_on);
  Py_VISIT(traverse_module_state->__pyx_n_s_sig_on_bench);
  Py_VISIT(traverse_module_state->__pyx_kp_u_sig_on_bench_line_1177);
  Py_VISIT(traverse_module_state->__pyx_n_s_signals);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_kp_s_src_cysignals_tests_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_stderr);
  Py_VISIT(traverse_module_state->__pyx_n_s_stdout);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_subprocess);
  Py_VISIT(traverse_module_state->__pyx_n_s_subpython_err);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_t1);
  Py_VISIT(traverse_module_state->__pyx_n_s_t2);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_abort);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_abort_line_633);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_access_mmap_noreserve);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_access_mmap_noreserve_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_bad_str);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_bad_str_line_726);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_dereference_null_pointer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_dereference_null_pointer_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_graceful_exit);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_graceful_exit_line_1255);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_graceful_exit_locals_goodby);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_interrupt_bomb);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_interrupt_bomb_line_785);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_block);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_block_line_1067);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_block_nested);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_block_nested_line_1093);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_block_outside_sig_on);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_block_outside_sig_on_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_check);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_check_inside_sig_on);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_check_inside_sig_on_lin);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_check_line_316);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_check_no_except);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_check_no_except_line_46);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_error);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_error_line_390);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_occurred_dealloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_occurred_dealloc_in_gc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_occurred_dealloc_line_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_occurred_finally);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_occurred_finally_line_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_occurred_live_exception);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_occurred_live_exception_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_off);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_off_line_220);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_cython_after_delay);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_cython_after_delay_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_cython_except);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_cython_except_all);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_cython_except_all_li);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_cython_except_line_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_cython_line_267);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_inside_try);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_inside_try_line_768);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_line_232);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_on_no_except);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_on_no_except_line_409);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_retry);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_retry_and_signal);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_retry_and_signal_line_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_retry_line_351);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_str);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_str_line_247);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sig_str_no_except);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sig_str_no_except_line_438);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sighup);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_sighup_and_sigint);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sighup_and_sigint_line_1230);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_sighup_line_1212);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_abrt);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_abrt_line_530);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_bus);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_bus_line_546);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_during_malloc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_during_malloc_line_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_fpe);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_fpe_line_498);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_ill);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_ill_line_514);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_quit);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_quit_line_562);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_signal_segv);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_signal_segv_line_482);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_stack_overflow);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_stack_overflow_line_668);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_thread_sig_block);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_thread_sig_block_line_1299);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_try_finally_raise);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_try_finally_raise_line_843);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_try_finally_return);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_try_finally_return_line_863);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_try_finally_signal);
  Py_VISIT(traverse_module_state->__pyx_kp_u_test_try_finally_signal_line_822);
  Py_VISIT(traverse_module_state->__pyx_n_s_unguarded_abort);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unguarded_abort_line_648);
  Py_VISIT(traverse_module_state->__pyx_n_s_unguarded_dereference_null_point);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unguarded_dereference_null_point_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_unguarded_stack_overflow);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unguarded_stack_overflow_line_68);
  Py_VISIT(traverse_module_state->__pyx_n_s_universal_newlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_x);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_42);
  Py_VISIT(traverse_module_state->__pyx_int_500);
  Py_VISIT(traverse_module_state->__pyx_int_228825662);
  Py_VISIT(traverse_module_state->__pyx_tuple_);
  Py_VISIT(traverse_module_state->__pyx_tuple__3);
  Py_VISIT(traverse_module_state->__pyx_tuple__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__17);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__31);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__37);
  Py_VISIT(traverse_module_state->__pyx_tuple__39);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__44);
  Py_VISIT(traverse_module_state->__pyx_tuple__46);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__66);
  Py_VISIT(traverse_module_state->__pyx_tuple__68);
  Py_VISIT(traverse_module_state->__pyx_tuple__70);
  Py_VISIT(traverse_module_state->__pyx_tuple__72);
  Py_VISIT(traverse_module_state->__pyx_tuple__74);
  Py_VISIT(traverse_module_state->__pyx_tuple__76);
  Py_VISIT(traverse_module_state->__pyx_tuple__80);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__87);
  Py_VISIT(traverse_module_state->__pyx_tuple__89);
  Py_VISIT(traverse_module_state->__pyx_tuple__91);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_codeobj__7);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__105);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__111);
  Py_VISIT(traverse_module_state->__pyx_codeobj__12);
  Py_VISIT(traverse_module_state->__pyx_codeobj__14);
  Py_VISIT(traverse_module_state->__pyx_codeobj__16);
  Py_VISIT(traverse_module_state->__pyx_codeobj__18);
  Py_VISIT(traverse_module_state->__pyx_codeobj__19);
  Py_VISIT(traverse_module_state->__pyx_codeobj__21);
  Py_VISIT(traverse_module_state->__pyx_codeobj__22);
  Py_VISIT(traverse_module_state->__pyx_codeobj__24);
  Py_VISIT(traverse_module_state->__pyx_codeobj__26);
  Py_VISIT(traverse_module_state->__pyx_codeobj__28);
  Py_VISIT(traverse_module_state->__pyx_codeobj__30);
  Py_VISIT(traverse_module_state->__pyx_codeobj__32);
  Py_VISIT(traverse_module_state->__pyx_codeobj__34);
  Py_VISIT(traverse_module_state->__pyx_codeobj__36);
  Py_VISIT(traverse_module_state->__pyx_codeobj__38);
  Py_VISIT(traverse_module_state->__pyx_codeobj__40);
  Py_VISIT(traverse_module_state->__pyx_codeobj__41);
  Py_VISIT(traverse_module_state->__pyx_codeobj__43);
  Py_VISIT(traverse_module_state->__pyx_codeobj__45);
  Py_VISIT(traverse_module_state->__pyx_codeobj__47);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__60);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__62);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__64);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__67);
  Py_VISIT(traverse_module_state->__pyx_codeobj__69);
  Py_VISIT(traverse_module_state->__pyx_codeobj__71);
  Py_VISIT(traverse_module_state->__pyx_codeobj__73);
  Py_VISIT(traverse_module_state->__pyx_codeobj__75);
  Py_VISIT(traverse_module_state->__pyx_codeobj__77);
  Py_VISIT(traverse_module_state->__pyx_codeobj__78);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__82);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__86);
  Py_VISIT(traverse_module_state->__pyx_codeobj__88);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__110);
  Py_VISIT(traverse_module_state->__pyx_codeobj__112);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#if CYTHON_COMPILING_IN_LIMITED_API
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#define __pyx_ptype_7cpython_4bool_bool __pyx_mstate_global->__pyx_ptype_7cpython_4bool_bool
#define __pyx_ptype_7cpython_7complex_complex __pyx_mstate_global->__pyx_ptype_7cpython_7complex_complex
#define __pyx_ptype_9cysignals_5tests_DeallocDebug __pyx_mstate_global->__pyx_ptype_9cysignals_5tests_DeallocDebug
#define __pyx_type_9cysignals_5tests_DeallocDebug __pyx_mstate_global->__pyx_type_9cysignals_5tests_DeallocDebug
#define __pyx_kp_u_Are_we_currently_on_the_alterna __pyx_mstate_global->__pyx_kp_u_Are_we_currently_on_the_alterna
#define __pyx_n_s_BaseException __pyx_mstate_global->__pyx_n_s_BaseException
#define __pyx_kp_u_Call_sig_check_1_million_times __pyx_mstate_global->__pyx_kp_u_Call_sig_check_1_million_times
#define __pyx_kp_u_Call_sig_on_and_sig_off_1_milli __pyx_mstate_global->__pyx_kp_u_Call_sig_on_and_sig_off_1_milli
#define __pyx_n_s_DeallocDebug __pyx_mstate_global->__pyx_n_s_DeallocDebug
#define __pyx_n_s_DeallocDebug___reduce_cython __pyx_mstate_global->__pyx_n_s_DeallocDebug___reduce_cython
#define __pyx_n_s_DeallocDebug___setstate_cython __pyx_mstate_global->__pyx_n_s_DeallocDebug___setstate_cython
#define __pyx_kp_s_Decorator_class_which_makes_a_f __pyx_mstate_global->__pyx_kp_s_Decorator_class_which_makes_a_f
#define __pyx_kp_s_Everything_ok __pyx_mstate_global->__pyx_kp_s_Everything_ok
#define __pyx_n_s_GO __pyx_mstate_global->__pyx_n_s_GO
#define __pyx_kp_s_Goodbye __pyx_mstate_global->__pyx_kp_s_Goodbye
#define __pyx_kp_u_Have_p_processes_each_sending_n __pyx_mstate_global->__pyx_kp_u_Have_p_processes_each_sending_n
#define __pyx_kp_s_Incompatible_checksums_s_vs_0xda __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_s_vs_0xda
#define __pyx_n_s_KeyboardInterrupt __pyx_mstate_global->__pyx_n_s_KeyboardInterrupt
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_kp_s_No_current_exception __pyx_mstate_global->__pyx_kp_s_No_current_exception
#define __pyx_n_s_P __pyx_mstate_global->__pyx_n_s_P
#define __pyx_n_s_PIPE __pyx_mstate_global->__pyx_n_s_PIPE
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_Popen __pyx_mstate_global->__pyx_n_s_Popen
#define __pyx_kp_u_Print_the_exception_which_is_cu __pyx_mstate_global->__pyx_kp_u_Print_the_exception_which_is_cu
#define __pyx_kp_u_Received __pyx_mstate_global->__pyx_kp_u_Received
#define __pyx_kp_u_Regression_test_for_https_githu __pyx_mstate_global->__pyx_kp_u_Regression_test_for_https_githu
#define __pyx_n_s_RuntimeError __pyx_mstate_global->__pyx_n_s_RuntimeError
#define __pyx_kp_u_Send_an_interrupt_signal_SIGINT __pyx_mstate_global->__pyx_kp_u_Send_an_interrupt_signal_SIGINT
#define __pyx_kp_u_Start_a_subprocess_set_up_some __pyx_mstate_global->__pyx_kp_u_Start_a_subprocess_set_up_some
#define __pyx_n_s_Success __pyx_mstate_global->__pyx_n_s_Success
#define __pyx_kp_u_TESTS_Regression_test_for_https __pyx_mstate_global->__pyx_kp_u_TESTS_Regression_test_for_https
#define __pyx_kp_u_TESTS_This_test_should_result_i __pyx_mstate_global->__pyx_kp_u_TESTS_This_test_should_result_i
#define __pyx_kp_u_TESTS_We_run_Python_in_a_subpro __pyx_mstate_global->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro
#define __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2 __pyx_mstate_global->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2
#define __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3 __pyx_mstate_global->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3
#define __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4 __pyx_mstate_global->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4
#define __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5 __pyx_mstate_global->__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_10 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_10
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_11 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_11
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_12 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_12
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_13 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_13
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_14 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_14
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_15 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_15
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_16 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_16
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_17 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_17
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_18 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_18
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_19 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_19
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_2 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_2
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_20 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_20
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_21 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_21
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_22 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_22
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_23 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_23
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_24 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_24
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_25 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_25
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_26 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_26
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_27 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_27
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_28 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_28
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_29 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_29
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_3 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_3
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_4 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_4
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_5 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_5
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_6 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_6
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_7 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_7
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_8 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_8
#define __pyx_kp_u_TESTS_from_cysignals_tests_impo_9 __pyx_mstate_global->__pyx_kp_u_TESTS_from_cysignals_tests_impo_9
#define __pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri __pyx_mstate_global->__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri
#define __pyx_kp_u_Test_a_basic_SIGHUP_signal_whic __pyx_mstate_global->__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic
#define __pyx_kp_u_Test_a_signal_arriving_during_a __pyx_mstate_global->__pyx_kp_u_Test_a_signal_arriving_during_a
#define __pyx_kp_u_Test_a_try_finally_construct_fo __pyx_mstate_global->__pyx_kp_u_Test_a_try_finally_construct_fo
#define __pyx_kp_u_Test_a_try_finally_construct_fo_2 __pyx_mstate_global->__pyx_kp_u_Test_a_try_finally_construct_fo_2
#define __pyx_kp_u_Test_a_try_finally_construct_fo_3 __pyx_mstate_global->__pyx_kp_u_Test_a_try_finally_construct_fo_3
#define __pyx_kp_u_Test_that_calling_sig_block_sig __pyx_mstate_global->__pyx_kp_u_Test_that_calling_sig_block_sig
#define __pyx_kp_s_Unexpected_zero_returned_from_si __pyx_mstate_global->__pyx_kp_s_Unexpected_zero_returned_from_si
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s__113 __pyx_mstate_global->__pyx_n_s__113
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_s__4 __pyx_mstate_global->__pyx_kp_s__4
#define __pyx_n_s__6 __pyx_mstate_global->__pyx_n_s__6
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_argv __pyx_mstate_global->__pyx_n_s_argv
#define __pyx_n_s_atexit __pyx_mstate_global->__pyx_n_s_atexit
#define __pyx_n_s_base_delay __pyx_mstate_global->__pyx_n_s_base_delay
#define __pyx_kp_s_c __pyx_mstate_global->__pyx_kp_s_c
#define __pyx_n_s_call __pyx_mstate_global->__pyx_n_s_call
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_command __pyx_mstate_global->__pyx_n_s_command
#define __pyx_n_s_communicate __pyx_mstate_global->__pyx_n_s_communicate
#define __pyx_n_s_cysignals_tests __pyx_mstate_global->__pyx_n_s_cysignals_tests
#define __pyx_kp_s_dealloc __pyx_mstate_global->__pyx_kp_s_dealloc
#define __pyx_n_s_delay __pyx_mstate_global->__pyx_n_s_delay
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_n_s_e __pyx_mstate_global->__pyx_n_s_e
#define __pyx_n_s_err __pyx_mstate_global->__pyx_n_s_err
#define __pyx_n_s_exc __pyx_mstate_global->__pyx_n_s_exc
#define __pyx_n_s_executable __pyx_mstate_global->__pyx_n_s_executable
#define __pyx_kp_s_failed_to_allocate_s_bytes __pyx_mstate_global->__pyx_kp_s_failed_to_allocate_s_bytes
#define __pyx_kp_s_failed_to_allocate_s_s_bytes __pyx_mstate_global->__pyx_kp_s_failed_to_allocate_s_s_bytes
#define __pyx_n_s_flush __pyx_mstate_global->__pyx_n_s_flush
#define __pyx_n_s_func __pyx_mstate_global->__pyx_n_s_func
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_goodbye __pyx_mstate_global->__pyx_n_s_goodbye
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_interrupt_after_delay __pyx_mstate_global->__pyx_n_s_interrupt_after_delay
#define __pyx_kp_u_interrupt_after_delay_line_154 __pyx_mstate_global->__pyx_kp_u_interrupt_after_delay_line_154
#define __pyx_kp_u_interrupts __pyx_mstate_global->__pyx_kp_u_interrupts
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_kwds __pyx_mstate_global->__pyx_n_s_kwds
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_kp_u_mmap_failed_errno __pyx_mstate_global->__pyx_kp_u_mmap_failed_errno
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_ms_delay __pyx_mstate_global->__pyx_n_s_ms_delay
#define __pyx_kp_u_munmap_failed_errno __pyx_mstate_global->__pyx_kp_u_munmap_failed_errno
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_on_stack __pyx_mstate_global->__pyx_n_s_on_stack
#define __pyx_kp_u_on_stack_line_182 __pyx_mstate_global->__pyx_kp_u_on_stack_line_182
#define __pyx_n_s_out __pyx_mstate_global->__pyx_n_s_out
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_print_sig_occurred __pyx_mstate_global->__pyx_n_s_print_sig_occurred
#define __pyx_kp_u_print_sig_occurred_line_886 __pyx_mstate_global->__pyx_kp_u_print_sig_occurred_line_886
#define __pyx_n_s_ptr __pyx_mstate_global->__pyx_n_s_ptr
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_DeallocDebug __pyx_mstate_global->__pyx_n_s_pyx_unpickle_DeallocDebug
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_return_exception __pyx_mstate_global->__pyx_n_s_return_exception
#define __pyx_n_s_return_exception___call __pyx_mstate_global->__pyx_n_s_return_exception___call
#define __pyx_n_s_return_exception___init __pyx_mstate_global->__pyx_n_s_return_exception___init
#define __pyx_n_s_s __pyx_mstate_global->__pyx_n_s_s
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_s_set_debug_level __pyx_mstate_global->__pyx_n_s_set_debug_level
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_sig_check_bench __pyx_mstate_global->__pyx_n_s_sig_check_bench
#define __pyx_kp_u_sig_check_bench_line_1193 __pyx_mstate_global->__pyx_kp_u_sig_check_bench_line_1193
#define __pyx_n_s_sig_on __pyx_mstate_global->__pyx_n_s_sig_on
#define __pyx_n_s_sig_on_bench __pyx_mstate_global->__pyx_n_s_sig_on_bench
#define __pyx_kp_u_sig_on_bench_line_1177 __pyx_mstate_global->__pyx_kp_u_sig_on_bench_line_1177
#define __pyx_n_s_signals __pyx_mstate_global->__pyx_n_s_signals
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_kp_s_src_cysignals_tests_pyx __pyx_mstate_global->__pyx_kp_s_src_cysignals_tests_pyx
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_stderr __pyx_mstate_global->__pyx_n_s_stderr
#define __pyx_n_s_stdout __pyx_mstate_global->__pyx_n_s_stdout
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_subprocess __pyx_mstate_global->__pyx_n_s_subprocess
#define __pyx_n_s_subpython_err __pyx_mstate_global->__pyx_n_s_subpython_err
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_t __pyx_mstate_global->__pyx_n_s_t
#define __pyx_n_s_t1 __pyx_mstate_global->__pyx_n_s_t1
#define __pyx_n_s_t2 __pyx_mstate_global->__pyx_n_s_t2
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_test_abort __pyx_mstate_global->__pyx_n_s_test_abort
#define __pyx_kp_u_test_abort_line_633 __pyx_mstate_global->__pyx_kp_u_test_abort_line_633
#define __pyx_n_s_test_access_mmap_noreserve __pyx_mstate_global->__pyx_n_s_test_access_mmap_noreserve
#define __pyx_kp_u_test_access_mmap_noreserve_line __pyx_mstate_global->__pyx_kp_u_test_access_mmap_noreserve_line
#define __pyx_n_s_test_bad_str __pyx_mstate_global->__pyx_n_s_test_bad_str
#define __pyx_kp_u_test_bad_str_line_726 __pyx_mstate_global->__pyx_kp_u_test_bad_str_line_726
#define __pyx_n_s_test_dereference_null_pointer __pyx_mstate_global->__pyx_n_s_test_dereference_null_pointer
#define __pyx_kp_u_test_dereference_null_pointer_li __pyx_mstate_global->__pyx_kp_u_test_dereference_null_pointer_li
#define __pyx_n_s_test_graceful_exit __pyx_mstate_global->__pyx_n_s_test_graceful_exit
#define __pyx_kp_u_test_graceful_exit_line_1255 __pyx_mstate_global->__pyx_kp_u_test_graceful_exit_line_1255
#define __pyx_n_s_test_graceful_exit_locals_goodby __pyx_mstate_global->__pyx_n_s_test_graceful_exit_locals_goodby
#define __pyx_n_s_test_interrupt_bomb __pyx_mstate_global->__pyx_n_s_test_interrupt_bomb
#define __pyx_kp_u_test_interrupt_bomb_line_785 __pyx_mstate_global->__pyx_kp_u_test_interrupt_bomb_line_785
#define __pyx_n_s_test_sig_block __pyx_mstate_global->__pyx_n_s_test_sig_block
#define __pyx_kp_u_test_sig_block_line_1067 __pyx_mstate_global->__pyx_kp_u_test_sig_block_line_1067
#define __pyx_n_s_test_sig_block_nested __pyx_mstate_global->__pyx_n_s_test_sig_block_nested
#define __pyx_kp_u_test_sig_block_nested_line_1093 __pyx_mstate_global->__pyx_kp_u_test_sig_block_nested_line_1093
#define __pyx_n_s_test_sig_block_outside_sig_on __pyx_mstate_global->__pyx_n_s_test_sig_block_outside_sig_on
#define __pyx_kp_u_test_sig_block_outside_sig_on_li __pyx_mstate_global->__pyx_kp_u_test_sig_block_outside_sig_on_li
#define __pyx_n_s_test_sig_check __pyx_mstate_global->__pyx_n_s_test_sig_check
#define __pyx_n_s_test_sig_check_inside_sig_on __pyx_mstate_global->__pyx_n_s_test_sig_check_inside_sig_on
#define __pyx_kp_u_test_sig_check_inside_sig_on_lin __pyx_mstate_global->__pyx_kp_u_test_sig_check_inside_sig_on_lin
#define __pyx_kp_u_test_sig_check_line_316 __pyx_mstate_global->__pyx_kp_u_test_sig_check_line_316
#define __pyx_n_s_test_sig_check_no_except __pyx_mstate_global->__pyx_n_s_test_sig_check_no_except
#define __pyx_kp_u_test_sig_check_no_except_line_46 __pyx_mstate_global->__pyx_kp_u_test_sig_check_no_except_line_46
#define __pyx_n_s_test_sig_error __pyx_mstate_global->__pyx_n_s_test_sig_error
#define __pyx_kp_u_test_sig_error_line_390 __pyx_mstate_global->__pyx_kp_u_test_sig_error_line_390
#define __pyx_n_s_test_sig_occurred_dealloc __pyx_mstate_global->__pyx_n_s_test_sig_occurred_dealloc
#define __pyx_n_s_test_sig_occurred_dealloc_in_gc __pyx_mstate_global->__pyx_n_s_test_sig_occurred_dealloc_in_gc
#define __pyx_kp_u_test_sig_occurred_dealloc_in_gc_2 __pyx_mstate_global->__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2
#define __pyx_kp_u_test_sig_occurred_dealloc_line_9 __pyx_mstate_global->__pyx_kp_u_test_sig_occurred_dealloc_line_9
#define __pyx_n_s_test_sig_occurred_finally __pyx_mstate_global->__pyx_n_s_test_sig_occurred_finally
#define __pyx_kp_u_test_sig_occurred_finally_line_9 __pyx_mstate_global->__pyx_kp_u_test_sig_occurred_finally_line_9
#define __pyx_n_s_test_sig_occurred_live_exception __pyx_mstate_global->__pyx_n_s_test_sig_occurred_live_exception
#define __pyx_kp_u_test_sig_occurred_live_exception_2 __pyx_mstate_global->__pyx_kp_u_test_sig_occurred_live_exception_2
#define __pyx_n_s_test_sig_off __pyx_mstate_global->__pyx_n_s_test_sig_off
#define __pyx_kp_u_test_sig_off_line_220 __pyx_mstate_global->__pyx_kp_u_test_sig_off_line_220
#define __pyx_n_s_test_sig_on __pyx_mstate_global->__pyx_n_s_test_sig_on
#define __pyx_n_s_test_sig_on_cython __pyx_mstate_global->__pyx_n_s_test_sig_on_cython
#define __pyx_n_s_test_sig_on_cython_after_delay __pyx_mstate_global->__pyx_n_s_test_sig_on_cython_after_delay
#define __pyx_kp_u_test_sig_on_cython_after_delay_l __pyx_mstate_global->__pyx_kp_u_test_sig_on_cython_after_delay_l
#define __pyx_n_s_test_sig_on_cython_except __pyx_mstate_global->__pyx_n_s_test_sig_on_cython_except
#define __pyx_n_s_test_sig_on_cython_except_all __pyx_mstate_global->__pyx_n_s_test_sig_on_cython_except_all
#define __pyx_kp_u_test_sig_on_cython_except_all_li __pyx_mstate_global->__pyx_kp_u_test_sig_on_cython_except_all_li
#define __pyx_kp_u_test_sig_on_cython_except_line_2 __pyx_mstate_global->__pyx_kp_u_test_sig_on_cython_except_line_2
#define __pyx_kp_u_test_sig_on_cython_line_267 __pyx_mstate_global->__pyx_kp_u_test_sig_on_cython_line_267
#define __pyx_n_s_test_sig_on_inside_try __pyx_mstate_global->__pyx_n_s_test_sig_on_inside_try
#define __pyx_kp_u_test_sig_on_inside_try_line_768 __pyx_mstate_global->__pyx_kp_u_test_sig_on_inside_try_line_768
#define __pyx_kp_u_test_sig_on_line_232 __pyx_mstate_global->__pyx_kp_u_test_sig_on_line_232
#define __pyx_n_s_test_sig_on_no_except __pyx_mstate_global->__pyx_n_s_test_sig_on_no_except
#define __pyx_kp_u_test_sig_on_no_except_line_409 __pyx_mstate_global->__pyx_kp_u_test_sig_on_no_except_line_409
#define __pyx_n_s_test_sig_retry __pyx_mstate_global->__pyx_n_s_test_sig_retry
#define __pyx_n_s_test_sig_retry_and_signal __pyx_mstate_global->__pyx_n_s_test_sig_retry_and_signal
#define __pyx_kp_u_test_sig_retry_and_signal_line_3 __pyx_mstate_global->__pyx_kp_u_test_sig_retry_and_signal_line_3
#define __pyx_kp_u_test_sig_retry_line_351 __pyx_mstate_global->__pyx_kp_u_test_sig_retry_line_351
#define __pyx_n_s_test_sig_str __pyx_mstate_global->__pyx_n_s_test_sig_str
#define __pyx_kp_u_test_sig_str_line_247 __pyx_mstate_global->__pyx_kp_u_test_sig_str_line_247
#define __pyx_n_s_test_sig_str_no_except __pyx_mstate_global->__pyx_n_s_test_sig_str_no_except
#define __pyx_kp_u_test_sig_str_no_except_line_438 __pyx_mstate_global->__pyx_kp_u_test_sig_str_no_except_line_438
#define __pyx_n_s_test_sighup __pyx_mstate_global->__pyx_n_s_test_sighup
#define __pyx_n_s_test_sighup_and_sigint __pyx_mstate_global->__pyx_n_s_test_sighup_and_sigint
#define __pyx_kp_u_test_sighup_and_sigint_line_1230 __pyx_mstate_global->__pyx_kp_u_test_sighup_and_sigint_line_1230
#define __pyx_kp_u_test_sighup_line_1212 __pyx_mstate_global->__pyx_kp_u_test_sighup_line_1212
#define __pyx_n_s_test_signal_abrt __pyx_mstate_global->__pyx_n_s_test_signal_abrt
#define __pyx_kp_u_test_signal_abrt_line_530 __pyx_mstate_global->__pyx_kp_u_test_signal_abrt_line_530
#define __pyx_n_s_test_signal_bus __pyx_mstate_global->__pyx_n_s_test_signal_bus
#define __pyx_kp_u_test_signal_bus_line_546 __pyx_mstate_global->__pyx_kp_u_test_signal_bus_line_546
#define __pyx_n_s_test_signal_during_malloc __pyx_mstate_global->__pyx_n_s_test_signal_during_malloc
#define __pyx_kp_u_test_signal_during_malloc_line_1 __pyx_mstate_global->__pyx_kp_u_test_signal_during_malloc_line_1
#define __pyx_n_s_test_signal_fpe __pyx_mstate_global->__pyx_n_s_test_signal_fpe
#define __pyx_kp_u_test_signal_fpe_line_498 __pyx_mstate_global->__pyx_kp_u_test_signal_fpe_line_498
#define __pyx_n_s_test_signal_ill __pyx_mstate_global->__pyx_n_s_test_signal_ill
#define __pyx_kp_u_test_signal_ill_line_514 __pyx_mstate_global->__pyx_kp_u_test_signal_ill_line_514
#define __pyx_n_s_test_signal_quit __pyx_mstate_global->__pyx_n_s_test_signal_quit
#define __pyx_kp_u_test_signal_quit_line_562 __pyx_mstate_global->__pyx_kp_u_test_signal_quit_line_562
#define __pyx_n_s_test_signal_segv __pyx_mstate_global->__pyx_n_s_test_signal_segv
#define __pyx_kp_u_test_signal_segv_line_482 __pyx_mstate_global->__pyx_kp_u_test_signal_segv_line_482
#define __pyx_n_s_test_stack_overflow __pyx_mstate_global->__pyx_n_s_test_stack_overflow
#define __pyx_kp_u_test_stack_overflow_line_668 __pyx_mstate_global->__pyx_kp_u_test_stack_overflow_line_668
#define __pyx_n_s_test_thread_sig_block __pyx_mstate_global->__pyx_n_s_test_thread_sig_block
#define __pyx_kp_u_test_thread_sig_block_line_1299 __pyx_mstate_global->__pyx_kp_u_test_thread_sig_block_line_1299
#define __pyx_n_s_test_try_finally_raise __pyx_mstate_global->__pyx_n_s_test_try_finally_raise
#define __pyx_kp_u_test_try_finally_raise_line_843 __pyx_mstate_global->__pyx_kp_u_test_try_finally_raise_line_843
#define __pyx_n_s_test_try_finally_return __pyx_mstate_global->__pyx_n_s_test_try_finally_return
#define __pyx_kp_u_test_try_finally_return_line_863 __pyx_mstate_global->__pyx_kp_u_test_try_finally_return_line_863
#define __pyx_n_s_test_try_finally_signal __pyx_mstate_global->__pyx_n_s_test_try_finally_signal
#define __pyx_kp_u_test_try_finally_signal_line_822 __pyx_mstate_global->__pyx_kp_u_test_try_finally_signal_line_822
#define __pyx_n_s_unguarded_abort __pyx_mstate_global->__pyx_n_s_unguarded_abort
#define __pyx_kp_u_unguarded_abort_line_648 __pyx_mstate_global->__pyx_kp_u_unguarded_abort_line_648
#define __pyx_n_s_unguarded_dereference_null_point __pyx_mstate_global->__pyx_n_s_unguarded_dereference_null_point
#define __pyx_kp_u_unguarded_dereference_null_point_2 __pyx_mstate_global->__pyx_kp_u_unguarded_dereference_null_point_2
#define __pyx_n_s_unguarded_stack_overflow __pyx_mstate_global->__pyx_n_s_unguarded_stack_overflow
#define __pyx_kp_u_unguarded_stack_overflow_line_68 __pyx_mstate_global->__pyx_kp_u_unguarded_stack_overflow_line_68
#define __pyx_n_s_universal_newlines __pyx_mstate_global->__pyx_n_s_universal_newlines
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_x __pyx_mstate_global->__pyx_n_s_x
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_42 __pyx_mstate_global->__pyx_int_42
#define __pyx_int_500 __pyx_mstate_global->__pyx_int_500
#define __pyx_int_228825662 __pyx_mstate_global->__pyx_int_228825662
#define __pyx_tuple_ __pyx_mstate_global->__pyx_tuple_
#define __pyx_tuple__3 __pyx_mstate_global->__pyx_tuple__3
#define __pyx_tuple__5 __pyx_mstate_global->__pyx_tuple__5
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__17 __pyx_mstate_global->__pyx_tuple__17
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__31 __pyx_mstate_global->__pyx_tuple__31
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__37 __pyx_mstate_global->__pyx_tuple__37
#define __pyx_tuple__39 __pyx_mstate_global->__pyx_tuple__39
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__44 __pyx_mstate_global->__pyx_tuple__44
#define __pyx_tuple__46 __pyx_mstate_global->__pyx_tuple__46
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__66 __pyx_mstate_global->__pyx_tuple__66
#define __pyx_tuple__68 __pyx_mstate_global->__pyx_tuple__68
#define __pyx_tuple__70 __pyx_mstate_global->__pyx_tuple__70
#define __pyx_tuple__72 __pyx_mstate_global->__pyx_tuple__72
#define __pyx_tuple__74 __pyx_mstate_global->__pyx_tuple__74
#define __pyx_tuple__76 __pyx_mstate_global->__pyx_tuple__76
#define __pyx_tuple__80 __pyx_mstate_global->__pyx_tuple__80
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__87 __pyx_mstate_global->__pyx_tuple__87
#define __pyx_tuple__89 __pyx_mstate_global->__pyx_tuple__89
#define __pyx_tuple__91 __pyx_mstate_global->__pyx_tuple__91
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_codeobj__7 __pyx_mstate_global->__pyx_codeobj__7
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__105 __pyx_mstate_global->__pyx_tuple__105
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__111 __pyx_mstate_global->__pyx_tuple__111
#define __pyx_codeobj__12 __pyx_mstate_global->__pyx_codeobj__12
#define __pyx_codeobj__14 __pyx_mstate_global->__pyx_codeobj__14
#define __pyx_codeobj__16 __pyx_mstate_global->__pyx_codeobj__16
#define __pyx_codeobj__18 __pyx_mstate_global->__pyx_codeobj__18
#define __pyx_codeobj__19 __pyx_mstate_global->__pyx_codeobj__19
#define __pyx_codeobj__21 __pyx_mstate_global->__pyx_codeobj__21
#define __pyx_codeobj__22 __pyx_mstate_global->__pyx_codeobj__22
#define __pyx_codeobj__24 __pyx_mstate_global->__pyx_codeobj__24
#define __pyx_codeobj__26 __pyx_mstate_global->__pyx_codeobj__26
#define __pyx_codeobj__28 __pyx_mstate_global->__pyx_codeobj__28
#define __pyx_codeobj__30 __pyx_mstate_global->__pyx_codeobj__30
#define __pyx_codeobj__32 __pyx_mstate_global->__pyx_codeobj__32
#define __pyx_codeobj__34 __pyx_mstate_global->__pyx_codeobj__34
#define __pyx_codeobj__36 __pyx_mstate_global->__pyx_codeobj__36
#define __pyx_codeobj__38 __pyx_mstate_global->__pyx_codeobj__38
#define __pyx_codeobj__40 __pyx_mstate_global->__pyx_codeobj__40
#define __pyx_codeobj__41 __pyx_mstate_global->__pyx_codeobj__41
#define __pyx_codeobj__43 __pyx_mstate_global->__pyx_codeobj__43
#define __pyx_codeobj__45 __pyx_mstate_global->__pyx_codeobj__45
#define __pyx_codeobj__47 __pyx_mstate_global->__pyx_codeobj__47
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__60 __pyx_mstate_global->__pyx_codeobj__60
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__62 __pyx_mstate_global->__pyx_codeobj__62
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__64 __pyx_mstate_global->__pyx_codeobj__64
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__67 __pyx_mstate_global->__pyx_codeobj__67
#define __pyx_codeobj__69 __pyx_mstate_global->__pyx_codeobj__69
#define __pyx_codeobj__71 __pyx_mstate_global->__pyx_codeobj__71
#define __pyx_codeobj__73 __pyx_mstate_global->__pyx_codeobj__73
#define __pyx_codeobj__75 __pyx_mstate_global->__pyx_codeobj__75
#define __pyx_codeobj__77 __pyx_mstate_global->__pyx_codeobj__77
#define __pyx_codeobj__78 __pyx_mstate_global->__pyx_codeobj__78
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__82 __pyx_mstate_global->__pyx_codeobj__82
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__86 __pyx_mstate_global->__pyx_codeobj__86
#define __pyx_codeobj__88 __pyx_mstate_global->__pyx_codeobj__88
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__102 __pyx_mstate_global->__pyx_codeobj__102
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__110 __pyx_mstate_global->__pyx_codeobj__110
#define __pyx_codeobj__112 __pyx_mstate_global->__pyx_codeobj__112
#endif
/* #### Code section: module_code ### */

/* "cysignals/tests.pyx":94
 * # C helper functions                                                   #
 * ########################################################################
 * cdef void infinite_loop() nogil:             # <<<<<<<<<<<<<<
 *     # Ensure that the compiler cannot "optimize away" this infinite
 *     # loop, see https://bugs.llvm.org/show_bug.cgi?id=965
 */

static void __pyx_f_9cysignals_5tests_infinite_loop(void) {
  volatile int __pyx_v_x;
  int __pyx_t_1;

  /* "cysignals/tests.pyx":97
 *     # Ensure that the compiler cannot "optimize away" this infinite
 *     # loop, see https://bugs.llvm.org/show_bug.cgi?id=965
 *     cdef volatile_int x = 0             # <<<<<<<<<<<<<<
 *     while x == 0:
 *         pass
 */
  __pyx_v_x = 0;

  /* "cysignals/tests.pyx":98
 *     # loop, see https://bugs.llvm.org/show_bug.cgi?id=965
 *     cdef volatile_int x = 0
 *     while x == 0:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_x == 0) != 0);
    if (!__pyx_t_1) break;
  }

  /* "cysignals/tests.pyx":94
 * # C helper functions                                                   #
 * ########################################################################
 * cdef void infinite_loop() nogil:             # <<<<<<<<<<<<<<
 *     # Ensure that the compiler cannot "optimize away" this infinite
 *     # loop, see https://bugs.llvm.org/show_bug.cgi?id=965
 */

  /* function exit code */
}

/* "cysignals/tests.pyx":101
 *         pass
 * 
 * cdef void infinite_malloc_loop() nogil:             # <<<<<<<<<<<<<<
 *     cdef size_t s = 1
 *     while True:
 */

static void __pyx_f_9cysignals_5tests_infinite_malloc_loop(void) {
  size_t __pyx_v_s;
  int __pyx_t_1;

  /* "cysignals/tests.pyx":102
 * 
 * cdef void infinite_malloc_loop() nogil:
 *     cdef size_t s = 1             # <<<<<<<<<<<<<<
 *     while True:
 *         sig_free(sig_malloc(s))
 */
  __pyx_v_s = 1;

  /* "cysignals/tests.pyx":103
 * cdef void infinite_malloc_loop() nogil:
 *     cdef size_t s = 1
 *     while True:             # <<<<<<<<<<<<<<
 *         sig_free(sig_malloc(s))
 *         s *= 2
 */
  while (1) {

    /* "cysignals/tests.pyx":104
 *     cdef size_t s = 1
 *     while True:
 *         sig_free(sig_malloc(s))             # <<<<<<<<<<<<<<
 *         s *= 2
 *         if (s > 1000000): s = 1
 */
    sig_free(sig_malloc(__pyx_v_s));

    /* "cysignals/tests.pyx":105
 *     while True:
 *         sig_free(sig_malloc(s))
 *         s *= 2             # <<<<<<<<<<<<<<
 *         if (s > 1000000): s = 1
 * 
 */
    __pyx_v_s = (__pyx_v_s * 2);

    /* "cysignals/tests.pyx":106
 *         sig_free(sig_malloc(s))
 *         s *= 2
 *         if (s > 1000000): s = 1             # <<<<<<<<<<<<<<
 * 
 * # Dereference a NULL pointer on purpose. This signals a SIGSEGV on most
 */
    __pyx_t_1 = ((__pyx_v_s > 0xF4240) != 0);
    if (__pyx_t_1) {
      __pyx_v_s = 1;
    }
  }

  /* "cysignals/tests.pyx":101
 *         pass
 * 
 * cdef void infinite_malloc_loop() nogil:             # <<<<<<<<<<<<<<
 *     cdef size_t s = 1
 *     while True:
 */

  /* function exit code */
}

/* "cysignals/tests.pyx":111
 * # systems, but on older Mac OS X and possibly other systems, this
 * # signals a SIGBUS instead. In any case, this should give some signal.
 * cdef void dereference_null_pointer() nogil:             # <<<<<<<<<<<<<<
 *     cdef volatile_int* ptr = <volatile_int*>(0)
 *     ptr[0] += 1
 */

static void __pyx_f_9cysignals_5tests_dereference_null_pointer(void) {
  volatile int *__pyx_v_ptr;
  long __pyx_t_1;

  /* "cysignals/tests.pyx":112
 * # signals a SIGBUS instead. In any case, this should give some signal.
 * cdef void dereference_null_pointer() nogil:
 *     cdef volatile_int* ptr = <volatile_int*>(0)             # <<<<<<<<<<<<<<
 *     ptr[0] += 1
 * 
 */
  __pyx_v_ptr = ((volatile int *)0);

  /* "cysignals/tests.pyx":113
 * cdef void dereference_null_pointer() nogil:
 *     cdef volatile_int* ptr = <volatile_int*>(0)
 *     ptr[0] += 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = 0;
  (__pyx_v_ptr[__pyx_t_1]) = ((__pyx_v_ptr[__pyx_t_1]) + 1);

  /* "cysignals/tests.pyx":111
 * # systems, but on older Mac OS X and possibly other systems, this
 * # signals a SIGBUS instead. In any case, this should give some signal.
 * cdef void dereference_null_pointer() nogil:             # <<<<<<<<<<<<<<
 *     cdef volatile_int* ptr = <volatile_int*>(0)
 *     ptr[0] += 1
 */

  /* function exit code */
}

/* "cysignals/tests.pyx":116
 * 
 * 
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:             # <<<<<<<<<<<<<<
 *     cdef volatile_int a = 0
 *     if x is not NULL:
 */

static int __pyx_f_9cysignals_5tests_stack_overflow(struct __pyx_opt_args_9cysignals_5tests_stack_overflow *__pyx_optional_args) {
  volatile int *__pyx_v_x = ((volatile int *)NULL);
  volatile int __pyx_v_a;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  struct __pyx_opt_args_9cysignals_5tests_stack_overflow __pyx_t_3;
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_x = __pyx_optional_args->x;
    }
  }

  /* "cysignals/tests.pyx":117
 * 
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:
 *     cdef volatile_int a = 0             # <<<<<<<<<<<<<<
 *     if x is not NULL:
 *         a = x[0]
 */
  __pyx_v_a = 0;

  /* "cysignals/tests.pyx":118
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:
 *     cdef volatile_int a = 0
 *     if x is not NULL:             # <<<<<<<<<<<<<<
 *         a = x[0]
 *     a += stack_overflow(&a)
 */
  __pyx_t_1 = ((__pyx_v_x != NULL) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":119
 *     cdef volatile_int a = 0
 *     if x is not NULL:
 *         a = x[0]             # <<<<<<<<<<<<<<
 *     a += stack_overflow(&a)
 *     a += stack_overflow(&a)
 */
    __pyx_v_a = (__pyx_v_x[0]);

    /* "cysignals/tests.pyx":118
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:
 *     cdef volatile_int a = 0
 *     if x is not NULL:             # <<<<<<<<<<<<<<
 *         a = x[0]
 *     a += stack_overflow(&a)
 */
  }

  /* "cysignals/tests.pyx":120
 *     if x is not NULL:
 *         a = x[0]
 *     a += stack_overflow(&a)             # <<<<<<<<<<<<<<
 *     a += stack_overflow(&a)
 *     return a
 */
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.x = (&__pyx_v_a);
  __pyx_t_2 = __pyx_f_9cysignals_5tests_stack_overflow(&__pyx_t_3); 
  __pyx_v_a = (__pyx_v_a + __pyx_t_2);

  /* "cysignals/tests.pyx":121
 *         a = x[0]
 *     a += stack_overflow(&a)
 *     a += stack_overflow(&a)             # <<<<<<<<<<<<<<
 *     return a
 * 
 */
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.x = (&__pyx_v_a);
  __pyx_t_2 = __pyx_f_9cysignals_5tests_stack_overflow(&__pyx_t_3); 
  __pyx_v_a = (__pyx_v_a + __pyx_t_2);

  /* "cysignals/tests.pyx":122
 *     a += stack_overflow(&a)
 *     a += stack_overflow(&a)
 *     return a             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_a;
  goto __pyx_L0;

  /* "cysignals/tests.pyx":116
 * 
 * 
 * cdef int stack_overflow(volatile_int* x=NULL) nogil:             # <<<<<<<<<<<<<<
 *     cdef volatile_int a = 0
 *     if x is not NULL:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cysignals/tests.pyx":144
 * 
 *     """
 *     def __init__ (self, func):             # <<<<<<<<<<<<<<
 *         self.func = func
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_16return_exception_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_16return_exception_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_16return_exception_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_16return_exception_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_func = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_func,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_func,0};
    #endif
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 144, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 144, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 144, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 144, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 144, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.return_exception.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_16return_exception___init__(__pyx_self, __pyx_v_self, __pyx_v_func);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_16return_exception___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_func) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cysignals/tests.pyx":145
 *     """
 *     def __init__ (self, func):
 *         self.func = func             # <<<<<<<<<<<<<<
 * 
 *     def __call__ (self, *args):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_func, __pyx_v_func) < 0) __PYX_ERR(0, 145, __pyx_L1_error)

  /* "cysignals/tests.pyx":144
 * 
 *     """
 *     def __init__ (self, func):             # <<<<<<<<<<<<<<
 *         self.func = func
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.return_exception.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":147
 *         self.func = func
 * 
 *     def __call__ (self, *args):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.func(*args)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_16return_exception_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_16return_exception_3__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_16return_exception_3__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_16return_exception_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    #endif
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 147, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "__call__") < 0)) __PYX_ERR(0, 147, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 147, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("cysignals.tests.return_exception.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_16return_exception_2__call__(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_16return_exception_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "cysignals/tests.pyx":148
 * 
 *     def __call__ (self, *args):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.func(*args)
 *         except BaseException as e:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":149
 *     def __call__ (self, *args):
 *         try:
 *             return self.func(*args)             # <<<<<<<<<<<<<<
 *         except BaseException as e:
 *             return e
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_func); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 149, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_v_args, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 149, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L7_try_return;

      /* "cysignals/tests.pyx":148
 * 
 *     def __call__ (self, *args):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.func(*args)
 *         except BaseException as e:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cysignals/tests.pyx":150
 *         try:
 *             return self.func(*args)
 *         except BaseException as e:             # <<<<<<<<<<<<<<
 *             return e
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cysignals.tests.return_exception.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 150, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_e = __pyx_t_4;
      /*try:*/ {

        /* "cysignals/tests.pyx":151
 *             return self.func(*args)
 *         except BaseException as e:
 *             return e             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_e);
        __pyx_r = __pyx_v_e;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L13_return;
      }

      /* "cysignals/tests.pyx":150
 *         try:
 *             return self.func(*args)
 *         except BaseException as e:             # <<<<<<<<<<<<<<
 *             return e
 * 
 */
      /*finally:*/ {
        __pyx_L13_return: {
          __pyx_t_8 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          __pyx_r = __pyx_t_8;
          __pyx_t_8 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":148
 * 
 *     def __call__ (self, *args):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.func(*args)
 *         except BaseException as e:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cysignals/tests.pyx":147
 *         self.func = func
 * 
 *     def __call__ (self, *args):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.func(*args)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cysignals.tests.return_exception.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":154
 * 
 * 
 * def interrupt_after_delay(ms_delay=500):             # <<<<<<<<<<<<<<
 *     """
 *     Send an interrupt signal (``SIGINT``) to the process after a delay of
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_1interrupt_after_delay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_interrupt_after_delay, "\n    Send an interrupt signal (``SIGINT``) to the process after a delay of\n    ``ms_delay`` milliseconds.\n\n    INPUT:\n\n        - ``ms_delay`` -- (default: 500) a nonnegative integer indicating how\n          many milliseconds to wait before raising the interrupt signal.\n\n    EXAMPLES:\n\n    This function is meant to test interrupt functionality.  We demonstrate here\n    how to test that an infinite loop can be interrupted::\n\n        >>> import cysignals.tests\n        >>> try:\n        ...     cysignals.tests.interrupt_after_delay()\n        ...     while True:\n        ...         pass\n        ... except KeyboardInterrupt:\n        ...     print(\"Caught KeyboardInterrupt\")\n        Caught KeyboardInterrupt\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_1interrupt_after_delay = {"interrupt_after_delay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_1interrupt_after_delay, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_interrupt_after_delay};
static PyObject *__pyx_pw_9cysignals_5tests_1interrupt_after_delay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ms_delay = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interrupt_after_delay (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ms_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ms_delay,0};
    #endif
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)((PyObject *)__pyx_int_500));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ms_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 154, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "interrupt_after_delay") < 0)) __PYX_ERR(0, 154, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_ms_delay = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("interrupt_after_delay", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 154, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.interrupt_after_delay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_interrupt_after_delay(__pyx_self, __pyx_v_ms_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_interrupt_after_delay(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_ms_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interrupt_after_delay", 0);

  /* "cysignals/tests.pyx":179
 * 
 *     """
 *     signal_after_delay(SIGINT, ms_delay)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_As_long(__pyx_v_ms_delay); if (unlikely((__pyx_t_1 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 179, __pyx_L1_error)
  signal_after_delay(SIGINT, __pyx_t_1);

  /* "cysignals/tests.pyx":154
 * 
 * 
 * def interrupt_after_delay(ms_delay=500):             # <<<<<<<<<<<<<<
 *     """
 *     Send an interrupt signal (``SIGINT``) to the process after a delay of
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.interrupt_after_delay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":182
 * 
 * 
 * def on_stack():             # <<<<<<<<<<<<<<
 *     """
 *     Are we currently on the alternate signal stack (see sigaltstack(2))?
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_3on_stack(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_2on_stack, "\n    Are we currently on the alternate signal stack (see sigaltstack(2))?\n\n    EXAMPLES::\n\n        >>> from cysignals.tests import on_stack\n        >>> on_stack()\n        False\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_3on_stack = {"on_stack", (PyCFunction)__pyx_pw_9cysignals_5tests_3on_stack, METH_NOARGS, __pyx_doc_9cysignals_5tests_2on_stack};
static PyObject *__pyx_pw_9cysignals_5tests_3on_stack(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("on_stack (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_2on_stack(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_2on_stack(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("on_stack", 0);

  /* "cysignals/tests.pyx":193
 * 
 *     """
 *     return on_alt_stack()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(on_alt_stack()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cysignals/tests.pyx":182
 * 
 * 
 * def on_stack():             # <<<<<<<<<<<<<<
 *     """
 *     Are we currently on the alternate signal stack (see sigaltstack(2))?
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cysignals.tests.on_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":196
 * 
 * 
 * def _sig_on():             # <<<<<<<<<<<<<<
 *     """
 *     A single ``sig_on()`` for doctesting purposes. This can never work
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_5_sig_on(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_4_sig_on, "\n    A single ``sig_on()`` for doctesting purposes. This can never work\n    for real code.\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_5_sig_on = {"_sig_on", (PyCFunction)__pyx_pw_9cysignals_5tests_5_sig_on, METH_NOARGS, __pyx_doc_9cysignals_5tests_4_sig_on};
static PyObject *__pyx_pw_9cysignals_5tests_5_sig_on(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_sig_on (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_4_sig_on(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_4_sig_on(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_sig_on", 0);

  /* "cysignals/tests.pyx":201
 *     for real code.
 *     """
 *     sig_on()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 201, __pyx_L1_error)

  /* "cysignals/tests.pyx":196
 * 
 * 
 * def _sig_on():             # <<<<<<<<<<<<<<
 *     """
 *     A single ``sig_on()`` for doctesting purposes. This can never work
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests._sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":204
 * 
 * 
 * def subpython_err(command, **kwds):             # <<<<<<<<<<<<<<
 *     """
 *     Run ``command`` in a Python subprocess and print the standard error
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_7subpython_err(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_6subpython_err, "\n    Run ``command`` in a Python subprocess and print the standard error\n    which was generated.\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_7subpython_err = {"subpython_err", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_7subpython_err, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_6subpython_err};
static PyObject *__pyx_pw_9cysignals_5tests_7subpython_err(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_command = 0;
  PyObject *__pyx_v_kwds = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subpython_err (wrapper)", 0);
  __pyx_v_kwds = PyDict_New(); if (unlikely(!__pyx_v_kwds)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwds);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_command,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_command,0};
    #endif
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_command)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwds, values + 0, kwd_pos_args, "subpython_err") < 0)) __PYX_ERR(0, 204, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_command = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("subpython_err", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 204, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_kwds); __pyx_v_kwds = 0;
  __Pyx_AddTraceback("cysignals.tests.subpython_err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_6subpython_err(__pyx_self, __pyx_v_command, __pyx_v_kwds);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwds);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_6subpython_err(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_command, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_v_argv = NULL;
  PyObject *__pyx_v_P = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subpython_err", 0);

  /* "cysignals/tests.pyx":209
 *     which was generated.
 *     """
 *     argv = [sys.executable, '-c', command]             # <<<<<<<<<<<<<<
 *     P = Popen(argv, stdout=PIPE, stderr=PIPE, universal_newlines=True, **kwds)
 *     (out, err) = P.communicate()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_executable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_kp_s_c);
  __Pyx_GIVEREF(__pyx_kp_s_c);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s_c);
  __Pyx_INCREF(__pyx_v_command);
  __Pyx_GIVEREF(__pyx_v_command);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_command);
  __pyx_t_2 = 0;
  __pyx_v_argv = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":210
 *     """
 *     argv = [sys.executable, '-c', command]
 *     P = Popen(argv, stdout=PIPE, stderr=PIPE, universal_newlines=True, **kwds)             # <<<<<<<<<<<<<<
 *     (out, err) = P.communicate()
 *     sys.stdout.write(err)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Popen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_argv);
  __Pyx_GIVEREF(__pyx_v_argv);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_argv);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PIPE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stdout, __pyx_t_5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PIPE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_stderr, __pyx_t_5) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_universal_newlines, Py_True) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_t_4 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwds) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_P = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cysignals/tests.pyx":211
 *     argv = [sys.executable, '-c', command]
 *     P = Popen(argv, stdout=PIPE, stderr=PIPE, universal_newlines=True, **kwds)
 *     (out, err) = P.communicate()             # <<<<<<<<<<<<<<
 *     sys.stdout.write(err)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_P, __pyx_n_s_communicate); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_2, };
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 211, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_3 = __pyx_t_7(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_1), 2) < 0) __PYX_ERR(0, 211, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 211, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_out = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_err = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":212
 *     P = Popen(argv, stdout=PIPE, stderr=PIPE, universal_newlines=True, **kwds)
 *     (out, err) = P.communicate()
 *     sys.stdout.write(err)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stdout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_err};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cysignals/tests.pyx":204
 * 
 * 
 * def subpython_err(command, **kwds):             # <<<<<<<<<<<<<<
 *     """
 *     Run ``command`` in a Python subprocess and print the standard error
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cysignals.tests.subpython_err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_argv);
  __Pyx_XDECREF(__pyx_v_P);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":220
 * # (if possible) within a "with nogil" block.                           #
 * ########################################################################
 * def test_sig_off():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_9test_sig_off(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_8test_sig_off, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_off()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_9test_sig_off = {"test_sig_off", (PyCFunction)__pyx_pw_9cysignals_5tests_9test_sig_off, METH_NOARGS, __pyx_doc_9cysignals_5tests_8test_sig_off};
static PyObject *__pyx_pw_9cysignals_5tests_9test_sig_off(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_off (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_8test_sig_off(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_8test_sig_off(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_off", 0);

  /* "cysignals/tests.pyx":228
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         sig_off()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":229
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         sig_off()
 * 
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 229, __pyx_L4_error)

        /* "cysignals/tests.pyx":230
 *     with nogil:
 *         sig_on()
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
        sig_off();
      }

      /* "cysignals/tests.pyx":228
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         sig_off()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":220
 * # (if possible) within a "with nogil" block.                           #
 * ########################################################################
 * def test_sig_off():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_off", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":232
 *         sig_off()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_108__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_11test_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_10test_sig_on, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_11test_sig_on = {"test_sig_on", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_11test_sig_on, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_10test_sig_on};
static PyObject *__pyx_pw_9cysignals_5tests_11test_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 232, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on") < 0)) __PYX_ERR(0, 232, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 233, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 232, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_10test_sig_on(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_10test_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on", 0);

  /* "cysignals/tests.pyx":242
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGINT, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":243
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 243, __pyx_L4_error)

        /* "cysignals/tests.pyx":244
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":245
 *         sig_on()
 *         signal_after_delay(SIGINT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_sig_str(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":242
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGINT, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":232
 *         sig_off()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":247
 *         infinite_loop()
 * 
 * def test_sig_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_110__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_13test_sig_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_12test_sig_str, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_str()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_13test_sig_str = {"test_sig_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_13test_sig_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_12test_sig_str};
static PyObject *__pyx_pw_9cysignals_5tests_13test_sig_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_str (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 247, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_str") < 0)) __PYX_ERR(0, 247, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 247, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_str", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 247, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_12test_sig_str(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_12test_sig_str(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_str", 0);

  /* "cysignals/tests.pyx":258
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_str("Everything ok!")
 *         signal_after_delay(SIGABRT, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":259
 *     """
 *     with nogil:
 *         sig_str("Everything ok!")             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_str(((char const *)"Everything ok!")); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 259, __pyx_L4_error)

        /* "cysignals/tests.pyx":260
 *     with nogil:
 *         sig_str("Everything ok!")
 *         signal_after_delay(SIGABRT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGABRT, __pyx_v_delay);

        /* "cysignals/tests.pyx":261
 *         sig_str("Everything ok!")
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * cdef c_test_sig_on_cython():
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":258
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_str("Everything ok!")
 *         signal_after_delay(SIGABRT, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":247
 *         infinite_loop()
 * 
 * def test_sig_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":263
 *         infinite_loop()
 * 
 * cdef c_test_sig_on_cython():             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

static PyObject *__pyx_f_9cysignals_5tests_c_test_sig_on_cython(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("c_test_sig_on_cython", 0);

  /* "cysignals/tests.pyx":264
 * 
 * cdef c_test_sig_on_cython():
 *     sig_on()             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 264, __pyx_L1_error)

  /* "cysignals/tests.pyx":265
 * cdef c_test_sig_on_cython():
 *     sig_on()
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":263
 *         infinite_loop()
 * 
 * cdef c_test_sig_on_cython():             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.c_test_sig_on_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":267
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_112__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_15test_sig_on_cython(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_14test_sig_on_cython, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_15test_sig_on_cython = {"test_sig_on_cython", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_15test_sig_on_cython, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_14test_sig_on_cython};
static PyObject *__pyx_pw_9cysignals_5tests_15test_sig_on_cython(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_cython (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults2 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 267, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_cython") < 0)) __PYX_ERR(0, 267, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 268, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_cython", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 267, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_14test_sig_on_cython(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_14test_sig_on_cython(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_cython", 0);

  /* "cysignals/tests.pyx":277
 * 
 *     """
 *     signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *     c_test_sig_on_cython()
 * 
 */
  signal_after_delay(SIGINT, __pyx_v_delay);

  /* "cysignals/tests.pyx":278
 *     """
 *     signal_after_delay(SIGINT, delay)
 *     c_test_sig_on_cython()             # <<<<<<<<<<<<<<
 * 
 * cdef int c_test_sig_on_cython_except() nogil except 42:
 */
  __pyx_t_1 = __pyx_f_9cysignals_5tests_c_test_sig_on_cython(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":267
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":280
 *     c_test_sig_on_cython()
 * 
 * cdef int c_test_sig_on_cython_except() nogil except 42:             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

static int __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except(void) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "cysignals/tests.pyx":281
 * 
 * cdef int c_test_sig_on_cython_except() nogil except 42:
 *     sig_on()             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 281, __pyx_L1_error)

  /* "cysignals/tests.pyx":282
 * cdef int c_test_sig_on_cython_except() nogil except 42:
 *     sig_on()
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":280
 *     c_test_sig_on_cython()
 * 
 * cdef int c_test_sig_on_cython_except() nogil except 42:             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("cysignals.tests.c_test_sig_on_cython_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 42;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "cysignals/tests.pyx":284
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_114__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_17test_sig_on_cython_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_16test_sig_on_cython_except, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_except()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_17test_sig_on_cython_except = {"test_sig_on_cython_except", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_17test_sig_on_cython_except, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_16test_sig_on_cython_except};
static PyObject *__pyx_pw_9cysignals_5tests_17test_sig_on_cython_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_cython_except (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults3 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 284, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_cython_except") < 0)) __PYX_ERR(0, 284, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 285, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_cython_except", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 284, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_16test_sig_on_cython_except(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_16test_sig_on_cython_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_cython_except", 0);

  /* "cysignals/tests.pyx":294
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":295
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         c_test_sig_on_cython_except()
 * 
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":296
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except()             # <<<<<<<<<<<<<<
 * 
 * cdef void c_test_sig_on_cython_except_all() nogil except *:
 */
        __pyx_t_1 = __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except(); if (unlikely(__pyx_t_1 == ((int)42))) __PYX_ERR(0, 296, __pyx_L4_error)
      }

      /* "cysignals/tests.pyx":294
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":284
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":298
 *         c_test_sig_on_cython_except()
 * 
 * cdef void c_test_sig_on_cython_except_all() nogil except *:             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

static void __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except_all(void) {
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "cysignals/tests.pyx":299
 * 
 * cdef void c_test_sig_on_cython_except_all() nogil except *:
 *     sig_on()             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 299, __pyx_L1_error)

  /* "cysignals/tests.pyx":300
 * cdef void c_test_sig_on_cython_except_all() nogil except *:
 *     sig_on()
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":298
 *         c_test_sig_on_cython_except()
 * 
 * cdef void c_test_sig_on_cython_except_all() nogil except *:             # <<<<<<<<<<<<<<
 *     sig_on()
 *     infinite_loop()
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("cysignals.tests.c_test_sig_on_cython_except_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
}

/* "cysignals/tests.pyx":302
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_116__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_19test_sig_on_cython_except_all(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_18test_sig_on_cython_except_all, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_except_all()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_19test_sig_on_cython_except_all = {"test_sig_on_cython_except_all", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_19test_sig_on_cython_except_all, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_18test_sig_on_cython_except_all};
static PyObject *__pyx_pw_9cysignals_5tests_19test_sig_on_cython_except_all(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_cython_except_all (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults4 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 302, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_cython_except_all") < 0)) __PYX_ERR(0, 302, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 303, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_cython_except_all", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 302, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_except_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_18test_sig_on_cython_except_all(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_18test_sig_on_cython_except_all(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_cython_except_all", 0);

  /* "cysignals/tests.pyx":312
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except_all()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":313
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         c_test_sig_on_cython_except_all()
 * 
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":314
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except_all()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
        __pyx_f_9cysignals_5tests_c_test_sig_on_cython_except_all(); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 314, __pyx_L4_error)
      }

      /* "cysignals/tests.pyx":312
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         c_test_sig_on_cython_except_all()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":302
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_except_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":316
 *         c_test_sig_on_cython_except_all()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_118__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_21test_sig_check(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_20test_sig_check, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_21test_sig_check = {"test_sig_check", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_21test_sig_check, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_20test_sig_check};
static PyObject *__pyx_pw_9cysignals_5tests_21test_sig_check(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_check (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults5 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 316, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_check") < 0)) __PYX_ERR(0, 316, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 317, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_check", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 316, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_20test_sig_check(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_20test_sig_check(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_check", 0);

  /* "cysignals/tests.pyx":326
 * 
 *     """
 *     signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *     while True:
 *         with nogil:
 */
  signal_after_delay(SIGINT, __pyx_v_delay);

  /* "cysignals/tests.pyx":327
 *     """
 *     signal_after_delay(SIGINT, delay)
 *     while True:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_check()
 */
  while (1) {

    /* "cysignals/tests.pyx":328
 *     signal_after_delay(SIGINT, delay)
 *     while True:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_check()
 * 
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "cysignals/tests.pyx":329
 *     while True:
 *         with nogil:
 *             sig_check()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
          __pyx_t_1 = sig_check(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 329, __pyx_L8_error)
        }

        /* "cysignals/tests.pyx":328
 *     signal_after_delay(SIGINT, delay)
 *     while True:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_check()
 * 
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L9;
          }
          __pyx_L8_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L9:;
        }
    }
  }

  /* "cysignals/tests.pyx":316
 *         c_test_sig_on_cython_except_all()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":331
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_120__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_23test_sig_check_inside_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_22test_sig_check_inside_sig_on, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check_inside_sig_on()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_23test_sig_check_inside_sig_on = {"test_sig_check_inside_sig_on", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_23test_sig_check_inside_sig_on, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_22test_sig_check_inside_sig_on};
static PyObject *__pyx_pw_9cysignals_5tests_23test_sig_check_inside_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_check_inside_sig_on (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults6 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 331, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_check_inside_sig_on") < 0)) __PYX_ERR(0, 331, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 332, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_check_inside_sig_on", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check_inside_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_22test_sig_check_inside_sig_on(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_22test_sig_check_inside_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_check_inside_sig_on", 0);

  /* "cysignals/tests.pyx":341
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         sig_on()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":342
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         sig_on()
 *         while True:
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":343
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)
 *         sig_on()             # <<<<<<<<<<<<<<
 *         while True:
 *             sig_check()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 343, __pyx_L4_error)

        /* "cysignals/tests.pyx":344
 *         signal_after_delay(SIGINT, delay)
 *         sig_on()
 *         while True:             # <<<<<<<<<<<<<<
 *             sig_check()
 * 
 */
        while (1) {

          /* "cysignals/tests.pyx":345
 *         sig_on()
 *         while True:
 *             sig_check()             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_1 = sig_check(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 345, __pyx_L4_error)
        }
      }

      /* "cysignals/tests.pyx":341
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         sig_on()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":331
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check_inside_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":351
 * # Test sig_retry() and sig_error()                                     #
 * ########################################################################
 * def test_sig_retry():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_25test_sig_retry(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_24test_sig_retry, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_retry()\n        10\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_25test_sig_retry = {"test_sig_retry", (PyCFunction)__pyx_pw_9cysignals_5tests_25test_sig_retry, METH_NOARGS, __pyx_doc_9cysignals_5tests_24test_sig_retry};
static PyObject *__pyx_pw_9cysignals_5tests_25test_sig_retry(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_retry (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_24test_sig_retry(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_24test_sig_retry(CYTHON_UNUSED PyObject *__pyx_self) {
  volatile int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_retry", 0);

  /* "cysignals/tests.pyx":360
 * 
 *     """
 *     cdef volatile_int v = 0             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __pyx_v_v = 0;

  /* "cysignals/tests.pyx":362
 *     cdef volatile_int v = 0
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if v < 10:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":363
 * 
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         if v < 10:
 *             v = v + 1
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 363, __pyx_L4_error)

        /* "cysignals/tests.pyx":364
 *     with nogil:
 *         sig_on()
 *         if v < 10:             # <<<<<<<<<<<<<<
 *             v = v + 1
 *             sig_retry()
 */
        __pyx_t_2 = ((__pyx_v_v < 10) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":365
 *         sig_on()
 *         if v < 10:
 *             v = v + 1             # <<<<<<<<<<<<<<
 *             sig_retry()
 *         sig_off()
 */
          __pyx_v_v = (__pyx_v_v + 1);

          /* "cysignals/tests.pyx":366
 *         if v < 10:
 *             v = v + 1
 *             sig_retry()             # <<<<<<<<<<<<<<
 *         sig_off()
 *     return v
 */
          sig_retry();

          /* "cysignals/tests.pyx":364
 *     with nogil:
 *         sig_on()
 *         if v < 10:             # <<<<<<<<<<<<<<
 *             v = v + 1
 *             sig_retry()
 */
        }

        /* "cysignals/tests.pyx":367
 *             v = v + 1
 *             sig_retry()
 *         sig_off()             # <<<<<<<<<<<<<<
 *     return v
 * 
 */
        sig_off();
      }

      /* "cysignals/tests.pyx":362
 *     cdef volatile_int v = 0
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if v < 10:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":368
 *             sig_retry()
 *         sig_off()
 *     return v             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_volatile__int(__pyx_v_v); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cysignals/tests.pyx":351
 * # Test sig_retry() and sig_error()                                     #
 * ########################################################################
 * def test_sig_retry():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.tests.test_sig_retry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":370
 *     return v
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_122__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_27test_sig_retry_and_signal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_26test_sig_retry_and_signal, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_retry_and_signal()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_27test_sig_retry_and_signal = {"test_sig_retry_and_signal", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_27test_sig_retry_and_signal, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_26test_sig_retry_and_signal};
static PyObject *__pyx_pw_9cysignals_5tests_27test_sig_retry_and_signal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_retry_and_signal (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults7 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 370, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_retry_and_signal") < 0)) __PYX_ERR(0, 370, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 371, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_retry_and_signal", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 370, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_retry_and_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_26test_sig_retry_and_signal(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_26test_sig_retry_and_signal(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  volatile int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_retry_and_signal", 0);

  /* "cysignals/tests.pyx":380
 * 
 *     """
 *     cdef volatile_int v = 0             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __pyx_v_v = 0;

  /* "cysignals/tests.pyx":382
 *     cdef volatile_int v = 0
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if v < 10:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":383
 * 
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         if v < 10:
 *             v = v + 1
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 383, __pyx_L4_error)

        /* "cysignals/tests.pyx":384
 *     with nogil:
 *         sig_on()
 *         if v < 10:             # <<<<<<<<<<<<<<
 *             v = v + 1
 *             sig_retry()
 */
        __pyx_t_2 = ((__pyx_v_v < 10) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":385
 *         sig_on()
 *         if v < 10:
 *             v = v + 1             # <<<<<<<<<<<<<<
 *             sig_retry()
 *         signal_after_delay(SIGINT, delay)
 */
          __pyx_v_v = (__pyx_v_v + 1);

          /* "cysignals/tests.pyx":386
 *         if v < 10:
 *             v = v + 1
 *             sig_retry()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         infinite_loop()
 */
          sig_retry();

          /* "cysignals/tests.pyx":384
 *     with nogil:
 *         sig_on()
 *         if v < 10:             # <<<<<<<<<<<<<<
 *             v = v + 1
 *             sig_retry()
 */
        }

        /* "cysignals/tests.pyx":387
 *             v = v + 1
 *             sig_retry()
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":388
 *             sig_retry()
 *         signal_after_delay(SIGINT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_sig_error():
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":382
 *     cdef volatile_int v = 0
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if v < 10:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":370
 *     return v
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_retry_and_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":390
 *         infinite_loop()
 * 
 * def test_sig_error():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_29test_sig_error(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_28test_sig_error, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_error()\n        Traceback (most recent call last):\n        ...\n        ValueError: some error\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_29test_sig_error = {"test_sig_error", (PyCFunction)__pyx_pw_9cysignals_5tests_29test_sig_error, METH_NOARGS, __pyx_doc_9cysignals_5tests_28test_sig_error};
static PyObject *__pyx_pw_9cysignals_5tests_29test_sig_error(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_error (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_28test_sig_error(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_28test_sig_error(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_error", 0);

  /* "cysignals/tests.pyx":401
 * 
 *     """
 *     sig_on()             # <<<<<<<<<<<<<<
 *     PyErr_SetString(ValueError, "some error")
 *     sig_error()
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 401, __pyx_L1_error)

  /* "cysignals/tests.pyx":402
 *     """
 *     sig_on()
 *     PyErr_SetString(ValueError, "some error")             # <<<<<<<<<<<<<<
 *     sig_error()
 * 
 */
  PyErr_SetString(__pyx_builtin_ValueError, ((char *)"some error"));

  /* "cysignals/tests.pyx":403
 *     sig_on()
 *     PyErr_SetString(ValueError, "some error")
 *     sig_error()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  sig_error();

  /* "cysignals/tests.pyx":390
 *         infinite_loop()
 * 
 * def test_sig_error():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":409
 * # Test no_except macros                                                #
 * ########################################################################
 * def test_sig_on_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_124__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_31test_sig_on_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_30test_sig_on_no_except, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_no_except()\n        42\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_31test_sig_on_no_except = {"test_sig_on_no_except", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_31test_sig_on_no_except, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_30test_sig_on_no_except};
static PyObject *__pyx_pw_9cysignals_5tests_31test_sig_on_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_no_except (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults8 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 409, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_no_except") < 0)) __PYX_ERR(0, 409, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 409, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_no_except", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 409, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_30test_sig_on_no_except(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_30test_sig_on_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_no_except", 0);

  /* "cysignals/tests.pyx":418
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch any signal.
 */
  __pyx_t_1 = ((!(sig_on() != 0)) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":421
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch any signal.
 *         print("Unexpected zero returned from sig_on_no_except()")             # <<<<<<<<<<<<<<
 *     sig_off()
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cysignals/tests.pyx":418
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch any signal.
 */
  }

  /* "cysignals/tests.pyx":422
 *         # will not catch any signal.
 *         print("Unexpected zero returned from sig_on_no_except()")
 *     sig_off()             # <<<<<<<<<<<<<<
 * 
 *     signal_after_delay(SIGINT, delay)
 */
  sig_off();

  /* "cysignals/tests.pyx":424
 *     sig_off()
 * 
 *     signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *     if not sig_on_no_except():
 *         # We get here when we caught a signal.  An exception
 */
  signal_after_delay(SIGINT, __pyx_v_delay);

  /* "cysignals/tests.pyx":425
 * 
 *     signal_after_delay(SIGINT, delay)
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We get here when we caught a signal.  An exception
 *         # has been raised, but Cython doesn't realize it yet.
 */
  __pyx_t_1 = ((!(sig_on() != 0)) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":428
 *         # We get here when we caught a signal.  An exception
 *         # has been raised, but Cython doesn't realize it yet.
 *         try:             # <<<<<<<<<<<<<<
 *             # Make Cython realize that there is an exception.
 *             # To Cython, it will look like the exception was raised on
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "cysignals/tests.pyx":432
 *             # To Cython, it will look like the exception was raised on
 *             # the following line, so the try/except should work.
 *             cython_check_exception()             # <<<<<<<<<<<<<<
 *         except KeyboardInterrupt:
 *             return 42
 */
        __pyx_f_9cysignals_7signals_cython_check_exception(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 432, __pyx_L5_error)

        /* "cysignals/tests.pyx":428
 *         # We get here when we caught a signal.  An exception
 *         # has been raised, but Cython doesn't realize it yet.
 *         try:             # <<<<<<<<<<<<<<
 *             # Make Cython realize that there is an exception.
 *             # To Cython, it will look like the exception was raised on
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cysignals/tests.pyx":433
 *             # the following line, so the try/except should work.
 *             cython_check_exception()
 *         except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *             return 42
 *         return 0 # fail
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("cysignals.tests.test_sig_on_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 433, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);

        /* "cysignals/tests.pyx":434
 *             cython_check_exception()
 *         except KeyboardInterrupt:
 *             return 42             # <<<<<<<<<<<<<<
 *         return 0 # fail
 *     infinite_loop()
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_int_42);
        __pyx_r = __pyx_int_42;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L8_except_return;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cysignals/tests.pyx":428
 *         # We get here when we caught a signal.  An exception
 *         # has been raised, but Cython doesn't realize it yet.
 *         try:             # <<<<<<<<<<<<<<
 *             # Make Cython realize that there is an exception.
 *             # To Cython, it will look like the exception was raised on
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L8_except_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
      __pyx_L10_try_end:;
    }

    /* "cysignals/tests.pyx":435
 *         except KeyboardInterrupt:
 *             return 42
 *         return 0 # fail             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;

    /* "cysignals/tests.pyx":425
 * 
 *     signal_after_delay(SIGINT, delay)
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We get here when we caught a signal.  An exception
 *         # has been raised, but Cython doesn't realize it yet.
 */
  }

  /* "cysignals/tests.pyx":436
 *             return 42
 *         return 0 # fail
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_sig_str_no_except(long delay=DEFAULT_DELAY):
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":409
 * # Test no_except macros                                                #
 * ########################################################################
 * def test_sig_on_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":438
 *     infinite_loop()
 * 
 * def test_sig_str_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_126__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_33test_sig_str_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_32test_sig_str_no_except, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_str_no_except()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_33test_sig_str_no_except = {"test_sig_str_no_except", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_33test_sig_str_no_except, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_32test_sig_str_no_except};
static PyObject *__pyx_pw_9cysignals_5tests_33test_sig_str_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_str_no_except (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults9 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_str_no_except") < 0)) __PYX_ERR(0, 438, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_str_no_except", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 438, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_str_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_32test_sig_str_no_except(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_32test_sig_str_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_str_no_except", 0);

  /* "cysignals/tests.pyx":449
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch a signal.
 */
  __pyx_t_1 = ((!(sig_on() != 0)) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":452
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch a signal.
 *         print("Unexpected zero returned from sig_on_no_except()")             # <<<<<<<<<<<<<<
 *     sig_off()
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cysignals/tests.pyx":449
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch a signal.
 */
  }

  /* "cysignals/tests.pyx":453
 *         # will not catch a signal.
 *         print("Unexpected zero returned from sig_on_no_except()")
 *     sig_off()             # <<<<<<<<<<<<<<
 * 
 *     if not sig_str_no_except("Everything ok!"):
 */
  sig_off();

  /* "cysignals/tests.pyx":455
 *     sig_off()
 * 
 *     if not sig_str_no_except("Everything ok!"):             # <<<<<<<<<<<<<<
 *         cython_check_exception()
 *         return 0 # fail
 */
  __pyx_t_1 = ((!(sig_str(((char const *)"Everything ok!")) != 0)) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":456
 * 
 *     if not sig_str_no_except("Everything ok!"):
 *         cython_check_exception()             # <<<<<<<<<<<<<<
 *         return 0 # fail
 *     signal_after_delay(SIGABRT, delay)
 */
    __pyx_f_9cysignals_7signals_cython_check_exception(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 456, __pyx_L1_error)

    /* "cysignals/tests.pyx":457
 *     if not sig_str_no_except("Everything ok!"):
 *         cython_check_exception()
 *         return 0 # fail             # <<<<<<<<<<<<<<
 *     signal_after_delay(SIGABRT, delay)
 *     infinite_loop()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;

    /* "cysignals/tests.pyx":455
 *     sig_off()
 * 
 *     if not sig_str_no_except("Everything ok!"):             # <<<<<<<<<<<<<<
 *         cython_check_exception()
 *         return 0 # fail
 */
  }

  /* "cysignals/tests.pyx":458
 *         cython_check_exception()
 *         return 0 # fail
 *     signal_after_delay(SIGABRT, delay)             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
  signal_after_delay(SIGABRT, __pyx_v_delay);

  /* "cysignals/tests.pyx":459
 *         return 0 # fail
 *     signal_after_delay(SIGABRT, delay)
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":438
 *     infinite_loop()
 * 
 * def test_sig_str_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.test_sig_str_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":461
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_128__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_35test_sig_check_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_34test_sig_check_no_except, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_check_no_except()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_35test_sig_check_no_except = {"test_sig_check_no_except", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_35test_sig_check_no_except, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_34test_sig_check_no_except};
static PyObject *__pyx_pw_9cysignals_5tests_35test_sig_check_no_except(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_check_no_except (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults10 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 461, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_check_no_except") < 0)) __PYX_ERR(0, 461, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_check_no_except", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 461, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_34test_sig_check_no_except(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_34test_sig_check_no_except(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_check_no_except", 0);

  /* "cysignals/tests.pyx":471
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         while True:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":472
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         while True:
 *             if not sig_check_no_except():
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":473
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)
 *         while True:             # <<<<<<<<<<<<<<
 *             if not sig_check_no_except():
 *                 cython_check_exception()
 */
        while (1) {

          /* "cysignals/tests.pyx":474
 *         signal_after_delay(SIGINT, delay)
 *         while True:
 *             if not sig_check_no_except():             # <<<<<<<<<<<<<<
 *                 cython_check_exception()
 *                 break # fail
 */
          __pyx_t_1 = ((!(sig_check() != 0)) != 0);
          if (__pyx_t_1) {

            /* "cysignals/tests.pyx":475
 *         while True:
 *             if not sig_check_no_except():
 *                 cython_check_exception()             # <<<<<<<<<<<<<<
 *                 break # fail
 * 
 */
            __pyx_f_9cysignals_7signals_cython_check_exception(); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 475, __pyx_L4_error)

            /* "cysignals/tests.pyx":476
 *             if not sig_check_no_except():
 *                 cython_check_exception()
 *                 break # fail             # <<<<<<<<<<<<<<
 * 
 * 
 */
            goto __pyx_L7_break;

            /* "cysignals/tests.pyx":474
 *         signal_after_delay(SIGINT, delay)
 *         while True:
 *             if not sig_check_no_except():             # <<<<<<<<<<<<<<
 *                 cython_check_exception()
 *                 break # fail
 */
          }
        }
        __pyx_L7_break:;
      }

      /* "cysignals/tests.pyx":471
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         while True:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":461
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_check_no_except", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":482
 * # Test different signals                                               #
 * ########################################################################
 * def test_signal_segv(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_130__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_37test_signal_segv(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_36test_signal_segv, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_segv()\n        Traceback (most recent call last):\n        ...\n        SignalError: Segmentation fault\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_37test_signal_segv = {"test_signal_segv", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_37test_signal_segv, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_36test_signal_segv};
static PyObject *__pyx_pw_9cysignals_5tests_37test_signal_segv(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_segv (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults11 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 482, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_segv") < 0)) __PYX_ERR(0, 482, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 482, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_segv", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 482, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_segv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_36test_signal_segv(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_36test_signal_segv(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_segv", 0);

  /* "cysignals/tests.pyx":493
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGSEGV, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":494
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGSEGV, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 494, __pyx_L4_error)

        /* "cysignals/tests.pyx":495
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGSEGV, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGSEGV, __pyx_v_delay);

        /* "cysignals/tests.pyx":496
 *         sig_on()
 *         signal_after_delay(SIGSEGV, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_signal_fpe(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":493
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGSEGV, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":482
 * # Test different signals                                               #
 * ########################################################################
 * def test_signal_segv(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_segv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":498
 *         infinite_loop()
 * 
 * def test_signal_fpe(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_132__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults12, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_39test_signal_fpe(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_38test_signal_fpe, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_fpe()\n        Traceback (most recent call last):\n        ...\n        FloatingPointError: Floating point exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_39test_signal_fpe = {"test_signal_fpe", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_39test_signal_fpe, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_38test_signal_fpe};
static PyObject *__pyx_pw_9cysignals_5tests_39test_signal_fpe(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_fpe (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults12 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults12, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 498, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_fpe") < 0)) __PYX_ERR(0, 498, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 498, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_fpe", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 498, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_fpe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_38test_signal_fpe(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_38test_signal_fpe(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_fpe", 0);

  /* "cysignals/tests.pyx":509
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGFPE, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":510
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGFPE, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 510, __pyx_L4_error)

        /* "cysignals/tests.pyx":511
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGFPE, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGFPE, __pyx_v_delay);

        /* "cysignals/tests.pyx":512
 *         sig_on()
 *         signal_after_delay(SIGFPE, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_signal_ill(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":509
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGFPE, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":498
 *         infinite_loop()
 * 
 * def test_signal_fpe(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_fpe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":514
 *         infinite_loop()
 * 
 * def test_signal_ill(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_134__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults13, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_41test_signal_ill(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_40test_signal_ill, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_ill()\n        Traceback (most recent call last):\n        ...\n        SignalError: Illegal instruction\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_41test_signal_ill = {"test_signal_ill", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_41test_signal_ill, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_40test_signal_ill};
static PyObject *__pyx_pw_9cysignals_5tests_41test_signal_ill(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_ill (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults13 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults13, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 514, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_ill") < 0)) __PYX_ERR(0, 514, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 514, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_ill", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 514, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_ill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_40test_signal_ill(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_40test_signal_ill(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_ill", 0);

  /* "cysignals/tests.pyx":525
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGILL, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":526
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGILL, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 526, __pyx_L4_error)

        /* "cysignals/tests.pyx":527
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGILL, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGILL, __pyx_v_delay);

        /* "cysignals/tests.pyx":528
 *         sig_on()
 *         signal_after_delay(SIGILL, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_signal_abrt(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":525
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGILL, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":514
 *         infinite_loop()
 * 
 * def test_signal_ill(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_ill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":530
 *         infinite_loop()
 * 
 * def test_signal_abrt(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_136__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults14, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_43test_signal_abrt(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_42test_signal_abrt, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_abrt()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_43test_signal_abrt = {"test_signal_abrt", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_43test_signal_abrt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_42test_signal_abrt};
static PyObject *__pyx_pw_9cysignals_5tests_43test_signal_abrt(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_abrt (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults14 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults14, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 530, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_abrt") < 0)) __PYX_ERR(0, 530, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 530, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_abrt", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 530, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_abrt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_42test_signal_abrt(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_42test_signal_abrt(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_abrt", 0);

  /* "cysignals/tests.pyx":541
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGABRT, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":542
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 542, __pyx_L4_error)

        /* "cysignals/tests.pyx":543
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGABRT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGABRT, __pyx_v_delay);

        /* "cysignals/tests.pyx":544
 *         sig_on()
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_signal_bus(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":541
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGABRT, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":530
 *         infinite_loop()
 * 
 * def test_signal_abrt(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_abrt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":546
 *         infinite_loop()
 * 
 * def test_signal_bus(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_138__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults15, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_45test_signal_bus(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_44test_signal_bus, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_signal_bus()\n        Traceback (most recent call last):\n        ...\n        SignalError: Bus error\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_45test_signal_bus = {"test_signal_bus", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_45test_signal_bus, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_44test_signal_bus};
static PyObject *__pyx_pw_9cysignals_5tests_45test_signal_bus(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_bus (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults15 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults15, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 546, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_bus") < 0)) __PYX_ERR(0, 546, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 546, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_bus", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 546, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_bus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_44test_signal_bus(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_44test_signal_bus(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_bus", 0);

  /* "cysignals/tests.pyx":557
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGBUS, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":558
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGBUS, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 558, __pyx_L4_error)

        /* "cysignals/tests.pyx":559
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGBUS, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGBUS, __pyx_v_delay);

        /* "cysignals/tests.pyx":560
 *         sig_on()
 *         signal_after_delay(SIGBUS, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * def test_signal_quit(long delay=DEFAULT_DELAY):
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":557
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGBUS, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":546
 *         infinite_loop()
 * 
 * def test_signal_bus(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_bus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":562
 *         infinite_loop()
 * 
 * def test_signal_quit(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

static PyObject *__pyx_pf_9cysignals_5tests_140__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults16, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_47test_signal_quit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_46test_signal_quit, "\n    TESTS:\n\n    We run Python in a subprocess and make it raise a SIGQUIT under\n    ``sig_on()``.  This should cause Python to exit::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; test_signal_quit()')\n        ---------------------------------------------------------------------...\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_47test_signal_quit = {"test_signal_quit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_47test_signal_quit, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_46test_signal_quit};
static PyObject *__pyx_pw_9cysignals_5tests_47test_signal_quit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_quit (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults16 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults16, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 562, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_quit") < 0)) __PYX_ERR(0, 562, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 562, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_quit", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 562, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_quit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_46test_signal_quit(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_46test_signal_quit(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_quit", 0);

  /* "cysignals/tests.pyx":575
 *     """
 *     # The sig_on() shouldn't make a difference for SIGQUIT
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGQUIT, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":576
 *     # The sig_on() shouldn't make a difference for SIGQUIT
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGQUIT, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 576, __pyx_L4_error)

        /* "cysignals/tests.pyx":577
 *     with nogil:
 *         sig_on()
 *         signal_after_delay(SIGQUIT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGQUIT, __pyx_v_delay);

        /* "cysignals/tests.pyx":578
 *         sig_on()
 *         signal_after_delay(SIGQUIT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":575
 *     """
 *     # The sig_on() shouldn't make a difference for SIGQUIT
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         signal_after_delay(SIGQUIT, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":562
 *         infinite_loop()
 * 
 * def test_signal_quit(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_quit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":584
 * # Test with "true" errors (not signals raised by hand)                 #
 * ########################################################################
 * def test_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_49test_dereference_null_pointer(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_48test_dereference_null_pointer, "\n    TESTS:\n\n    This test should result in either a Segmentation Fault or a Bus\n    Error. ::\n\n        >>> from cysignals.tests import *\n        >>> test_dereference_null_pointer()\n        Traceback (most recent call last):\n        ...\n        SignalError: ...\n        >>> on_stack()\n        False\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_49test_dereference_null_pointer = {"test_dereference_null_pointer", (PyCFunction)__pyx_pw_9cysignals_5tests_49test_dereference_null_pointer, METH_NOARGS, __pyx_doc_9cysignals_5tests_48test_dereference_null_pointer};
static PyObject *__pyx_pw_9cysignals_5tests_49test_dereference_null_pointer(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_dereference_null_pointer (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_48test_dereference_null_pointer(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_48test_dereference_null_pointer(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_dereference_null_pointer", 0);

  /* "cysignals/tests.pyx":600
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         dereference_null_pointer()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":601
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         dereference_null_pointer()
 * 
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 601, __pyx_L4_error)

        /* "cysignals/tests.pyx":602
 *     with nogil:
 *         sig_on()
 *         dereference_null_pointer()             # <<<<<<<<<<<<<<
 * 
 * def unguarded_dereference_null_pointer():
 */
        __pyx_f_9cysignals_5tests_dereference_null_pointer();
      }

      /* "cysignals/tests.pyx":600
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         dereference_null_pointer()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":584
 * # Test with "true" errors (not signals raised by hand)                 #
 * ########################################################################
 * def test_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_dereference_null_pointer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":604
 *         dereference_null_pointer()
 * 
 * def unguarded_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_51unguarded_dereference_null_pointer(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_50unguarded_dereference_null_pointer, "\n    TESTS:\n\n    We run Python in a subprocess and dereference a NULL pointer without\n    using ``sig_on()``. This will crash Python::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_dereference_null_pointer()')\n        ---------------------------------------------------------------------...\n        Unhandled SIG...\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    The same but with ``CYSIGNALS_CRASH_QUIET`` set. This will crash\n    Python silently::\n\n        >>> import os\n        >>> env = dict(os.environ)\n        >>> env[\"CYSIGNALS_CRASH_QUIET\"] = \"\"\n        >>> subpython_err('from cysignals.tests import *; unguarded_dereference_null_pointer()', env=env)\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_51unguarded_dereference_null_pointer = {"unguarded_dereference_null_pointer", (PyCFunction)__pyx_pw_9cysignals_5tests_51unguarded_dereference_null_pointer, METH_NOARGS, __pyx_doc_9cysignals_5tests_50unguarded_dereference_null_pointer};
static PyObject *__pyx_pw_9cysignals_5tests_51unguarded_dereference_null_pointer(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_dereference_null_pointer (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_50unguarded_dereference_null_pointer(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_50unguarded_dereference_null_pointer(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_dereference_null_pointer", 0);

  /* "cysignals/tests.pyx":629
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         dereference_null_pointer()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":630
 *     """
 *     with nogil:
 *         dereference_null_pointer()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_f_9cysignals_5tests_dereference_null_pointer();
      }

      /* "cysignals/tests.pyx":629
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         dereference_null_pointer()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":604
 *         dereference_null_pointer()
 * 
 * def unguarded_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":633
 * 
 * 
 * def test_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_53test_abort(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_52test_abort, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_abort()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_53test_abort = {"test_abort", (PyCFunction)__pyx_pw_9cysignals_5tests_53test_abort, METH_NOARGS, __pyx_doc_9cysignals_5tests_52test_abort};
static PyObject *__pyx_pw_9cysignals_5tests_53test_abort(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_abort (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_52test_abort(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_52test_abort(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_abort", 0);

  /* "cysignals/tests.pyx":644
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         abort()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":645
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         abort()
 * 
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 645, __pyx_L4_error)

        /* "cysignals/tests.pyx":646
 *     with nogil:
 *         sig_on()
 *         abort()             # <<<<<<<<<<<<<<
 * 
 * def unguarded_abort():
 */
        abort();
      }

      /* "cysignals/tests.pyx":644
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         abort()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":633
 * 
 * 
 * def test_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_abort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":648
 *         abort()
 * 
 * def unguarded_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_55unguarded_abort(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_54unguarded_abort, "\n    TESTS:\n\n    We run Python in a subprocess and make it call abort()::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_abort()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGABRT: An abort() occurred.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_55unguarded_abort = {"unguarded_abort", (PyCFunction)__pyx_pw_9cysignals_5tests_55unguarded_abort, METH_NOARGS, __pyx_doc_9cysignals_5tests_54unguarded_abort};
static PyObject *__pyx_pw_9cysignals_5tests_55unguarded_abort(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_abort (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_54unguarded_abort(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_54unguarded_abort(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_abort", 0);

  /* "cysignals/tests.pyx":664
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         abort()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":665
 *     """
 *     with nogil:
 *         abort()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        abort();
      }

      /* "cysignals/tests.pyx":664
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         abort()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":648
 *         abort()
 * 
 * def unguarded_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":668
 * 
 * 
 * def test_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_57test_stack_overflow(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_56test_stack_overflow, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_stack_overflow()\n        Traceback (most recent call last):\n        ...\n        SignalError: Segmentation fault\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_57test_stack_overflow = {"test_stack_overflow", (PyCFunction)__pyx_pw_9cysignals_5tests_57test_stack_overflow, METH_NOARGS, __pyx_doc_9cysignals_5tests_56test_stack_overflow};
static PyObject *__pyx_pw_9cysignals_5tests_57test_stack_overflow(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_stack_overflow (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_56test_stack_overflow(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_56test_stack_overflow(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_stack_overflow", 0);

  /* "cysignals/tests.pyx":679
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         stack_overflow()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":680
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         stack_overflow()
 * 
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 680, __pyx_L4_error)

        /* "cysignals/tests.pyx":681
 *     with nogil:
 *         sig_on()
 *         stack_overflow()             # <<<<<<<<<<<<<<
 * 
 * def unguarded_stack_overflow():
 */
        (void)(__pyx_f_9cysignals_5tests_stack_overflow(NULL));
      }

      /* "cysignals/tests.pyx":679
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         stack_overflow()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":668
 * 
 * 
 * def test_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_stack_overflow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":683
 *         stack_overflow()
 * 
 * def unguarded_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_59unguarded_stack_overflow(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_58unguarded_stack_overflow, "\n    TESTS:\n\n    We run Python in a subprocess and overflow the stack::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; unguarded_stack_overflow()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGSEGV: A segmentation fault occurred.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_59unguarded_stack_overflow = {"unguarded_stack_overflow", (PyCFunction)__pyx_pw_9cysignals_5tests_59unguarded_stack_overflow, METH_NOARGS, __pyx_doc_9cysignals_5tests_58unguarded_stack_overflow};
static PyObject *__pyx_pw_9cysignals_5tests_59unguarded_stack_overflow(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_stack_overflow (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_58unguarded_stack_overflow(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_58unguarded_stack_overflow(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unguarded_stack_overflow", 0);

  /* "cysignals/tests.pyx":699
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         stack_overflow()
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":700
 *     """
 *     with nogil:
 *         stack_overflow()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        (void)(__pyx_f_9cysignals_5tests_stack_overflow(NULL));
      }

      /* "cysignals/tests.pyx":699
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         stack_overflow()
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":683
 *         stack_overflow()
 * 
 * def unguarded_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":703
 * 
 * 
 * def test_access_mmap_noreserve():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_61test_access_mmap_noreserve(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_60test_access_mmap_noreserve, "\n    TESTS:\n\n    Regression test for https://github.com/sagemath/cysignals/pull/108; if\n    the issue is fixed then ``test_access_mmap_noreserve()`` should have no\n    output.  Otherwise the subprocess will exit and report an error occurred\n    during signal handling::\n\n        >>> from cysignals.tests import test_access_mmap_noreserve\n        >>> test_access_mmap_noreserve()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_61test_access_mmap_noreserve = {"test_access_mmap_noreserve", (PyCFunction)__pyx_pw_9cysignals_5tests_61test_access_mmap_noreserve, METH_NOARGS, __pyx_doc_9cysignals_5tests_60test_access_mmap_noreserve};
static PyObject *__pyx_pw_9cysignals_5tests_61test_access_mmap_noreserve(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_access_mmap_noreserve (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_60test_access_mmap_noreserve(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_60test_access_mmap_noreserve(CYTHON_UNUSED PyObject *__pyx_self) {
  int *__pyx_v_ptr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_access_mmap_noreserve", 0);

  /* "cysignals/tests.pyx":716
 * 
 *     """
 *     cdef int* ptr = <int*>map_noreserve()             # <<<<<<<<<<<<<<
 *     if ptr is NULL:
 *         raise RuntimeError(f"mmap() failed; errno: {errno}")
 */
  __pyx_v_ptr = ((int *)map_noreserve());

  /* "cysignals/tests.pyx":717
 *     """
 *     cdef int* ptr = <int*>map_noreserve()
 *     if ptr is NULL:             # <<<<<<<<<<<<<<
 *         raise RuntimeError(f"mmap() failed; errno: {errno}")
 * 
 */
  __pyx_t_1 = ((__pyx_v_ptr == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "cysignals/tests.pyx":718
 *     cdef int* ptr = <int*>map_noreserve()
 *     if ptr is NULL:
 *         raise RuntimeError(f"mmap() failed; errno: {errno}")             # <<<<<<<<<<<<<<
 * 
 *     ptr[0] += 1  # Should just work
 */
    __pyx_t_2 = __Pyx_PyUnicode_From_int(errno, 0, ' ', 'd'); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_mmap_failed_errno, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 718, __pyx_L1_error)

    /* "cysignals/tests.pyx":717
 *     """
 *     cdef int* ptr = <int*>map_noreserve()
 *     if ptr is NULL:             # <<<<<<<<<<<<<<
 *         raise RuntimeError(f"mmap() failed; errno: {errno}")
 * 
 */
  }

  /* "cysignals/tests.pyx":720
 *         raise RuntimeError(f"mmap() failed; errno: {errno}")
 * 
 *     ptr[0] += 1  # Should just work             # <<<<<<<<<<<<<<
 * 
 *     if unmap_noreserve(ptr) != 0:
 */
  __pyx_t_4 = 0;
  (__pyx_v_ptr[__pyx_t_4]) = ((__pyx_v_ptr[__pyx_t_4]) + 1);

  /* "cysignals/tests.pyx":722
 *     ptr[0] += 1  # Should just work
 * 
 *     if unmap_noreserve(ptr) != 0:             # <<<<<<<<<<<<<<
 *         raise RuntimeError(f"munmap() failed; errno: {errno}")
 * 
 */
  __pyx_t_1 = ((unmap_noreserve(__pyx_v_ptr) != 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "cysignals/tests.pyx":723
 * 
 *     if unmap_noreserve(ptr) != 0:
 *         raise RuntimeError(f"munmap() failed; errno: {errno}")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyUnicode_From_int(errno, 0, ' ', 'd'); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 723, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_munmap_failed_errno, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 723, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 723, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 723, __pyx_L1_error)

    /* "cysignals/tests.pyx":722
 *     ptr[0] += 1  # Should just work
 * 
 *     if unmap_noreserve(ptr) != 0:             # <<<<<<<<<<<<<<
 *         raise RuntimeError(f"munmap() failed; errno: {errno}")
 * 
 */
  }

  /* "cysignals/tests.pyx":703
 * 
 * 
 * def test_access_mmap_noreserve():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.tests.test_access_mmap_noreserve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":726
 * 
 * 
 * def test_bad_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

static PyObject *__pyx_pf_9cysignals_5tests_142__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_63test_bad_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_62test_bad_str, "\n    TESTS:\n\n    We run Python in a subprocess and induce an error during the signal handler::\n\n        >>> from cysignals.tests import subpython_err\n        >>> subpython_err('from cysignals.tests import *; test_bad_str()')\n        ---------------------------------------------------------------------...\n        Unhandled SIGSEGV during signal handling.\n        This probably occurred because a *compiled* module has a bug\n        in it and is not properly wrapped with sig_on(), sig_off().\n        Python will now terminate.\n        ------------------------------------------------------------------------\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_63test_bad_str = {"test_bad_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_63test_bad_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_62test_bad_str};
static PyObject *__pyx_pw_9cysignals_5tests_63test_bad_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_bad_str (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults17 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 726, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_bad_str") < 0)) __PYX_ERR(0, 726, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 726, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_bad_str", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 726, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_bad_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_62test_bad_str(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_62test_bad_str(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  char *__pyx_v_s;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_bad_str", 0);

  /* "cysignals/tests.pyx":742
 * 
 *     """
 *     cdef char* s = <char*>(16)             # <<<<<<<<<<<<<<
 *     with nogil:
 *         sig_str(s)
 */
  __pyx_v_s = ((char *)16);

  /* "cysignals/tests.pyx":743
 *     """
 *     cdef char* s = <char*>(16)
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_str(s)
 *         signal_after_delay(SIGILL, delay)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":744
 *     cdef char* s = <char*>(16)
 *     with nogil:
 *         sig_str(s)             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGILL, delay)
 *         infinite_loop()
 */
        __pyx_t_1 = sig_str(__pyx_v_s); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 744, __pyx_L4_error)

        /* "cysignals/tests.pyx":745
 *     with nogil:
 *         sig_str(s)
 *         signal_after_delay(SIGILL, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 * 
 */
        signal_after_delay(SIGILL, __pyx_v_delay);

        /* "cysignals/tests.pyx":746
 *         sig_str(s)
 *         signal_after_delay(SIGILL, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_f_9cysignals_5tests_infinite_loop();
      }

      /* "cysignals/tests.pyx":743
 *     """
 *     cdef char* s = <char*>(16)
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_str(s)
 *         signal_after_delay(SIGILL, delay)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":726
 * 
 * 
 * def test_bad_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_bad_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":752
 * # Test various usage scenarios for sig_on()/sig_off()                  #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_144__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_65test_sig_on_cython_after_delay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_64test_sig_on_cython_after_delay, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_cython_after_delay()\n        KeyboardInterrupt()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_65test_sig_on_cython_after_delay = {"test_sig_on_cython_after_delay", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_65test_sig_on_cython_after_delay, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_64test_sig_on_cython_after_delay};
static PyObject *__pyx_pw_9cysignals_5tests_65test_sig_on_cython_after_delay(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_cython_after_delay (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults18 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 752, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_cython_after_delay") < 0)) __PYX_ERR(0, 752, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 753, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_cython_after_delay", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 752, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_after_delay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_64test_sig_on_cython_after_delay(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_64test_sig_on_cython_after_delay(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_cython_after_delay", 0);

  /* "cysignals/tests.pyx":762
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":763
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_on()             # The signal should be detected here
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":764
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)
 *         ms_sleep(delay * 2)  # We get signaled during this sleep             # <<<<<<<<<<<<<<
 *         sig_on()             # The signal should be detected here
 *         abort()              # This should not be reached
 */
        ms_sleep((__pyx_v_delay * 2));

        /* "cysignals/tests.pyx":765
 *         signal_after_delay(SIGINT, delay)
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_on()             # The signal should be detected here             # <<<<<<<<<<<<<<
 *         abort()              # This should not be reached
 * 
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 765, __pyx_L4_error)

        /* "cysignals/tests.pyx":766
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_on()             # The signal should be detected here
 *         abort()              # This should not be reached             # <<<<<<<<<<<<<<
 * 
 * def test_sig_on_inside_try(long delay=DEFAULT_DELAY):
 */
        abort();
      }

      /* "cysignals/tests.pyx":762
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":752
 * # Test various usage scenarios for sig_on()/sig_off()                  #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_cython_after_delay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":768
 *         abort()              # This should not be reached
 * 
 * def test_sig_on_inside_try(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_146__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_67test_sig_on_inside_try(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_66test_sig_on_inside_try, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_on_inside_try()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_67test_sig_on_inside_try = {"test_sig_on_inside_try", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_67test_sig_on_inside_try, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_66test_sig_on_inside_try};
static PyObject *__pyx_pw_9cysignals_5tests_67test_sig_on_inside_try(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_on_inside_try (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults19 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 768, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_on_inside_try") < 0)) __PYX_ERR(0, 768, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 768, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_on_inside_try", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 768, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_inside_try", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_66test_sig_on_inside_try(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_66test_sig_on_inside_try(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_on_inside_try", 0);

  /* "cysignals/tests.pyx":776
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":777
 *     """
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             signal_after_delay(SIGABRT, delay)
 */
      {
          #ifdef WITH_THREAD
          PyThreadState *_save;
          Py_UNBLOCK_THREADS
          __Pyx_FastGIL_Remember();
          #endif
          /*try:*/ {

            /* "cysignals/tests.pyx":778
 *     try:
 *         with nogil:
 *             sig_on()             # <<<<<<<<<<<<<<
 *             signal_after_delay(SIGABRT, delay)
 *             infinite_loop()
 */
            __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 778, __pyx_L10_error)

            /* "cysignals/tests.pyx":779
 *         with nogil:
 *             sig_on()
 *             signal_after_delay(SIGABRT, delay)             # <<<<<<<<<<<<<<
 *             infinite_loop()
 *     except RuntimeError:
 */
            signal_after_delay(SIGABRT, __pyx_v_delay);

            /* "cysignals/tests.pyx":780
 *             sig_on()
 *             signal_after_delay(SIGABRT, delay)
 *             infinite_loop()             # <<<<<<<<<<<<<<
 *     except RuntimeError:
 *         pass
 */
            __pyx_f_9cysignals_5tests_infinite_loop();
          }

          /* "cysignals/tests.pyx":777
 *     """
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             signal_after_delay(SIGABRT, delay)
 */
          /*finally:*/ {
            /*normal exit:*/{
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L11;
            }
            __pyx_L10_error: {
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L3_error;
            }
            __pyx_L11:;
          }
      }

      /* "cysignals/tests.pyx":776
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "cysignals/tests.pyx":781
 *             signal_after_delay(SIGABRT, delay)
 *             infinite_loop()
 *     except RuntimeError:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_RuntimeError);
    if (__pyx_t_4) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":776
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cysignals/tests.pyx":768
 *         abort()              # This should not be reached
 * 
 * def test_sig_on_inside_try(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_on_inside_try", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":785
 * 
 * 
 * def test_interrupt_bomb(long n=100, long p=10):             # <<<<<<<<<<<<<<
 *     """
 *     Have `p` processes each sending `n` interrupts in very quick
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_69test_interrupt_bomb(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_68test_interrupt_bomb, "\n    Have `p` processes each sending `n` interrupts in very quick\n    succession and see what happens :-)\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_interrupt_bomb()  # doctest: +SKIP_CYGWIN\n        Received ... interrupts\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_69test_interrupt_bomb = {"test_interrupt_bomb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_69test_interrupt_bomb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_68test_interrupt_bomb};
static PyObject *__pyx_pw_9cysignals_5tests_69test_interrupt_bomb(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_n;
  long __pyx_v_p;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_interrupt_bomb (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_p,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_p,0};
    #endif
    PyObject* values[2] = {0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 785, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_p);
          if (value) { values[1] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 785, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_interrupt_bomb") < 0)) __PYX_ERR(0, 785, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_n = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_n == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 785, __pyx_L3_error)
    } else {
      __pyx_v_n = ((long)((long)0x64));
    }
    if (values[1]) {
      __pyx_v_p = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v_p == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 785, __pyx_L3_error)
    } else {
      __pyx_v_p = ((long)((long)10));
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_interrupt_bomb", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 785, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_interrupt_bomb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_68test_interrupt_bomb(__pyx_self, __pyx_v_n, __pyx_v_p);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_68test_interrupt_bomb(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_n, long __pyx_v_p) {
  long __pyx_v_i;
  long __pyx_v_base_delay;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  long __pyx_t_2;
  long __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_interrupt_bomb", 0);

  /* "cysignals/tests.pyx":800
 * 
 *     # Spawn p processes, each sending n signals with an interval of 1 millisecond
 *     cdef long base_delay = DEFAULT_DELAY + 5*p             # <<<<<<<<<<<<<<
 *     for i in range(p):
 *         signals_after_delay(SIGINT, base_delay, 1, n)
 */
  __pyx_v_base_delay = (__pyx_v_9cysignals_5tests_DEFAULT_DELAY + (5 * __pyx_v_p));

  /* "cysignals/tests.pyx":801
 *     # Spawn p processes, each sending n signals with an interval of 1 millisecond
 *     cdef long base_delay = DEFAULT_DELAY + 5*p
 *     for i in range(p):             # <<<<<<<<<<<<<<
 *         signals_after_delay(SIGINT, base_delay, 1, n)
 * 
 */
  __pyx_t_1 = __pyx_v_p;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "cysignals/tests.pyx":802
 *     cdef long base_delay = DEFAULT_DELAY + 5*p
 *     for i in range(p):
 *         signals_after_delay(SIGINT, base_delay, 1, n)             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
    signals_after_delay(SIGINT, __pyx_v_base_delay, 1, __pyx_v_n);
  }

  /* "cysignals/tests.pyx":804
 *         signals_after_delay(SIGINT, base_delay, 1, n)
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     while True:
 *         try:
 */
  __pyx_v_i = 0;

  /* "cysignals/tests.pyx":805
 * 
 *     i = 0
 *     while True:             # <<<<<<<<<<<<<<
 *         try:
 *             with nogil:
 */
  while (1) {

    /* "cysignals/tests.pyx":806
 *     i = 0
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sig_on()
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "cysignals/tests.pyx":807
 *     while True:
 *         try:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sig_on()
 *                 ms_sleep(1000)
 */
        {
            #ifdef WITH_THREAD
            PyThreadState *_save;
            Py_UNBLOCK_THREADS
            __Pyx_FastGIL_Remember();
            #endif
            /*try:*/ {

              /* "cysignals/tests.pyx":808
 *         try:
 *             with nogil:
 *                 sig_on()             # <<<<<<<<<<<<<<
 *                 ms_sleep(1000)
 *                 sig_off()
 */
              __pyx_t_7 = sig_on(); if (unlikely(__pyx_t_7 == ((int)0))) __PYX_ERR(0, 808, __pyx_L18_error)

              /* "cysignals/tests.pyx":809
 *             with nogil:
 *                 sig_on()
 *                 ms_sleep(1000)             # <<<<<<<<<<<<<<
 *                 sig_off()
 *             # If 1 second passed since the last interrupt, we assume that
 */
              ms_sleep(0x3E8);

              /* "cysignals/tests.pyx":810
 *                 sig_on()
 *                 ms_sleep(1000)
 *                 sig_off()             # <<<<<<<<<<<<<<
 *             # If 1 second passed since the last interrupt, we assume that
 *             # no more interrupts are coming.
 */
              sig_off();
            }

            /* "cysignals/tests.pyx":807
 *     while True:
 *         try:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 sig_on()
 *                 ms_sleep(1000)
 */
            /*finally:*/ {
              /*normal exit:*/{
                #ifdef WITH_THREAD
                __Pyx_FastGIL_Forget();
                Py_BLOCK_THREADS
                #endif
                goto __pyx_L19;
              }
              __pyx_L18_error: {
                #ifdef WITH_THREAD
                __Pyx_FastGIL_Forget();
                Py_BLOCK_THREADS
                #endif
                goto __pyx_L7_error;
              }
              __pyx_L19:;
            }
        }

        /* "cysignals/tests.pyx":813
 *             # If 1 second passed since the last interrupt, we assume that
 *             # no more interrupts are coming.
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 break
 *         except KeyboardInterrupt:
 */
        __pyx_t_8 = ((__pyx_v_i > 0) != 0);
        if (__pyx_t_8) {

          /* "cysignals/tests.pyx":814
 *             # no more interrupts are coming.
 *             if i > 0:
 *                 break             # <<<<<<<<<<<<<<
 *         except KeyboardInterrupt:
 *             i += 1
 */
          goto __pyx_L12_try_break;

          /* "cysignals/tests.pyx":813
 *             # If 1 second passed since the last interrupt, we assume that
 *             # no more interrupts are coming.
 *             if i > 0:             # <<<<<<<<<<<<<<
 *                 break
 *         except KeyboardInterrupt:
 */
        }

        /* "cysignals/tests.pyx":806
 *     i = 0
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sig_on()
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L14_try_end;
      __pyx_L7_error:;

      /* "cysignals/tests.pyx":815
 *             if i > 0:
 *                 break
 *         except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *             i += 1
 *     print(f"Received {i}/{n*p} interrupts")
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cysignals.tests.test_interrupt_bomb", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0) __PYX_ERR(0, 815, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GOTREF(__pyx_t_11);

        /* "cysignals/tests.pyx":816
 *                 break
 *         except KeyboardInterrupt:
 *             i += 1             # <<<<<<<<<<<<<<
 *     print(f"Received {i}/{n*p} interrupts")
 * 
 */
        __pyx_v_i = (__pyx_v_i + 1);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "cysignals/tests.pyx":806
 *     i = 0
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 sig_on()
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L12_try_break:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L6_break;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L14_try_end:;
    }
  }
  __pyx_L6_break:;

  /* "cysignals/tests.pyx":817
 *         except KeyboardInterrupt:
 *             i += 1
 *     print(f"Received {i}/{n*p} interrupts")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_11 = PyTuple_New(5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = 0;
  __pyx_t_13 = 127;
  __Pyx_INCREF(__pyx_kp_u_Received);
  __pyx_t_12 += 9;
  __Pyx_GIVEREF(__pyx_kp_u_Received);
  PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u_Received);
  __pyx_t_10 = __Pyx_PyUnicode_From_long(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_10);
  __pyx_t_10 = 0;
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_t_12 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_kp_u__2);
  __pyx_t_10 = __Pyx_PyUnicode_From_long((__pyx_v_n * __pyx_v_p), 0, ' ', 'd'); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_10);
  __pyx_t_10 = 0;
  __Pyx_INCREF(__pyx_kp_u_interrupts);
  __pyx_t_12 += 11;
  __Pyx_GIVEREF(__pyx_kp_u_interrupts);
  PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_kp_u_interrupts);
  __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_11, 5, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "cysignals/tests.pyx":785
 * 
 * 
 * def test_interrupt_bomb(long n=100, long p=10):             # <<<<<<<<<<<<<<
 *     """
 *     Have `p` processes each sending `n` interrupts in very quick
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cysignals.tests.test_interrupt_bomb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":822
 * # Special thanks to Robert Bradshaw for suggesting the try/finally
 * # construction. -- Jeroen Demeyer
 * def test_try_finally_signal(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */

static PyObject *__pyx_pf_9cysignals_5tests_148__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_71test_try_finally_signal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_70test_try_finally_signal, "\n    Test a try/finally construct for sig_on() and sig_off(), raising\n    a signal inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_signal()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Aborted\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_71test_try_finally_signal = {"test_try_finally_signal", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_71test_try_finally_signal, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_70test_try_finally_signal};
static PyObject *__pyx_pw_9cysignals_5tests_71test_try_finally_signal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_try_finally_signal (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults20 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 822, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_try_finally_signal") < 0)) __PYX_ERR(0, 822, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 822, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_try_finally_signal", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 822, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_try_finally_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_70test_try_finally_signal(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_70test_try_finally_signal(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_try_finally_signal", 0);

  /* "cysignals/tests.pyx":836
 * 
 *     """
 *     sig_on()             # <<<<<<<<<<<<<<
 *     try:
 *         signal_after_delay(SIGABRT, delay)
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 836, __pyx_L1_error)

  /* "cysignals/tests.pyx":837
 *     """
 *     sig_on()
 *     try:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()
 */
  /*try:*/ {

    /* "cysignals/tests.pyx":838
 *     sig_on()
 *     try:
 *         signal_after_delay(SIGABRT, delay)             # <<<<<<<<<<<<<<
 *         infinite_loop()
 *     finally:
 */
    signal_after_delay(SIGABRT, __pyx_v_delay);

    /* "cysignals/tests.pyx":839
 *     try:
 *         signal_after_delay(SIGABRT, delay)
 *         infinite_loop()             # <<<<<<<<<<<<<<
 *     finally:
 *         sig_off()
 */
    __pyx_f_9cysignals_5tests_infinite_loop();
  }

  /* "cysignals/tests.pyx":841
 *         infinite_loop()
 *     finally:
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * def test_try_finally_raise():
 */
  /*finally:*/ {
    /*normal exit:*/{
      sig_off();
      goto __pyx_L5;
    }
    __pyx_L5:;
  }

  /* "cysignals/tests.pyx":822
 * # Special thanks to Robert Bradshaw for suggesting the try/finally
 * # construction. -- Jeroen Demeyer
 * def test_try_finally_signal(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_try_finally_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":843
 *         sig_off()
 * 
 * def test_try_finally_raise():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_73test_try_finally_raise(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_72test_try_finally_raise, "\n    Test a try/finally construct for sig_on() and sig_off(), raising\n    a Python exception inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_raise()\n        Traceback (most recent call last):\n        ...\n        RuntimeError: Everything ok!\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_73test_try_finally_raise = {"test_try_finally_raise", (PyCFunction)__pyx_pw_9cysignals_5tests_73test_try_finally_raise, METH_NOARGS, __pyx_doc_9cysignals_5tests_72test_try_finally_raise};
static PyObject *__pyx_pw_9cysignals_5tests_73test_try_finally_raise(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_try_finally_raise (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_72test_try_finally_raise(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_72test_try_finally_raise(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_try_finally_raise", 0);

  /* "cysignals/tests.pyx":857
 * 
 *     """
 *     sig_on()             # <<<<<<<<<<<<<<
 *     try:
 *         raise RuntimeError, "Everything ok!"
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 857, __pyx_L1_error)

  /* "cysignals/tests.pyx":858
 *     """
 *     sig_on()
 *     try:             # <<<<<<<<<<<<<<
 *         raise RuntimeError, "Everything ok!"
 *     finally:
 */
  /*try:*/ {

    /* "cysignals/tests.pyx":859
 *     sig_on()
 *     try:
 *         raise RuntimeError, "Everything ok!"             # <<<<<<<<<<<<<<
 *     finally:
 *         sig_off()
 */
    __Pyx_Raise(__pyx_builtin_RuntimeError, __pyx_kp_s_Everything_ok, 0, 0);
    __PYX_ERR(0, 859, __pyx_L4_error)
  }

  /* "cysignals/tests.pyx":861
 *         raise RuntimeError, "Everything ok!"
 *     finally:
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * def test_try_finally_return():
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0)) __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __pyx_t_1 = __pyx_lineno; __pyx_t_2 = __pyx_clineno; __pyx_t_3 = __pyx_filename;
      {
        sig_off();
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0;
      __pyx_lineno = __pyx_t_1; __pyx_clineno = __pyx_t_2; __pyx_filename = __pyx_t_3;
      goto __pyx_L1_error;
    }
  }

  /* "cysignals/tests.pyx":843
 *         sig_off()
 * 
 * def test_try_finally_raise():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_try_finally_raise", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":863
 *         sig_off()
 * 
 * def test_try_finally_return():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), doing a
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_75test_try_finally_return(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_74test_try_finally_return, "\n    Test a try/finally construct for sig_on() and sig_off(), doing a\n    normal ``return`` inside the ``try``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_try_finally_return()\n        'Everything ok!'\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_75test_try_finally_return = {"test_try_finally_return", (PyCFunction)__pyx_pw_9cysignals_5tests_75test_try_finally_return, METH_NOARGS, __pyx_doc_9cysignals_5tests_74test_try_finally_return};
static PyObject *__pyx_pw_9cysignals_5tests_75test_try_finally_return(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_try_finally_return (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_74test_try_finally_return(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_74test_try_finally_return(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_try_finally_return", 0);

  /* "cysignals/tests.pyx":875
 * 
 *     """
 *     sig_on()             # <<<<<<<<<<<<<<
 *     try:
 *         return "Everything ok!"
 */
  __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 875, __pyx_L1_error)

  /* "cysignals/tests.pyx":876
 *     """
 *     sig_on()
 *     try:             # <<<<<<<<<<<<<<
 *         return "Everything ok!"
 *     finally:
 */
  /*try:*/ {

    /* "cysignals/tests.pyx":877
 *     sig_on()
 *     try:
 *         return "Everything ok!"             # <<<<<<<<<<<<<<
 *     finally:
 *         sig_off()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_s_Everything_ok);
    __pyx_r = __pyx_kp_s_Everything_ok;
    goto __pyx_L3_return;
  }

  /* "cysignals/tests.pyx":879
 *         return "Everything ok!"
 *     finally:
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    __pyx_L3_return: {
      __pyx_t_2 = __pyx_r;
      __pyx_r = 0;
      sig_off();
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
    }
  }

  /* "cysignals/tests.pyx":863
 *         sig_off()
 * 
 * def test_try_finally_return():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), doing a
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_try_finally_return", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":886
 * ########################################################################
 * 
 * def print_sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Print the exception which is currently being handled.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_77print_sig_occurred(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_76print_sig_occurred, "\n    Print the exception which is currently being handled.\n\n    Note that we print instead of return the exception to mess as little\n    as possible with refcounts.\n\n    EXAMPLES::\n\n        >>> from cysignals.tests import *\n        >>> print_sig_occurred()\n        No current exception\n\n    In Python 3 and in Cython, the exception remains alive only inside\n    the ``except`` clause handling the exception. In Python 2, it stays\n    alive as long as the stack frame where it was raised is still running\n    and calling ``sys.exc_clear()`` clears it::\n\n        >>> import sys\n        >>> from cysignals.alarm import alarm\n        >>> if hasattr(sys, \"exc_clear\"):\n        ...     # Python 2\n        ...     def testfunc():\n        ...         try:\n        ...             alarm(0.1)\n        ...             while True:\n        ...                pass\n        ...         except KeyboardInterrupt:\n        ...             pass\n        ...         print_sig_occurred()\n        ...         sys.exc_clear()\n        ...         print_sig_occurred()\n        ... else:\n        ...     # Python 3\n        ...     def testfunc():\n        ...         try:\n        ...             alarm(0.1)\n        ...             while True:\n        ...                pass\n        ...         except KeyboardInterrupt:\n        ...             print_sig_occurred()\n        ...         print_sig_occurred()\n        >>> testfunc()\n        AlarmInterrupt\n        No current exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_77print_sig_occurred = {"print_sig_occurred", (PyCFunction)__pyx_pw_9cysignals_5tests_77print_sig_occurred, METH_NOARGS, __pyx_doc_9cysignals_5tests_76print_sig_occurred};
static PyObject *__pyx_pw_9cysignals_5tests_77print_sig_occurred(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("print_sig_occurred (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_76print_sig_occurred(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_76print_sig_occurred(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("print_sig_occurred", 0);

  /* "cysignals/tests.pyx":933
 * 
 *     """
 *     exc = sig_occurred()             # <<<<<<<<<<<<<<
 *     try:
 *         cython_check_exception()
 */
  __pyx_v_exc = __pyx_f_9cysignals_7signals_sig_occurred();

  /* "cysignals/tests.pyx":934
 *     """
 *     exc = sig_occurred()
 *     try:             # <<<<<<<<<<<<<<
 *         cython_check_exception()
 *     finally:
 */
  /*try:*/ {

    /* "cysignals/tests.pyx":935
 *     exc = sig_occurred()
 *     try:
 *         cython_check_exception()             # <<<<<<<<<<<<<<
 *     finally:
 *         if exc is NULL:
 */
    __pyx_f_9cysignals_7signals_cython_check_exception(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 935, __pyx_L4_error)
  }

  /* "cysignals/tests.pyx":937
 *         cython_check_exception()
 *     finally:
 *         if exc is NULL:             # <<<<<<<<<<<<<<
 *             print("No current exception")
 *         else:
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_1 = ((__pyx_v_exc == NULL) != 0);
      if (__pyx_t_1) {

        /* "cysignals/tests.pyx":938
 *     finally:
 *         if exc is NULL:
 *             print("No current exception")             # <<<<<<<<<<<<<<
 *         else:
 *             e = <object>exc
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 938, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cysignals/tests.pyx":937
 *         cython_check_exception()
 *     finally:
 *         if exc is NULL:             # <<<<<<<<<<<<<<
 *             print("No current exception")
 *         else:
 */
        goto __pyx_L6;
      }

      /* "cysignals/tests.pyx":940
 *             print("No current exception")
 *         else:
 *             e = <object>exc             # <<<<<<<<<<<<<<
 *             t = str(e)
 *             if t:
 */
      /*else*/ {
        __pyx_t_2 = ((PyObject *)__pyx_v_exc);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_v_e = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "cysignals/tests.pyx":941
 *         else:
 *             e = <object>exc
 *             t = str(e)             # <<<<<<<<<<<<<<
 *             if t:
 *                 t = ": " + t
 */
        __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 941, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_t = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "cysignals/tests.pyx":942
 *             e = <object>exc
 *             t = str(e)
 *             if t:             # <<<<<<<<<<<<<<
 *                 t = ": " + t
 *             print(type(e).__name__ + t)
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 942, __pyx_L1_error)
        if (__pyx_t_1) {

          /* "cysignals/tests.pyx":943
 *             t = str(e)
 *             if t:
 *                 t = ": " + t             # <<<<<<<<<<<<<<
 *             print(type(e).__name__ + t)
 * 
 */
          __pyx_t_2 = PyNumber_Add(__pyx_kp_s__4, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 943, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_t, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "cysignals/tests.pyx":942
 *             e = <object>exc
 *             t = str(e)
 *             if t:             # <<<<<<<<<<<<<<
 *                 t = ": " + t
 *             print(type(e).__name__ + t)
 */
        }

        /* "cysignals/tests.pyx":944
 *             if t:
 *                 t = ": " + t
 *             print(type(e).__name__ + t)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_e)), __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 944, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 944, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 944, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L6:;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {

        /* "cysignals/tests.pyx":937
 *         cython_check_exception()
 *     finally:
 *         if exc is NULL:             # <<<<<<<<<<<<<<
 *             print("No current exception")
 *         else:
 */
        __pyx_t_1 = ((__pyx_v_exc == NULL) != 0);
        if (__pyx_t_1) {

          /* "cysignals/tests.pyx":938
 *     finally:
 *         if exc is NULL:
 *             print("No current exception")             # <<<<<<<<<<<<<<
 *         else:
 *             e = <object>exc
 */
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 938, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "cysignals/tests.pyx":937
 *         cython_check_exception()
 *     finally:
 *         if exc is NULL:             # <<<<<<<<<<<<<<
 *             print("No current exception")
 *         else:
 */
          goto __pyx_L10;
        }

        /* "cysignals/tests.pyx":940
 *             print("No current exception")
 *         else:
 *             e = <object>exc             # <<<<<<<<<<<<<<
 *             t = str(e)
 *             if t:
 */
        /*else*/ {
          __pyx_t_2 = ((PyObject *)__pyx_v_exc);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_v_e = __pyx_t_2;
          __pyx_t_2 = 0;

          /* "cysignals/tests.pyx":941
 *         else:
 *             e = <object>exc
 *             t = str(e)             # <<<<<<<<<<<<<<
 *             if t:
 *                 t = ": " + t
 */
          __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 941, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_v_t = __pyx_t_2;
          __pyx_t_2 = 0;

          /* "cysignals/tests.pyx":942
 *             e = <object>exc
 *             t = str(e)
 *             if t:             # <<<<<<<<<<<<<<
 *                 t = ": " + t
 *             print(type(e).__name__ + t)
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 942, __pyx_L9_error)
          if (__pyx_t_1) {

            /* "cysignals/tests.pyx":943
 *             t = str(e)
 *             if t:
 *                 t = ": " + t             # <<<<<<<<<<<<<<
 *             print(type(e).__name__ + t)
 * 
 */
            __pyx_t_2 = PyNumber_Add(__pyx_kp_s__4, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 943, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF_SET(__pyx_v_t, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "cysignals/tests.pyx":942
 *             e = <object>exc
 *             t = str(e)
 *             if t:             # <<<<<<<<<<<<<<
 *                 t = ": " + t
 *             print(type(e).__name__ + t)
 */
          }

          /* "cysignals/tests.pyx":944
 *             if t:
 *                 t = ": " + t
 *             print(type(e).__name__ + t)             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_e)), __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 944, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 944, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 944, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_L10:;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
      __pyx_L9_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "cysignals/tests.pyx":886
 * ########################################################################
 * 
 * def print_sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Print the exception which is currently being handled.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.tests.print_sig_occurred", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":947
 * 
 * 
 * def test_sig_occurred_finally():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_79test_sig_occurred_finally(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_78test_sig_occurred_finally, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_occurred_finally()\n        No current exception\n        RuntimeError: test_sig_occurred_finally()\n        RuntimeError: test_sig_occurred_finally()\n        No current exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_79test_sig_occurred_finally = {"test_sig_occurred_finally", (PyCFunction)__pyx_pw_9cysignals_5tests_79test_sig_occurred_finally, METH_NOARGS, __pyx_doc_9cysignals_5tests_78test_sig_occurred_finally};
static PyObject *__pyx_pw_9cysignals_5tests_79test_sig_occurred_finally(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_occurred_finally (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_78test_sig_occurred_finally(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_78test_sig_occurred_finally(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_occurred_finally", 0);

  /* "cysignals/tests.pyx":959
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         try:
 *             sig_str("test_sig_occurred_finally()")
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":960
 *     """
 *     try:
 *         try:             # <<<<<<<<<<<<<<
 *             sig_str("test_sig_occurred_finally()")
 *         finally:
 */
      /*try:*/ {

        /* "cysignals/tests.pyx":961
 *     try:
 *         try:
 *             sig_str("test_sig_occurred_finally()")             # <<<<<<<<<<<<<<
 *         finally:
 *             print_sig_occurred()  # output 1 and 2
 */
        __pyx_t_4 = sig_str(((char const *)"test_sig_occurred_finally()")); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 961, __pyx_L10_error)
      }

      /* "cysignals/tests.pyx":963
 *             sig_str("test_sig_occurred_finally()")
 *         finally:
 *             print_sig_occurred()  # output 1 and 2             # <<<<<<<<<<<<<<
 *     except RuntimeError:
 *         print_sig_occurred()  # output 3
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 963, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = NULL;
          __pyx_t_4 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_4 = 1;
            }
          }
          {
            PyObject *__pyx_callargs[1] = {__pyx_t_7, };
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 963, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          goto __pyx_L11;
        }
        __pyx_L10_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_4 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
          {
            __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 963, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_7 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
                __pyx_t_16 = 1;
              }
            }
            {
              PyObject *__pyx_callargs[1] = {__pyx_t_7, };
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_16, 0+__pyx_t_16);
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 963, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            }
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          }
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
          __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
          goto __pyx_L3_error;
          __pyx_L13_error:;
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          }
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
          goto __pyx_L3_error;
        }
        __pyx_L11:;
      }

      /* "cysignals/tests.pyx":959
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         try:
 *             sig_str("test_sig_occurred_finally()")
 */
    }

    /* "cysignals/tests.pyx":967
 *         print_sig_occurred()  # output 3
 *     else:
 *         abort()             # <<<<<<<<<<<<<<
 *     print_sig_occurred()  # output 4
 * 
 */
    /*else:*/ {
      abort();
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cysignals/tests.pyx":964
 *         finally:
 *             print_sig_occurred()  # output 1 and 2
 *     except RuntimeError:             # <<<<<<<<<<<<<<
 *         print_sig_occurred()  # output 3
 *     else:
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_RuntimeError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cysignals.tests.test_sig_occurred_finally", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 964, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cysignals/tests.pyx":965
 *             print_sig_occurred()  # output 1 and 2
 *     except RuntimeError:
 *         print_sig_occurred()  # output 3             # <<<<<<<<<<<<<<
 *     else:
 *         abort()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 965, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __pyx_t_19 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_18))) {
        __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_18);
        if (likely(__pyx_t_19)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
          __Pyx_INCREF(__pyx_t_19);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_18, function);
          __pyx_t_8 = 1;
        }
      }
      {
        PyObject *__pyx_callargs[1] = {__pyx_t_19, };
        __pyx_t_17 = __Pyx_PyObject_FastCall(__pyx_t_18, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 965, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":959
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         try:
 *             sig_str("test_sig_occurred_finally()")
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cysignals/tests.pyx":968
 *     else:
 *         abort()
 *     print_sig_occurred()  # output 4             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_5, };
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cysignals/tests.pyx":947
 * 
 * 
 * def test_sig_occurred_finally():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("cysignals.tests.test_sig_occurred_finally", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":971
 * 
 * 
 * def test_sig_occurred_live_exception():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_81test_sig_occurred_live_exception(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_80test_sig_occurred_live_exception, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> try:\n        ...     test_sig_occurred_live_exception()\n        ... except RuntimeError:\n        ...     pass\n        RuntimeError: Aborted\n        >>> print_sig_occurred()\n        No current exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_81test_sig_occurred_live_exception = {"test_sig_occurred_live_exception", (PyCFunction)__pyx_pw_9cysignals_5tests_81test_sig_occurred_live_exception, METH_NOARGS, __pyx_doc_9cysignals_5tests_80test_sig_occurred_live_exception};
static PyObject *__pyx_pw_9cysignals_5tests_81test_sig_occurred_live_exception(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_occurred_live_exception (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_80test_sig_occurred_live_exception(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_80test_sig_occurred_live_exception(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_occurred_live_exception", 0);

  /* "cysignals/tests.pyx":985
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         print_sig_occurred()
 *     sig_error()
 */
  __pyx_t_1 = ((!(sig_on() != 0)) != 0);
  if (__pyx_t_1) {

    /* "cysignals/tests.pyx":986
 *     """
 *     if not sig_on_no_except():
 *         print_sig_occurred()             # <<<<<<<<<<<<<<
 *     sig_error()
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[1] = {__pyx_t_4, };
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 986, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cysignals/tests.pyx":985
 * 
 *     """
 *     if not sig_on_no_except():             # <<<<<<<<<<<<<<
 *         print_sig_occurred()
 *     sig_error()
 */
  }

  /* "cysignals/tests.pyx":987
 *     if not sig_on_no_except():
 *         print_sig_occurred()
 *     sig_error()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  sig_error();

  /* "cysignals/tests.pyx":971
 * 
 * 
 * def test_sig_occurred_live_exception():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cysignals.tests.test_sig_occurred_live_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":990
 * 
 * 
 * def test_sig_occurred_dealloc():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_83test_sig_occurred_dealloc(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_82test_sig_occurred_dealloc, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> try:\n        ...     test_sig_occurred_dealloc()\n        ... except RuntimeError:\n        ...     pass\n        __dealloc__: RuntimeError: test_sig_occurred_dealloc()\n        >>> print_sig_occurred()\n        No current exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_83test_sig_occurred_dealloc = {"test_sig_occurred_dealloc", (PyCFunction)__pyx_pw_9cysignals_5tests_83test_sig_occurred_dealloc, METH_NOARGS, __pyx_doc_9cysignals_5tests_82test_sig_occurred_dealloc};
static PyObject *__pyx_pw_9cysignals_5tests_83test_sig_occurred_dealloc(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_occurred_dealloc (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_82test_sig_occurred_dealloc(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_82test_sig_occurred_dealloc(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_occurred_dealloc", 0);

  /* "cysignals/tests.pyx":1004
 * 
 *     """
 *     x = DeallocDebug()             # <<<<<<<<<<<<<<
 *     sig_str("test_sig_occurred_dealloc()")
 *     abort()
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_9cysignals_5tests_DeallocDebug)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_x = ((struct __pyx_obj_9cysignals_5tests_DeallocDebug *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1005
 *     """
 *     x = DeallocDebug()
 *     sig_str("test_sig_occurred_dealloc()")             # <<<<<<<<<<<<<<
 *     abort()
 * 
 */
  __pyx_t_2 = sig_str(((char const *)"test_sig_occurred_dealloc()")); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(0, 1005, __pyx_L1_error)

  /* "cysignals/tests.pyx":1006
 *     x = DeallocDebug()
 *     sig_str("test_sig_occurred_dealloc()")
 *     abort()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  abort();

  /* "cysignals/tests.pyx":990
 * 
 * 
 * def test_sig_occurred_dealloc():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cysignals.tests.test_sig_occurred_dealloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1009
 * 
 * 
 * def test_sig_occurred_dealloc_in_gc():             # <<<<<<<<<<<<<<
 *     """
 *     Regression test for https://github.com/sagemath/cysignals/issues/126
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_85test_sig_occurred_dealloc_in_gc(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_84test_sig_occurred_dealloc_in_gc, "\n    Regression test for https://github.com/sagemath/cysignals/issues/126\n\n    TESTS:\n\n    The first part of this is similar to ``test_sig_occurred_dealloc()`` but we\n    keep a reference to the exception so it doesn't go away right away::\n\n        >>> from cysignals.tests import *\n        >>> import sys\n        >>> e = None\n        >>> try:\n        ...     test_sig_occurred_dealloc_in_gc()\n        ... except RuntimeError as exc:\n        ...     e = exc\n        >>> print_sig_occurred()\n        RuntimeError: test_sig_occurred_dealloc_in_gc()\n\n    Python 2 keeps the target of the \"except as\" in local scope, so make sure\n    to delete it as well::\n\n        >>> if sys.version_info[0] < 3: del exc\n\n    Put the exception into a list containing a reference to itself, so that\n    when the garbage collector runs (in ``verify_exc_value``) its reference\n    count drops to 1.  Also include a ``DeallocDebug`` so that\n    ``sig_occurred()`` is called during GC.\n\n    We also temporarily disable automatic GC to ensure that the garbage\n    collector is not called except by ``verify_exc_value()``::\n\n        >>> import gc\n        >>> l = [DeallocDebug(), e]\n        >>> l.append(l)\n        >>> gc.disable()\n        >>> try:\n        ...     del l, e\n        ...     print_sig_occurred()\n        ... finally:\n        ...     gc.enable()\n        __dealloc__: No current exception\n        No current exception\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_85test_sig_occurred_dealloc_in_gc = {"test_sig_occurred_dealloc_in_gc", (PyCFunction)__pyx_pw_9cysignals_5tests_85test_sig_occurred_dealloc_in_gc, METH_NOARGS, __pyx_doc_9cysignals_5tests_84test_sig_occurred_dealloc_in_gc};
static PyObject *__pyx_pw_9cysignals_5tests_85test_sig_occurred_dealloc_in_gc(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_occurred_dealloc_in_gc (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_84test_sig_occurred_dealloc_in_gc(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_84test_sig_occurred_dealloc_in_gc(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_occurred_dealloc_in_gc", 0);

  /* "cysignals/tests.pyx":1054
 * 
 *     """
 *     sig_str("test_sig_occurred_dealloc_in_gc()")             # <<<<<<<<<<<<<<
 *     abort()
 * 
 */
  __pyx_t_1 = sig_str(((char const *)"test_sig_occurred_dealloc_in_gc()")); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 1054, __pyx_L1_error)

  /* "cysignals/tests.pyx":1055
 *     """
 *     sig_str("test_sig_occurred_dealloc_in_gc()")
 *     abort()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  abort();

  /* "cysignals/tests.pyx":1009
 * 
 * 
 * def test_sig_occurred_dealloc_in_gc():             # <<<<<<<<<<<<<<
 *     """
 *     Regression test for https://github.com/sagemath/cysignals/issues/126
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_occurred_dealloc_in_gc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1059
 * 
 * cdef class DeallocDebug:
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         sys.stdout.write("__dealloc__: ")
 *         print_sig_occurred()
 */

/* Python wrapper */
static void __pyx_pw_9cysignals_5tests_12DeallocDebug_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9cysignals_5tests_12DeallocDebug_1__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_9cysignals_5tests_12DeallocDebug___dealloc__(((struct __pyx_obj_9cysignals_5tests_DeallocDebug *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9cysignals_5tests_12DeallocDebug___dealloc__(CYTHON_UNUSED struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "cysignals/tests.pyx":1060
 * cdef class DeallocDebug:
 *     def __dealloc__(self):
 *         sys.stdout.write("__dealloc__: ")             # <<<<<<<<<<<<<<
 *         print_sig_occurred()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stdout); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_s_dealloc};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1061
 *     def __dealloc__(self):
 *         sys.stdout.write("__dealloc__: ")
 *         print_sig_occurred()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_print_sig_occurred); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_3, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1061, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1059
 * 
 * cdef class DeallocDebug:
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         sys.stdout.write("__dealloc__: ")
 *         print_sig_occurred()
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("cysignals.tests.DeallocDebug.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_12DeallocDebug_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_12DeallocDebug_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_12DeallocDebug_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_12DeallocDebug_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9cysignals_5tests_12DeallocDebug_2__reduce_cython__(((struct __pyx_obj_9cysignals_5tests_DeallocDebug *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_12DeallocDebug_2__reduce_cython__(struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_DeallocDebug); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_228825662);
    __Pyx_GIVEREF(__pyx_int_228825662);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_228825662);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, None), state
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_DeallocDebug); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_228825662);
    __Pyx_GIVEREF(__pyx_int_228825662);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_228825662);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cysignals.tests.DeallocDebug.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_12DeallocDebug_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_12DeallocDebug_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_12DeallocDebug_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_12DeallocDebug_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    #endif
    PyObject* values[1] = {0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.DeallocDebug.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_12DeallocDebug_4__setstate_cython__(((struct __pyx_obj_9cysignals_5tests_DeallocDebug *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_12DeallocDebug_4__setstate_cython__(struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_9cysignals_5tests___pyx_unpickle_DeallocDebug__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cysignals.tests.DeallocDebug.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1067
 * # Test sig_block()/sig_unblock()                                       #
 * ########################################################################
 * def test_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_150__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_87test_sig_block(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_86test_sig_block, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block()\n        42\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_87test_sig_block = {"test_sig_block", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_87test_sig_block, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_86test_sig_block};
static PyObject *__pyx_pw_9cysignals_5tests_87test_sig_block(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_block (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults21 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1067, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_block") < 0)) __PYX_ERR(0, 1067, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1067, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_block", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1067, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_86test_sig_block(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_86test_sig_block(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  volatile int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_block", 0);

  /* "cysignals/tests.pyx":1076
 * 
 *     """
 *     cdef volatile_int v = 0             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_v_v = 0;

  /* "cysignals/tests.pyx":1078
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":1079
 * 
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_block()
 */
      {
          #ifdef WITH_THREAD
          PyThreadState *_save;
          Py_UNBLOCK_THREADS
          __Pyx_FastGIL_Remember();
          #endif
          /*try:*/ {

            /* "cysignals/tests.pyx":1080
 *     try:
 *         with nogil:
 *             sig_on()             # <<<<<<<<<<<<<<
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)
 */
            __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1080, __pyx_L10_error)

            /* "cysignals/tests.pyx":1081
 *         with nogil:
 *             sig_on()
 *             sig_block()             # <<<<<<<<<<<<<<
 *             signal_after_delay(SIGINT, delay)
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 */
            sig_block();

            /* "cysignals/tests.pyx":1082
 *             sig_on()
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             v = 42
 */
            signal_after_delay(SIGINT, __pyx_v_delay);

            /* "cysignals/tests.pyx":1083
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)
 *             ms_sleep(delay * 2)  # We get signaled during this sleep             # <<<<<<<<<<<<<<
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled
 */
            ms_sleep((__pyx_v_delay * 2));

            /* "cysignals/tests.pyx":1084
 *             signal_after_delay(SIGINT, delay)
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             v = 42             # <<<<<<<<<<<<<<
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()
 */
            __pyx_v_v = 42;

            /* "cysignals/tests.pyx":1085
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled             # <<<<<<<<<<<<<<
 *             sig_off()
 *     except KeyboardInterrupt:
 */
            sig_unblock();

            /* "cysignals/tests.pyx":1086
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         return v
 */
            sig_off();
          }

          /* "cysignals/tests.pyx":1079
 * 
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_block()
 */
          /*finally:*/ {
            /*normal exit:*/{
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L11;
            }
            __pyx_L10_error: {
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L3_error;
            }
            __pyx_L11:;
          }
      }

      /* "cysignals/tests.pyx":1078
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "cysignals/tests.pyx":1087
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         return v
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cysignals.tests.test_sig_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1087, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cysignals/tests.pyx":1088
 *             sig_off()
 *     except KeyboardInterrupt:
 *         return v             # <<<<<<<<<<<<<<
 * 
 *     # Never reached
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyInt_From_volatile__int(__pyx_v_v); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1088, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":1078
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "cysignals/tests.pyx":1091
 * 
 *     # Never reached
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * def test_sig_block_nested(long delay=DEFAULT_DELAY):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_1);
  __pyx_r = __pyx_int_1;
  goto __pyx_L0;

  /* "cysignals/tests.pyx":1067
 * # Test sig_block()/sig_unblock()                                       #
 * ########################################################################
 * def test_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cysignals.tests.test_sig_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1093
 *     return 1
 * 
 * def test_sig_block_nested(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_152__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_89test_sig_block_nested(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_88test_sig_block_nested, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block_nested()\n        42\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_89test_sig_block_nested = {"test_sig_block_nested", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_89test_sig_block_nested, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_88test_sig_block_nested};
static PyObject *__pyx_pw_9cysignals_5tests_89test_sig_block_nested(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_block_nested (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults22 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1093, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_block_nested") < 0)) __PYX_ERR(0, 1093, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1093, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_block_nested", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1093, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_block_nested", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_88test_sig_block_nested(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_88test_sig_block_nested(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  volatile int __pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_block_nested", 0);

  /* "cysignals/tests.pyx":1102
 * 
 *     """
 *     cdef volatile_int v = 0             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_v_v = 0;

  /* "cysignals/tests.pyx":1104
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":1105
 * 
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_block()
 */
      {
          #ifdef WITH_THREAD
          PyThreadState *_save;
          Py_UNBLOCK_THREADS
          __Pyx_FastGIL_Remember();
          #endif
          /*try:*/ {

            /* "cysignals/tests.pyx":1106
 *     try:
 *         with nogil:
 *             sig_on()             # <<<<<<<<<<<<<<
 *             sig_block()
 *             sig_block()
 */
            __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1106, __pyx_L10_error)

            /* "cysignals/tests.pyx":1107
 *         with nogil:
 *             sig_on()
 *             sig_block()             # <<<<<<<<<<<<<<
 *             sig_block()
 *             sig_block()
 */
            sig_block();

            /* "cysignals/tests.pyx":1108
 *             sig_on()
 *             sig_block()
 *             sig_block()             # <<<<<<<<<<<<<<
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)
 */
            sig_block();

            /* "cysignals/tests.pyx":1109
 *             sig_block()
 *             sig_block()
 *             sig_block()             # <<<<<<<<<<<<<<
 *             signal_after_delay(SIGINT, delay)
 *             sig_unblock()
 */
            sig_block();

            /* "cysignals/tests.pyx":1110
 *             sig_block()
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *             sig_unblock()
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 */
            signal_after_delay(SIGINT, __pyx_v_delay);

            /* "cysignals/tests.pyx":1111
 *             sig_block()
 *             signal_after_delay(SIGINT, delay)
 *             sig_unblock()             # <<<<<<<<<<<<<<
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             sig_check()
 */
            sig_unblock();

            /* "cysignals/tests.pyx":1112
 *             signal_after_delay(SIGINT, delay)
 *             sig_unblock()
 *             ms_sleep(delay * 2)  # We get signaled during this sleep             # <<<<<<<<<<<<<<
 *             sig_check()
 *             sig_unblock()
 */
            ms_sleep((__pyx_v_delay * 2));

            /* "cysignals/tests.pyx":1113
 *             sig_unblock()
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             sig_check()             # <<<<<<<<<<<<<<
 *             sig_unblock()
 *             sig_on()
 */
            __pyx_t_4 = sig_check(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1113, __pyx_L10_error)

            /* "cysignals/tests.pyx":1114
 *             ms_sleep(delay * 2)  # We get signaled during this sleep
 *             sig_check()
 *             sig_unblock()             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_off()
 */
            sig_unblock();

            /* "cysignals/tests.pyx":1115
 *             sig_check()
 *             sig_unblock()
 *             sig_on()             # <<<<<<<<<<<<<<
 *             sig_off()
 *             v = 42
 */
            __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1115, __pyx_L10_error)

            /* "cysignals/tests.pyx":1116
 *             sig_unblock()
 *             sig_on()
 *             sig_off()             # <<<<<<<<<<<<<<
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled
 */
            sig_off();

            /* "cysignals/tests.pyx":1117
 *             sig_on()
 *             sig_off()
 *             v = 42             # <<<<<<<<<<<<<<
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()
 */
            __pyx_v_v = 42;

            /* "cysignals/tests.pyx":1118
 *             sig_off()
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled             # <<<<<<<<<<<<<<
 *             sig_off()
 *     except KeyboardInterrupt:
 */
            sig_unblock();

            /* "cysignals/tests.pyx":1119
 *             v = 42
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         return v
 */
            sig_off();
          }

          /* "cysignals/tests.pyx":1105
 * 
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_block()
 */
          /*finally:*/ {
            /*normal exit:*/{
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L11;
            }
            __pyx_L10_error: {
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L3_error;
            }
            __pyx_L11:;
          }
      }

      /* "cysignals/tests.pyx":1104
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "cysignals/tests.pyx":1120
 *             sig_unblock()        # Here, the interrupt will be handled
 *             sig_off()
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         return v
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cysignals.tests.test_sig_block_nested", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1120, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cysignals/tests.pyx":1121
 *             sig_off()
 *     except KeyboardInterrupt:
 *         return v             # <<<<<<<<<<<<<<
 * 
 *     # Never reached
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyInt_From_volatile__int(__pyx_v_v); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1121, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":1104
 *     cdef volatile_int v = 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             sig_on()
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "cysignals/tests.pyx":1124
 * 
 *     # Never reached
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * def test_sig_block_outside_sig_on(long delay=DEFAULT_DELAY):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_1);
  __pyx_r = __pyx_int_1;
  goto __pyx_L0;

  /* "cysignals/tests.pyx":1093
 *     return 1
 * 
 * def test_sig_block_nested(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cysignals.tests.test_sig_block_nested", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1126
 *     return 1
 * 
 * def test_sig_block_outside_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

static PyObject *__pyx_pf_9cysignals_5tests_154__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_91test_sig_block_outside_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_90test_sig_block_outside_sig_on, "\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sig_block_outside_sig_on()\n        'Success'\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_91test_sig_block_outside_sig_on = {"test_sig_block_outside_sig_on", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_91test_sig_block_outside_sig_on, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_90test_sig_block_outside_sig_on};
static PyObject *__pyx_pw_9cysignals_5tests_91test_sig_block_outside_sig_on(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sig_block_outside_sig_on (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults23 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1126, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sig_block_outside_sig_on") < 0)) __PYX_ERR(0, 1126, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1126, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sig_block_outside_sig_on", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1126, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sig_block_outside_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_90test_sig_block_outside_sig_on(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_90test_sig_block_outside_sig_on(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sig_block_outside_sig_on", 0);

  /* "cysignals/tests.pyx":1135
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 * 
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1136
 *     """
 *     with nogil:
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 * 
 *         # sig_block()/sig_unblock() shouldn't do anything
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":1140
 *         # sig_block()/sig_unblock() shouldn't do anything
 *         # since we're outside of sig_on()
 *         sig_block()             # <<<<<<<<<<<<<<
 *         sig_block()
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 */
        sig_block();

        /* "cysignals/tests.pyx":1141
 *         # since we're outside of sig_on()
 *         sig_block()
 *         sig_block()             # <<<<<<<<<<<<<<
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_unblock()
 */
        sig_block();

        /* "cysignals/tests.pyx":1142
 *         sig_block()
 *         sig_block()
 *         ms_sleep(delay * 2)  # We get signaled during this sleep             # <<<<<<<<<<<<<<
 *         sig_unblock()
 *         sig_unblock()
 */
        ms_sleep((__pyx_v_delay * 2));

        /* "cysignals/tests.pyx":1143
 *         sig_block()
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_unblock()             # <<<<<<<<<<<<<<
 *         sig_unblock()
 * 
 */
        sig_unblock();

        /* "cysignals/tests.pyx":1144
 *         ms_sleep(delay * 2)  # We get signaled during this sleep
 *         sig_unblock()
 *         sig_unblock()             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
        sig_unblock();
      }

      /* "cysignals/tests.pyx":1135
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1146
 *         sig_unblock()
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         sig_on()  # Interrupt caught here
 *     except KeyboardInterrupt:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":1147
 * 
 *     try:
 *         sig_on()  # Interrupt caught here             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         return "Success"
 */
      __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1147, __pyx_L6_error)

      /* "cysignals/tests.pyx":1146
 *         sig_unblock()
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         sig_on()  # Interrupt caught here
 *     except KeyboardInterrupt:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;

    /* "cysignals/tests.pyx":1148
 *     try:
 *         sig_on()  # Interrupt caught here
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         return "Success"
 *     abort()   # This should not be reached
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_4) {
      __Pyx_AddTraceback("cysignals.tests.test_sig_block_outside_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1148, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cysignals/tests.pyx":1149
 *         sig_on()  # Interrupt caught here
 *     except KeyboardInterrupt:
 *         return "Success"             # <<<<<<<<<<<<<<
 *     abort()   # This should not be reached
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_n_s_Success);
      __pyx_r = __pyx_n_s_Success;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L9_except_return;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "cysignals/tests.pyx":1146
 *         sig_unblock()
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         sig_on()  # Interrupt caught here
 *     except KeyboardInterrupt:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L9_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L11_try_end:;
  }

  /* "cysignals/tests.pyx":1150
 *     except KeyboardInterrupt:
 *         return "Success"
 *     abort()   # This should not be reached             # <<<<<<<<<<<<<<
 * 
 * def test_signal_during_malloc(long delay=DEFAULT_DELAY):
 */
  abort();

  /* "cysignals/tests.pyx":1126
 *     return 1
 * 
 * def test_sig_block_outside_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cysignals.tests.test_sig_block_outside_sig_on", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1152
 *     abort()   # This should not be reached
 * 
 * def test_signal_during_malloc(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a signal arriving during a sig_malloc() or sig_free() call.
 */

static PyObject *__pyx_pf_9cysignals_5tests_156__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_93test_signal_during_malloc(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_92test_signal_during_malloc, "\n    Test a signal arriving during a sig_malloc() or sig_free() call.\n    Since these are wrapped with sig_block()/sig_unblock(), we should\n    safely be able to interrupt them.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> for i in range(5):  # Several times to reduce chances of false positive\n        ...     test_signal_during_malloc()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_93test_signal_during_malloc = {"test_signal_during_malloc", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_93test_signal_during_malloc, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_92test_signal_during_malloc};
static PyObject *__pyx_pw_9cysignals_5tests_93test_signal_during_malloc(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_signal_during_malloc (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults24 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1152, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_signal_during_malloc") < 0)) __PYX_ERR(0, 1152, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1152, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_signal_during_malloc", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1152, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_during_malloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_92test_signal_during_malloc(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_92test_signal_during_malloc(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_signal_during_malloc", 0);

  /* "cysignals/tests.pyx":1165
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             signal_after_delay(SIGINT, delay)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cysignals/tests.pyx":1166
 *     """
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             signal_after_delay(SIGINT, delay)
 *             sig_on()
 */
      {
          #ifdef WITH_THREAD
          PyThreadState *_save;
          Py_UNBLOCK_THREADS
          __Pyx_FastGIL_Remember();
          #endif
          /*try:*/ {

            /* "cysignals/tests.pyx":1167
 *     try:
 *         with nogil:
 *             signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *             sig_on()
 *             infinite_malloc_loop()
 */
            signal_after_delay(SIGINT, __pyx_v_delay);

            /* "cysignals/tests.pyx":1168
 *         with nogil:
 *             signal_after_delay(SIGINT, delay)
 *             sig_on()             # <<<<<<<<<<<<<<
 *             infinite_malloc_loop()
 *     except KeyboardInterrupt:
 */
            __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1168, __pyx_L10_error)

            /* "cysignals/tests.pyx":1169
 *             signal_after_delay(SIGINT, delay)
 *             sig_on()
 *             infinite_malloc_loop()             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         pass
 */
            __pyx_f_9cysignals_5tests_infinite_malloc_loop();
          }

          /* "cysignals/tests.pyx":1166
 *     """
 *     try:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             signal_after_delay(SIGINT, delay)
 *             sig_on()
 */
          /*finally:*/ {
            /*normal exit:*/{
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L11;
            }
            __pyx_L10_error: {
              #ifdef WITH_THREAD
              __Pyx_FastGIL_Forget();
              Py_BLOCK_THREADS
              #endif
              goto __pyx_L3_error;
            }
            __pyx_L11:;
          }
      }

      /* "cysignals/tests.pyx":1165
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             signal_after_delay(SIGINT, delay)
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "cysignals/tests.pyx":1170
 *             sig_on()
 *             infinite_malloc_loop()
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_4) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cysignals/tests.pyx":1165
 * 
 *     """
 *     try:             # <<<<<<<<<<<<<<
 *         with nogil:
 *             signal_after_delay(SIGINT, delay)
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "cysignals/tests.pyx":1152
 *     abort()   # This should not be reached
 * 
 * def test_signal_during_malloc(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a signal arriving during a sig_malloc() or sig_free() call.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_signal_during_malloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1177
 * # Benchmarking functions                                               #
 * ########################################################################
 * def sig_on_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_on()`` and ``sig_off()`` 1 million times.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_95sig_on_bench(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_94sig_on_bench, "\n    Call ``sig_on()`` and ``sig_off()`` 1 million times.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> sig_on_bench()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_95sig_on_bench = {"sig_on_bench", (PyCFunction)__pyx_pw_9cysignals_5tests_95sig_on_bench, METH_NOARGS, __pyx_doc_9cysignals_5tests_94sig_on_bench};
static PyObject *__pyx_pw_9cysignals_5tests_95sig_on_bench(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sig_on_bench (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_94sig_on_bench(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_94sig_on_bench(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sig_on_bench", 0);

  /* "cysignals/tests.pyx":1188
 *     """
 *     cdef int i
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(1000000):
 *             sig_on()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1189
 *     cdef int i
 *     with nogil:
 *         for i in range(1000000):             # <<<<<<<<<<<<<<
 *             sig_on()
 *             sig_off()
 */
        for (__pyx_t_1 = 0; __pyx_t_1 < 0xF4240; __pyx_t_1+=1) {
          __pyx_v_i = __pyx_t_1;

          /* "cysignals/tests.pyx":1190
 *     with nogil:
 *         for i in range(1000000):
 *             sig_on()             # <<<<<<<<<<<<<<
 *             sig_off()
 * 
 */
          __pyx_t_2 = sig_on(); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(0, 1190, __pyx_L4_error)

          /* "cysignals/tests.pyx":1191
 *         for i in range(1000000):
 *             sig_on()
 *             sig_off()             # <<<<<<<<<<<<<<
 * 
 * def sig_check_bench():
 */
          sig_off();
        }
      }

      /* "cysignals/tests.pyx":1188
 *     """
 *     cdef int i
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(1000000):
 *             sig_on()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1177
 * # Benchmarking functions                                               #
 * ########################################################################
 * def sig_on_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_on()`` and ``sig_off()`` 1 million times.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.sig_on_bench", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1193
 *             sig_off()
 * 
 * def sig_check_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_check()`` 1 million times.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_97sig_check_bench(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_96sig_check_bench, "\n    Call ``sig_check()`` 1 million times.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> sig_check_bench()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_97sig_check_bench = {"sig_check_bench", (PyCFunction)__pyx_pw_9cysignals_5tests_97sig_check_bench, METH_NOARGS, __pyx_doc_9cysignals_5tests_96sig_check_bench};
static PyObject *__pyx_pw_9cysignals_5tests_97sig_check_bench(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sig_check_bench (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_96sig_check_bench(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_96sig_check_bench(CYTHON_UNUSED PyObject *__pyx_self) {
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sig_check_bench", 0);

  /* "cysignals/tests.pyx":1204
 *     """
 *     cdef int i
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(1000000):
 *             sig_check()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1205
 *     cdef int i
 *     with nogil:
 *         for i in range(1000000):             # <<<<<<<<<<<<<<
 *             sig_check()
 * 
 */
        for (__pyx_t_1 = 0; __pyx_t_1 < 0xF4240; __pyx_t_1+=1) {
          __pyx_v_i = __pyx_t_1;

          /* "cysignals/tests.pyx":1206
 *     with nogil:
 *         for i in range(1000000):
 *             sig_check()             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_2 = sig_check(); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(0, 1206, __pyx_L4_error)
        }
      }

      /* "cysignals/tests.pyx":1204
 *     """
 *     cdef int i
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(1000000):
 *             sig_check()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1193
 *             sig_off()
 * 
 * def sig_check_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_check()`` 1 million times.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.sig_check_bench", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1212
 * # Test SIGHUP                                                          #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_158__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_99test_sighup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_98test_sighup, "\n    Test a basic SIGHUP signal, which would normally exit the Python interpreter\n    by raising ``SystemExit``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sighup()\n        SystemExit()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_99test_sighup = {"test_sighup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_99test_sighup, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_98test_sighup};
static PyObject *__pyx_pw_9cysignals_5tests_99test_sighup(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sighup (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults25 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1212, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sighup") < 0)) __PYX_ERR(0, 1212, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1213, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sighup", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1212, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sighup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_98test_sighup(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_98test_sighup(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sighup", 0);

  /* "cysignals/tests.pyx":1225
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGHUP, delay)
 *         while True:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1226
 *     """
 *     with nogil:
 *         signal_after_delay(SIGHUP, delay)             # <<<<<<<<<<<<<<
 *         while True:
 *             sig_check()
 */
        signal_after_delay(SIGHUP, __pyx_v_delay);

        /* "cysignals/tests.pyx":1227
 *     with nogil:
 *         signal_after_delay(SIGHUP, delay)
 *         while True:             # <<<<<<<<<<<<<<
 *             sig_check()
 * 
 */
        while (1) {

          /* "cysignals/tests.pyx":1228
 *         signal_after_delay(SIGHUP, delay)
 *         while True:
 *             sig_check()             # <<<<<<<<<<<<<<
 * 
 * @return_exception
 */
          __pyx_t_1 = sig_check(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 1228, __pyx_L4_error)
        }
      }

      /* "cysignals/tests.pyx":1225
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGHUP, delay)
 *         while True:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1212
 * # Test SIGHUP                                                          #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sighup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1230
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):
 *     """
 */

static PyObject *__pyx_pf_9cysignals_5tests_160__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_101test_sighup_and_sigint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_100test_sighup_and_sigint, "\n    Test a SIGHUP and a SIGINT arriving at essentially the same time.\n    The SIGINT should be ignored and we should get a ``SystemExit``.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_sighup_and_sigint()\n        SystemExit()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_101test_sighup_and_sigint = {"test_sighup_and_sigint", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_101test_sighup_and_sigint, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_100test_sighup_and_sigint};
static PyObject *__pyx_pw_9cysignals_5tests_101test_sighup_and_sigint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_sighup_and_sigint (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults26 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1230, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_sighup_and_sigint") < 0)) __PYX_ERR(0, 1230, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1231, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_sighup_and_sigint", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1230, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sighup_and_sigint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_100test_sighup_and_sigint(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_100test_sighup_and_sigint(CYTHON_UNUSED PyObject *__pyx_self, long __pyx_v_delay) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_sighup_and_sigint", 0);

  /* "cysignals/tests.pyx":1243
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         sig_block()
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1244
 *     """
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         sig_block()
 *         signal_after_delay(SIGHUP, delay)
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 1244, __pyx_L4_error)

        /* "cysignals/tests.pyx":1245
 *     with nogil:
 *         sig_on()
 *         sig_block()             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGHUP, delay)
 *         signal_after_delay(SIGINT, delay)
 */
        sig_block();

        /* "cysignals/tests.pyx":1246
 *         sig_on()
 *         sig_block()
 *         signal_after_delay(SIGHUP, delay)             # <<<<<<<<<<<<<<
 *         signal_after_delay(SIGINT, delay)
 *         # 3 sleeps to ensure both signals arrive
 */
        signal_after_delay(SIGHUP, __pyx_v_delay);

        /* "cysignals/tests.pyx":1247
 *         sig_block()
 *         signal_after_delay(SIGHUP, delay)
 *         signal_after_delay(SIGINT, delay)             # <<<<<<<<<<<<<<
 *         # 3 sleeps to ensure both signals arrive
 *         ms_sleep(delay)
 */
        signal_after_delay(SIGINT, __pyx_v_delay);

        /* "cysignals/tests.pyx":1249
 *         signal_after_delay(SIGINT, delay)
 *         # 3 sleeps to ensure both signals arrive
 *         ms_sleep(delay)             # <<<<<<<<<<<<<<
 *         ms_sleep(delay)
 *         ms_sleep(delay)
 */
        ms_sleep(__pyx_v_delay);

        /* "cysignals/tests.pyx":1250
 *         # 3 sleeps to ensure both signals arrive
 *         ms_sleep(delay)
 *         ms_sleep(delay)             # <<<<<<<<<<<<<<
 *         ms_sleep(delay)
 *         sig_unblock()
 */
        ms_sleep(__pyx_v_delay);

        /* "cysignals/tests.pyx":1251
 *         ms_sleep(delay)
 *         ms_sleep(delay)
 *         ms_sleep(delay)             # <<<<<<<<<<<<<<
 *         sig_unblock()
 *         sig_off()
 */
        ms_sleep(__pyx_v_delay);

        /* "cysignals/tests.pyx":1252
 *         ms_sleep(delay)
 *         ms_sleep(delay)
 *         sig_unblock()             # <<<<<<<<<<<<<<
 *         sig_off()
 * 
 */
        sig_unblock();

        /* "cysignals/tests.pyx":1253
 *         ms_sleep(delay)
 *         sig_unblock()
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * def test_graceful_exit():
 */
        sig_off();
      }

      /* "cysignals/tests.pyx":1243
 * 
 *     """
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         sig_block()
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1230
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):
 *     """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_sighup_and_sigint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1255
 *         sig_off()
 * 
 * def test_graceful_exit():             # <<<<<<<<<<<<<<
 *     r"""
 *     Start a subprocess, set up some ``atexit`` handler and kill the
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_103test_graceful_exit(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_102test_graceful_exit, "\n    Start a subprocess, set up some ``atexit`` handler and kill the\n    process with ``SIGHUP``. Then the process should exit gracefully,\n    running the ``atexit`` handler::\n\n        >>> from sys import executable\n        >>> from subprocess import *\n        >>> A = Popen([executable], stdin=PIPE, stdout=PIPE, stderr=PIPE)\n        >>> _ = A.stdin.write(b'from cysignals.tests import test_graceful_exit\\n')\n        >>> _ = A.stdin.write(b'test_graceful_exit()\\n')\n        >>> A.stdin.close()\n\n    Now read from the child until we read ``\"GO\"``.  This ensures that\n    the child process has properly started before we kill it::\n\n        >>> while b'GO' not in A.stdout.readline(): pass\n        >>> import os, signal, sys\n        >>> os.kill(A.pid, signal.SIGHUP)\n        >>> _ = sys.stdout.write(A.stdout.read().decode(\"utf-8\"))\n        Goodbye!\n        >>> A.wait()\n        0\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_103test_graceful_exit = {"test_graceful_exit", (PyCFunction)__pyx_pw_9cysignals_5tests_103test_graceful_exit, METH_NOARGS, __pyx_doc_9cysignals_5tests_102test_graceful_exit};
static PyObject *__pyx_pw_9cysignals_5tests_103test_graceful_exit(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_graceful_exit (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_102test_graceful_exit(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1282
 *     # This code is executed in the subprocess
 *     import atexit, sys
 *     def goodbye():             # <<<<<<<<<<<<<<
 *         print("Goodbye!")
 *     atexit.register(goodbye)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_18test_graceful_exit_1goodbye(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_18test_graceful_exit_1goodbye = {"goodbye", (PyCFunction)__pyx_pw_9cysignals_5tests_18test_graceful_exit_1goodbye, METH_NOARGS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_18test_graceful_exit_1goodbye(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("goodbye (wrapper)", 0);
  __pyx_r = __pyx_pf_9cysignals_5tests_18test_graceful_exit_goodbye(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_18test_graceful_exit_goodbye(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("goodbye", 0);

  /* "cysignals/tests.pyx":1283
 *     import atexit, sys
 *     def goodbye():
 *         print("Goodbye!")             # <<<<<<<<<<<<<<
 *     atexit.register(goodbye)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1282
 *     # This code is executed in the subprocess
 *     import atexit, sys
 *     def goodbye():             # <<<<<<<<<<<<<<
 *         print("Goodbye!")
 *     atexit.register(goodbye)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cysignals.tests.test_graceful_exit.goodbye", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1255
 *         sig_off()
 * 
 * def test_graceful_exit():             # <<<<<<<<<<<<<<
 *     r"""
 *     Start a subprocess, set up some ``atexit`` handler and kill the
 */

static PyObject *__pyx_pf_9cysignals_5tests_102test_graceful_exit(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_atexit = NULL;
  PyObject *__pyx_v_sys = NULL;
  PyObject *__pyx_v_goodbye = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_graceful_exit", 0);

  /* "cysignals/tests.pyx":1281
 *     """
 *     # This code is executed in the subprocess
 *     import atexit, sys             # <<<<<<<<<<<<<<
 *     def goodbye():
 *         print("Goodbye!")
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_atexit, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_atexit = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_sys, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sys = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1282
 *     # This code is executed in the subprocess
 *     import atexit, sys
 *     def goodbye():             # <<<<<<<<<<<<<<
 *         print("Goodbye!")
 *     atexit.register(goodbye)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_18test_graceful_exit_1goodbye, 0, __pyx_n_s_test_graceful_exit_locals_goodby, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__7)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_goodbye = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1284
 *     def goodbye():
 *         print("Goodbye!")
 *     atexit.register(goodbye)             # <<<<<<<<<<<<<<
 * 
 *     # Print something to synchronize with the parent
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_atexit, __pyx_n_s_register); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_goodbye};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1287
 * 
 *     # Print something to synchronize with the parent
 *     print("GO")             # <<<<<<<<<<<<<<
 *     sys.stdout.flush()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1288
 *     # Print something to synchronize with the parent
 *     print("GO")
 *     sys.stdout.flush()             # <<<<<<<<<<<<<<
 * 
 *     # Wait to be killed...
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sys, __pyx_n_s_stdout); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_flush); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[1] = {__pyx_t_2, };
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1291
 * 
 *     # Wait to be killed...
 *     sig_on()             # <<<<<<<<<<<<<<
 *     infinite_loop()
 * 
 */
  __pyx_t_4 = sig_on(); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1291, __pyx_L1_error)

  /* "cysignals/tests.pyx":1292
 *     # Wait to be killed...
 *     sig_on()
 *     infinite_loop()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_f_9cysignals_5tests_infinite_loop();

  /* "cysignals/tests.pyx":1255
 *         sig_off()
 * 
 * def test_graceful_exit():             # <<<<<<<<<<<<<<
 *     r"""
 *     Start a subprocess, set up some ``atexit`` handler and kill the
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.tests.test_graceful_exit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_atexit);
  __Pyx_XDECREF(__pyx_v_sys);
  __Pyx_XDECREF(__pyx_v_goodbye);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1299
 * ########################################################################
 * 
 * def test_thread_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test that calling ``sig_block``/``sig_unblock`` is thread-safe.
 */

static PyObject *__pyx_pf_9cysignals_5tests_162__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(__Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_self)->__pyx_arg_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cysignals.tests.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_105test_thread_sig_block(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9cysignals_5tests_104test_thread_sig_block, "\n    Test that calling ``sig_block``/``sig_unblock`` is thread-safe.\n\n    TESTS::\n\n        >>> from cysignals.tests import *\n        >>> test_thread_sig_block()\n\n    ");
static PyMethodDef __pyx_mdef_9cysignals_5tests_105test_thread_sig_block = {"test_thread_sig_block", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_105test_thread_sig_block, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9cysignals_5tests_104test_thread_sig_block};
static PyObject *__pyx_pw_9cysignals_5tests_105test_thread_sig_block(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED long __pyx_v_delay;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_thread_sig_block (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,0};
    #endif
    PyObject* values[1] = {0};
    __pyx_defaults27 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delay);
          if (value) { values[0] = value; kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1299, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "test_thread_sig_block") < 0)) __PYX_ERR(0, 1299, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_delay = __Pyx_PyInt_As_long(values[0]); if (unlikely((__pyx_v_delay == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1299, __pyx_L3_error)
    } else {
      __pyx_v_delay = __pyx_dynamic_args->__pyx_arg_delay;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_thread_sig_block", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1299, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.test_thread_sig_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_104test_thread_sig_block(__pyx_self, __pyx_v_delay);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_104test_thread_sig_block(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED long __pyx_v_delay) {
  pthread_t __pyx_v_t1;
  pthread_t __pyx_v_t2;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("test_thread_sig_block", 0);

  /* "cysignals/tests.pyx":1310
 *     """
 *     cdef pthread_t t1, t2
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "cysignals/tests.pyx":1311
 *     cdef pthread_t t1, t2
 *     with nogil:
 *         sig_on()             # <<<<<<<<<<<<<<
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 */
        __pyx_t_1 = sig_on(); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 1311, __pyx_L4_error)

        /* "cysignals/tests.pyx":1312
 *     with nogil:
 *         sig_on()
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 */
        __pyx_t_2 = (pthread_create((&__pyx_v_t1), NULL, __pyx_f_9cysignals_5tests_func_thread_sig_block, NULL) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":1313
 *         sig_on()
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 *             sig_error()             # <<<<<<<<<<<<<<
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 */
          sig_error();

          /* "cysignals/tests.pyx":1312
 *     with nogil:
 *         sig_on()
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 */
        }

        /* "cysignals/tests.pyx":1314
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_join(t1, NULL):
 */
        __pyx_t_2 = (pthread_create((&__pyx_v_t2), NULL, __pyx_f_9cysignals_5tests_func_thread_sig_block, NULL) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":1315
 *             sig_error()
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 *             sig_error()             # <<<<<<<<<<<<<<
 *         if pthread_join(t1, NULL):
 *             sig_error()
 */
          sig_error();

          /* "cysignals/tests.pyx":1314
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_join(t1, NULL):
 */
        }

        /* "cysignals/tests.pyx":1316
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 *         if pthread_join(t1, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_join(t2, NULL):
 */
        __pyx_t_2 = (pthread_join(__pyx_v_t1, NULL) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":1317
 *             sig_error()
 *         if pthread_join(t1, NULL):
 *             sig_error()             # <<<<<<<<<<<<<<
 *         if pthread_join(t2, NULL):
 *             sig_error()
 */
          sig_error();

          /* "cysignals/tests.pyx":1316
 *         if pthread_create(&t2, NULL, func_thread_sig_block, NULL):
 *             sig_error()
 *         if pthread_join(t1, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         if pthread_join(t2, NULL):
 */
        }

        /* "cysignals/tests.pyx":1318
 *         if pthread_join(t1, NULL):
 *             sig_error()
 *         if pthread_join(t2, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         sig_off()
 */
        __pyx_t_2 = (pthread_join(__pyx_v_t2, NULL) != 0);
        if (__pyx_t_2) {

          /* "cysignals/tests.pyx":1319
 *             sig_error()
 *         if pthread_join(t2, NULL):
 *             sig_error()             # <<<<<<<<<<<<<<
 *         sig_off()
 * 
 */
          sig_error();

          /* "cysignals/tests.pyx":1318
 *         if pthread_join(t1, NULL):
 *             sig_error()
 *         if pthread_join(t2, NULL):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         sig_off()
 */
        }

        /* "cysignals/tests.pyx":1320
 *         if pthread_join(t2, NULL):
 *             sig_error()
 *         sig_off()             # <<<<<<<<<<<<<<
 * 
 * 
 */
        sig_off();
      }

      /* "cysignals/tests.pyx":1310
 *     """
 *     cdef pthread_t t1, t2
 *     with nogil:             # <<<<<<<<<<<<<<
 *         sig_on()
 *         if pthread_create(&t1, NULL, func_thread_sig_block, NULL):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "cysignals/tests.pyx":1299
 * ########################################################################
 * 
 * def test_thread_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test that calling ``sig_block``/``sig_unblock`` is thread-safe.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cysignals.tests.test_thread_sig_block", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cysignals/tests.pyx":1323
 * 
 * 
 * cdef void* func_thread_sig_block(void* ignored) nogil:             # <<<<<<<<<<<<<<
 *     # This is executed by the two threads spawned by test_thread_sig_block()
 *     cdef int n
 */

static void *__pyx_f_9cysignals_5tests_func_thread_sig_block(CYTHON_UNUSED void *__pyx_v_ignored) {
  CYTHON_UNUSED int __pyx_v_n;
  void *__pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "cysignals/tests.pyx":1326
 *     # This is executed by the two threads spawned by test_thread_sig_block()
 *     cdef int n
 *     for n in range(1000000):             # <<<<<<<<<<<<<<
 *         sig_block()
 *         if not (1 <= cysigs.block_sigint <= 2):
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 0xF4240; __pyx_t_1+=1) {
    __pyx_v_n = __pyx_t_1;

    /* "cysignals/tests.pyx":1327
 *     cdef int n
 *     for n in range(1000000):
 *         sig_block()             # <<<<<<<<<<<<<<
 *         if not (1 <= cysigs.block_sigint <= 2):
 *             sig_error()
 */
    sig_block();

    /* "cysignals/tests.pyx":1328
 *     for n in range(1000000):
 *         sig_block()
 *         if not (1 <= cysigs.block_sigint <= 2):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         sig_unblock()
 */
    __pyx_t_2 = (1 <= cysigs.block_sigint);
    if (__pyx_t_2) {
      __pyx_t_2 = (cysigs.block_sigint <= 2);
    }
    __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
    if (__pyx_t_3) {

      /* "cysignals/tests.pyx":1329
 *         sig_block()
 *         if not (1 <= cysigs.block_sigint <= 2):
 *             sig_error()             # <<<<<<<<<<<<<<
 *         sig_unblock()
 */
      sig_error();

      /* "cysignals/tests.pyx":1328
 *     for n in range(1000000):
 *         sig_block()
 *         if not (1 <= cysigs.block_sigint <= 2):             # <<<<<<<<<<<<<<
 *             sig_error()
 *         sig_unblock()
 */
    }

    /* "cysignals/tests.pyx":1330
 *         if not (1 <= cysigs.block_sigint <= 2):
 *             sig_error()
 *         sig_unblock()             # <<<<<<<<<<<<<<
 */
    sig_unblock();
  }

  /* "cysignals/tests.pyx":1323
 * 
 * 
 * cdef void* func_thread_sig_block(void* ignored) nogil:             # <<<<<<<<<<<<<<
 *     # This is executed by the two threads spawned by test_thread_sig_block()
 *     cdef int n
 */

  /* function exit code */
  __pyx_r = 0;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_DeallocDebug(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_9cysignals_5tests_107__pyx_unpickle_DeallocDebug(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9cysignals_5tests_107__pyx_unpickle_DeallocDebug = {"__pyx_unpickle_DeallocDebug", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_107__pyx_unpickle_DeallocDebug, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9cysignals_5tests_107__pyx_unpickle_DeallocDebug(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED const Py_ssize_t __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_DeallocDebug (wrapper)", 0);
  {
    #if CYTHON_COMPILING_IN_LIMITED_API
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    #else
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    #endif
    PyObject* values[3] = {0,0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DeallocDebug", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DeallocDebug", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_DeallocDebug") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_DeallocDebug", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cysignals.tests.__pyx_unpickle_DeallocDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9cysignals_5tests_106__pyx_unpickle_DeallocDebug(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9cysignals_5tests_106__pyx_unpickle_DeallocDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_DeallocDebug", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xda39a3e:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xda39a3e) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xda39a3e:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xda39a3e:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xda, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_2, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xda39a3e:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_9cysignals_5tests_DeallocDebug), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_2 = __pyx_f_9cysignals_5tests___pyx_unpickle_DeallocDebug__set_state(((struct __pyx_obj_9cysignals_5tests_DeallocDebug *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (%s vs 0xda39a3e = ())" % __pyx_checksum
 *     __pyx_result = DeallocDebug.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_DeallocDebug(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cysignals.tests.__pyx_unpickle_DeallocDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_9cysignals_5tests___pyx_unpickle_DeallocDebug__set_state(struct __pyx_obj_9cysignals_5tests_DeallocDebug *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_DeallocDebug__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_DeallocDebug__set_state(<DeallocDebug> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_DeallocDebug__set_state(DeallocDebug __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cysignals.tests.__pyx_unpickle_DeallocDebug__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "signals.pxd":57
 * # (PyErr_Occurred() is non-NULL). To Cython, it will look like
 * # cython_check_exception() actually raised the exception.
 * cdef inline void cython_check_exception() nogil except *:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */

static CYTHON_INLINE void __pyx_f_9cysignals_7signals_cython_check_exception(void) {

  /* function exit code */
}

/* "signals.pxd":63
 * cdef void verify_exc_value()
 * 
 * cdef inline PyObject* sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Borrowed reference to the exception which is currently being
 */

static CYTHON_INLINE PyObject *__pyx_f_9cysignals_7signals_sig_occurred(void) {
  PyObject *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("sig_occurred", 0);

  /* "signals.pxd":77
 *     exception is stored somewhere.
 *     """
 *     if unlikely(cysigs.exc_value is not NULL):             # <<<<<<<<<<<<<<
 *         verify_exc_value()
 *     return cysigs.exc_value
 */
  __pyx_t_1 = (unlikely((cysigs.exc_value != NULL)) != 0);
  if (__pyx_t_1) {

    /* "signals.pxd":78
 *     """
 *     if unlikely(cysigs.exc_value is not NULL):
 *         verify_exc_value()             # <<<<<<<<<<<<<<
 *     return cysigs.exc_value
 * 
 */
    __pyx_f_9cysignals_7signals_verify_exc_value();

    /* "signals.pxd":77
 *     exception is stored somewhere.
 *     """
 *     if unlikely(cysigs.exc_value is not NULL):             # <<<<<<<<<<<<<<
 *         verify_exc_value()
 *     return cysigs.exc_value
 */
  }

  /* "signals.pxd":79
 *     if unlikely(cysigs.exc_value is not NULL):
 *         verify_exc_value()
 *     return cysigs.exc_value             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = cysigs.exc_value;
  goto __pyx_L0;

  /* "signals.pxd":63
 * cdef void verify_exc_value()
 * 
 * cdef inline PyObject* sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Borrowed reference to the exception which is currently being
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "signals.pxd":93
 * 
 * 
 * cdef inline void __generate_declarations():             # <<<<<<<<<<<<<<
 *     cysigs
 *     _sig_on_interrupt_received
 */

static CYTHON_INLINE void __pyx_f_9cysignals_7signals___generate_declarations(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__generate_declarations", 0);

  /* "signals.pxd":94
 * 
 * cdef inline void __generate_declarations():
 *     cysigs             # <<<<<<<<<<<<<<
 *     _sig_on_interrupt_received
 *     _sig_on_recover
 */
  (void)(cysigs);

  /* "signals.pxd":95
 * cdef inline void __generate_declarations():
 *     cysigs
 *     _sig_on_interrupt_received             # <<<<<<<<<<<<<<
 *     _sig_on_recover
 *     _sig_off_warning
 */
  (void)(_sig_on_interrupt_received);

  /* "signals.pxd":96
 *     cysigs
 *     _sig_on_interrupt_received
 *     _sig_on_recover             # <<<<<<<<<<<<<<
 *     _sig_off_warning
 *     print_backtrace
 */
  (void)(_sig_on_recover);

  /* "signals.pxd":97
 *     _sig_on_interrupt_received
 *     _sig_on_recover
 *     _sig_off_warning             # <<<<<<<<<<<<<<
 *     print_backtrace
 */
  (void)(_sig_off_warning);

  /* "signals.pxd":98
 *     _sig_on_recover
 *     _sig_off_warning
 *     print_backtrace             # <<<<<<<<<<<<<<
 */
  (void)(print_backtrace);

  /* "signals.pxd":93
 * 
 * 
 * cdef inline void __generate_declarations():             # <<<<<<<<<<<<<<
 *     cysigs
 *     _sig_on_interrupt_received
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "memory.pxd":36
 * 
 * 
 * cdef inline void* sig_malloc "sig_malloc"(size_t n) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = malloc(n)
 */

static CYTHON_INLINE void *sig_malloc(size_t __pyx_v_n) {
  void *__pyx_v_ret;
  void *__pyx_r;

  /* "memory.pxd":37
 * 
 * cdef inline void* sig_malloc "sig_malloc"(size_t n) nogil:
 *     sig_block()             # <<<<<<<<<<<<<<
 *     cdef void* ret = malloc(n)
 *     sig_unblock()
 */
  sig_block();

  /* "memory.pxd":38
 * cdef inline void* sig_malloc "sig_malloc"(size_t n) nogil:
 *     sig_block()
 *     cdef void* ret = malloc(n)             # <<<<<<<<<<<<<<
 *     sig_unblock()
 *     return ret
 */
  __pyx_v_ret = malloc(__pyx_v_n);

  /* "memory.pxd":39
 *     sig_block()
 *     cdef void* ret = malloc(n)
 *     sig_unblock()             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  sig_unblock();

  /* "memory.pxd":40
 *     cdef void* ret = malloc(n)
 *     sig_unblock()
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":36
 * 
 * 
 * cdef inline void* sig_malloc "sig_malloc"(size_t n) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = malloc(n)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "memory.pxd":43
 * 
 * 
 * cdef inline void* sig_realloc "sig_realloc"(void* ptr, size_t size) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = realloc(ptr, size)
 */

static CYTHON_INLINE void *sig_realloc(void *__pyx_v_ptr, size_t __pyx_v_size) {
  void *__pyx_v_ret;
  void *__pyx_r;

  /* "memory.pxd":44
 * 
 * cdef inline void* sig_realloc "sig_realloc"(void* ptr, size_t size) nogil:
 *     sig_block()             # <<<<<<<<<<<<<<
 *     cdef void* ret = realloc(ptr, size)
 *     sig_unblock()
 */
  sig_block();

  /* "memory.pxd":45
 * cdef inline void* sig_realloc "sig_realloc"(void* ptr, size_t size) nogil:
 *     sig_block()
 *     cdef void* ret = realloc(ptr, size)             # <<<<<<<<<<<<<<
 *     sig_unblock()
 *     return ret
 */
  __pyx_v_ret = realloc(__pyx_v_ptr, __pyx_v_size);

  /* "memory.pxd":46
 *     sig_block()
 *     cdef void* ret = realloc(ptr, size)
 *     sig_unblock()             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  sig_unblock();

  /* "memory.pxd":47
 *     cdef void* ret = realloc(ptr, size)
 *     sig_unblock()
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":43
 * 
 * 
 * cdef inline void* sig_realloc "sig_realloc"(void* ptr, size_t size) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = realloc(ptr, size)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "memory.pxd":50
 * 
 * 
 * cdef inline void* sig_calloc "sig_calloc"(size_t nmemb, size_t size) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = calloc(nmemb, size)
 */

static CYTHON_INLINE void *sig_calloc(size_t __pyx_v_nmemb, size_t __pyx_v_size) {
  void *__pyx_v_ret;
  void *__pyx_r;

  /* "memory.pxd":51
 * 
 * cdef inline void* sig_calloc "sig_calloc"(size_t nmemb, size_t size) nogil:
 *     sig_block()             # <<<<<<<<<<<<<<
 *     cdef void* ret = calloc(nmemb, size)
 *     sig_unblock()
 */
  sig_block();

  /* "memory.pxd":52
 * cdef inline void* sig_calloc "sig_calloc"(size_t nmemb, size_t size) nogil:
 *     sig_block()
 *     cdef void* ret = calloc(nmemb, size)             # <<<<<<<<<<<<<<
 *     sig_unblock()
 *     return ret
 */
  __pyx_v_ret = calloc(__pyx_v_nmemb, __pyx_v_size);

  /* "memory.pxd":53
 *     sig_block()
 *     cdef void* ret = calloc(nmemb, size)
 *     sig_unblock()             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  sig_unblock();

  /* "memory.pxd":54
 *     cdef void* ret = calloc(nmemb, size)
 *     sig_unblock()
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":50
 * 
 * 
 * cdef inline void* sig_calloc "sig_calloc"(size_t nmemb, size_t size) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     cdef void* ret = calloc(nmemb, size)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "memory.pxd":57
 * 
 * 
 * cdef inline void sig_free "sig_free"(void* ptr) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     free(ptr)
 */

static CYTHON_INLINE void sig_free(void *__pyx_v_ptr) {

  /* "memory.pxd":58
 * 
 * cdef inline void sig_free "sig_free"(void* ptr) nogil:
 *     sig_block()             # <<<<<<<<<<<<<<
 *     free(ptr)
 *     sig_unblock()
 */
  sig_block();

  /* "memory.pxd":59
 * cdef inline void sig_free "sig_free"(void* ptr) nogil:
 *     sig_block()
 *     free(ptr)             # <<<<<<<<<<<<<<
 *     sig_unblock()
 * 
 */
  free(__pyx_v_ptr);

  /* "memory.pxd":60
 *     sig_block()
 *     free(ptr)
 *     sig_unblock()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  sig_unblock();

  /* "memory.pxd":57
 * 
 * 
 * cdef inline void sig_free "sig_free"(void* ptr) nogil:             # <<<<<<<<<<<<<<
 *     sig_block()
 *     free(ptr)
 */

  /* function exit code */
}

/* "memory.pxd":64
 * 
 * @cython.cdivision(True)
 * cdef inline size_t mul_overflowcheck(size_t a, size_t b) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Return a*b, checking for overflow. Assume that a > 0.
 */

static CYTHON_INLINE size_t __pyx_f_9cysignals_6memory_mul_overflowcheck(size_t __pyx_v_a, size_t __pyx_v_b) {
  size_t __pyx_v_MUL_NO_OVERFLOW;
  size_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "memory.pxd":71
 *     """
 *     # If a and b both less than MUL_NO_OVERFLOW, no overflow can occur
 *     cdef size_t MUL_NO_OVERFLOW = ((<size_t>1) << (4*sizeof(size_t)))             # <<<<<<<<<<<<<<
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:
 *         if unlikely(b > (<size_t>-1) // a):
 */
  __pyx_v_MUL_NO_OVERFLOW = (((size_t)1) << (4 * (sizeof(size_t))));

  /* "memory.pxd":72
 *     # If a and b both less than MUL_NO_OVERFLOW, no overflow can occur
 *     cdef size_t MUL_NO_OVERFLOW = ((<size_t>1) << (4*sizeof(size_t)))
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:             # <<<<<<<<<<<<<<
 *         if unlikely(b > (<size_t>-1) // a):
 *             return <size_t>(-1)
 */
  __pyx_t_2 = ((__pyx_v_a >= __pyx_v_MUL_NO_OVERFLOW) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_b >= __pyx_v_MUL_NO_OVERFLOW) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "memory.pxd":73
 *     cdef size_t MUL_NO_OVERFLOW = ((<size_t>1) << (4*sizeof(size_t)))
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:
 *         if unlikely(b > (<size_t>-1) // a):             # <<<<<<<<<<<<<<
 *             return <size_t>(-1)
 *     return a*b
 */
    __pyx_t_1 = (unlikely((__pyx_v_b > (((size_t)-1L) / __pyx_v_a))) != 0);
    if (__pyx_t_1) {

      /* "memory.pxd":74
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:
 *         if unlikely(b > (<size_t>-1) // a):
 *             return <size_t>(-1)             # <<<<<<<<<<<<<<
 *     return a*b
 * 
 */
      __pyx_r = ((size_t)-1L);
      goto __pyx_L0;

      /* "memory.pxd":73
 *     cdef size_t MUL_NO_OVERFLOW = ((<size_t>1) << (4*sizeof(size_t)))
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:
 *         if unlikely(b > (<size_t>-1) // a):             # <<<<<<<<<<<<<<
 *             return <size_t>(-1)
 *     return a*b
 */
    }

    /* "memory.pxd":72
 *     # If a and b both less than MUL_NO_OVERFLOW, no overflow can occur
 *     cdef size_t MUL_NO_OVERFLOW = ((<size_t>1) << (4*sizeof(size_t)))
 *     if a >= MUL_NO_OVERFLOW or b >= MUL_NO_OVERFLOW:             # <<<<<<<<<<<<<<
 *         if unlikely(b > (<size_t>-1) // a):
 *             return <size_t>(-1)
 */
  }

  /* "memory.pxd":75
 *         if unlikely(b > (<size_t>-1) // a):
 *             return <size_t>(-1)
 *     return a*b             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = (__pyx_v_a * __pyx_v_b);
  goto __pyx_L0;

  /* "memory.pxd":64
 * 
 * @cython.cdivision(True)
 * cdef inline size_t mul_overflowcheck(size_t a, size_t b) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Return a*b, checking for overflow. Assume that a > 0.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "memory.pxd":78
 * 
 * 
 * cdef inline void* check_allocarray(size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate memory for ``nmemb`` elements of size ``size``.
 */

static CYTHON_INLINE void *__pyx_f_9cysignals_6memory_check_allocarray(size_t __pyx_v_nmemb, size_t __pyx_v_size) {
  size_t __pyx_v_n;
  void *__pyx_v_ret;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_allocarray", 0);

  /* "memory.pxd":82
 *     Allocate memory for ``nmemb`` elements of size ``size``.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 */
  __pyx_t_1 = ((__pyx_v_nmemb == 0) != 0);
  if (__pyx_t_1) {

    /* "memory.pxd":83
 *     """
 *     if nmemb == 0:
 *         return NULL             # <<<<<<<<<<<<<<
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_malloc(n)
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "memory.pxd":82
 *     Allocate memory for ``nmemb`` elements of size ``size``.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 */
  }

  /* "memory.pxd":84
 *     if nmemb == 0:
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)             # <<<<<<<<<<<<<<
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):
 */
  __pyx_v_n = __pyx_f_9cysignals_6memory_mul_overflowcheck(__pyx_v_nmemb, __pyx_v_size);

  /* "memory.pxd":85
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_malloc(n)             # <<<<<<<<<<<<<<
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 */
  __pyx_v_ret = sig_malloc(__pyx_v_n);

  /* "memory.pxd":86
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  __pyx_t_1 = (unlikely((__pyx_v_ret == NULL)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "memory.pxd":87
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_nmemb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_failed_to_allocate_s_s_bytes, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_MemoryError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 87, __pyx_L1_error)

    /* "memory.pxd":86
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  }

  /* "memory.pxd":88
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":78
 * 
 * 
 * cdef inline void* check_allocarray(size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate memory for ``nmemb`` elements of size ``size``.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cysignals.memory.check_allocarray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "memory.pxd":91
 * 
 * 
 * cdef inline void* check_reallocarray(void* ptr, size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Re-allocate memory at ``ptr`` to hold ``nmemb`` elements of size
 */

static CYTHON_INLINE void *__pyx_f_9cysignals_6memory_check_reallocarray(void *__pyx_v_ptr, size_t __pyx_v_nmemb, size_t __pyx_v_size) {
  size_t __pyx_v_n;
  void *__pyx_v_ret;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_reallocarray", 0);

  /* "memory.pxd":99
 *     When ``nmemb`` equals 0, then free the memory at ``ptr``.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         sig_free(ptr)
 *         return NULL
 */
  __pyx_t_1 = ((__pyx_v_nmemb == 0) != 0);
  if (__pyx_t_1) {

    /* "memory.pxd":100
 *     """
 *     if nmemb == 0:
 *         sig_free(ptr)             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 */
    sig_free(__pyx_v_ptr);

    /* "memory.pxd":101
 *     if nmemb == 0:
 *         sig_free(ptr)
 *         return NULL             # <<<<<<<<<<<<<<
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_realloc(ptr, n)
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "memory.pxd":99
 *     When ``nmemb`` equals 0, then free the memory at ``ptr``.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         sig_free(ptr)
 *         return NULL
 */
  }

  /* "memory.pxd":102
 *         sig_free(ptr)
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)             # <<<<<<<<<<<<<<
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):
 */
  __pyx_v_n = __pyx_f_9cysignals_6memory_mul_overflowcheck(__pyx_v_nmemb, __pyx_v_size);

  /* "memory.pxd":103
 *         return NULL
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_realloc(ptr, n)             # <<<<<<<<<<<<<<
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 */
  __pyx_v_ret = sig_realloc(__pyx_v_ptr, __pyx_v_n);

  /* "memory.pxd":104
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  __pyx_t_1 = (unlikely((__pyx_v_ret == NULL)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "memory.pxd":105
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_nmemb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_failed_to_allocate_s_s_bytes, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_MemoryError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 105, __pyx_L1_error)

    /* "memory.pxd":104
 *     cdef size_t n = mul_overflowcheck(nmemb, size)
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  }

  /* "memory.pxd":106
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":91
 * 
 * 
 * cdef inline void* check_reallocarray(void* ptr, size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Re-allocate memory at ``ptr`` to hold ``nmemb`` elements of size
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cysignals.memory.check_reallocarray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "memory.pxd":109
 * 
 * 
 * cdef inline void* check_malloc(size_t n) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate ``n`` bytes of memory.
 */

static CYTHON_INLINE void *__pyx_f_9cysignals_6memory_check_malloc(size_t __pyx_v_n) {
  void *__pyx_v_ret;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_malloc", 0);

  /* "memory.pxd":113
 *     Allocate ``n`` bytes of memory.
 *     """
 *     if n == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef void* ret = sig_malloc(n)
 */
  __pyx_t_1 = ((__pyx_v_n == 0) != 0);
  if (__pyx_t_1) {

    /* "memory.pxd":114
 *     """
 *     if n == 0:
 *         return NULL             # <<<<<<<<<<<<<<
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "memory.pxd":113
 *     Allocate ``n`` bytes of memory.
 *     """
 *     if n == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef void* ret = sig_malloc(n)
 */
  }

  /* "memory.pxd":115
 *     if n == 0:
 *         return NULL
 *     cdef void* ret = sig_malloc(n)             # <<<<<<<<<<<<<<
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)
 */
  __pyx_v_ret = sig_malloc(__pyx_v_n);

  /* "memory.pxd":116
 *         return NULL
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret
 */
  __pyx_t_1 = (unlikely((__pyx_v_ret == NULL)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "memory.pxd":117
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_failed_to_allocate_s_bytes, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_MemoryError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 117, __pyx_L1_error)

    /* "memory.pxd":116
 *         return NULL
 *     cdef void* ret = sig_malloc(n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret
 */
  }

  /* "memory.pxd":118
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":109
 * 
 * 
 * cdef inline void* check_malloc(size_t n) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate ``n`` bytes of memory.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.memory.check_malloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "memory.pxd":121
 * 
 * 
 * cdef inline void* check_realloc(void* ptr, size_t n) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Re-allocate memory at ``ptr`` to hold ``n`` bytes.
 */

static CYTHON_INLINE void *__pyx_f_9cysignals_6memory_check_realloc(void *__pyx_v_ptr, size_t __pyx_v_n) {
  void *__pyx_v_ret;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_realloc", 0);

  /* "memory.pxd":126
 *     If ``ptr`` equals ``NULL``, this behaves as ``check_malloc``.
 *     """
 *     if n == 0:             # <<<<<<<<<<<<<<
 *         sig_free(ptr)
 *         return NULL
 */
  __pyx_t_1 = ((__pyx_v_n == 0) != 0);
  if (__pyx_t_1) {

    /* "memory.pxd":127
 *     """
 *     if n == 0:
 *         sig_free(ptr)             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef void* ret = sig_realloc(ptr, n)
 */
    sig_free(__pyx_v_ptr);

    /* "memory.pxd":128
 *     if n == 0:
 *         sig_free(ptr)
 *         return NULL             # <<<<<<<<<<<<<<
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "memory.pxd":126
 *     If ``ptr`` equals ``NULL``, this behaves as ``check_malloc``.
 *     """
 *     if n == 0:             # <<<<<<<<<<<<<<
 *         sig_free(ptr)
 *         return NULL
 */
  }

  /* "memory.pxd":129
 *         sig_free(ptr)
 *         return NULL
 *     cdef void* ret = sig_realloc(ptr, n)             # <<<<<<<<<<<<<<
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)
 */
  __pyx_v_ret = sig_realloc(__pyx_v_ptr, __pyx_v_n);

  /* "memory.pxd":130
 *         return NULL
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret
 */
  __pyx_t_1 = (unlikely((__pyx_v_ret == NULL)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "memory.pxd":131
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_failed_to_allocate_s_bytes, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_MemoryError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 131, __pyx_L1_error)

    /* "memory.pxd":130
 *         return NULL
 *     cdef void* ret = sig_realloc(ptr, n)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret
 */
  }

  /* "memory.pxd":132
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s bytes" % n)
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":121
 * 
 * 
 * cdef inline void* check_realloc(void* ptr, size_t n) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Re-allocate memory at ``ptr`` to hold ``n`` bytes.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cysignals.memory.check_realloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "memory.pxd":135
 * 
 * 
 * cdef inline void* check_calloc(size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate memory for ``nmemb`` elements of size ``size``. The
 */

static CYTHON_INLINE void *__pyx_f_9cysignals_6memory_check_calloc(size_t __pyx_v_nmemb, size_t __pyx_v_size) {
  void *__pyx_v_ret;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_calloc", 0);

  /* "memory.pxd":140
 *     resulting memory is zeroed.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef void* ret = sig_calloc(nmemb, size)
 */
  __pyx_t_1 = ((__pyx_v_nmemb == 0) != 0);
  if (__pyx_t_1) {

    /* "memory.pxd":141
 *     """
 *     if nmemb == 0:
 *         return NULL             # <<<<<<<<<<<<<<
 *     cdef void* ret = sig_calloc(nmemb, size)
 *     if unlikely(ret == NULL):
 */
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "memory.pxd":140
 *     resulting memory is zeroed.
 *     """
 *     if nmemb == 0:             # <<<<<<<<<<<<<<
 *         return NULL
 *     cdef void* ret = sig_calloc(nmemb, size)
 */
  }

  /* "memory.pxd":142
 *     if nmemb == 0:
 *         return NULL
 *     cdef void* ret = sig_calloc(nmemb, size)             # <<<<<<<<<<<<<<
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 */
  __pyx_v_ret = sig_calloc(__pyx_v_nmemb, __pyx_v_size);

  /* "memory.pxd":143
 *         return NULL
 *     cdef void* ret = sig_calloc(nmemb, size)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  __pyx_t_1 = (unlikely((__pyx_v_ret == NULL)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "memory.pxd":144
 *     cdef void* ret = sig_calloc(nmemb, size)
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))             # <<<<<<<<<<<<<<
 *     return ret
 */
    __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_nmemb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_failed_to_allocate_s_s_bytes, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_MemoryError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 144, __pyx_L1_error)

    /* "memory.pxd":143
 *         return NULL
 *     cdef void* ret = sig_calloc(nmemb, size)
 *     if unlikely(ret == NULL):             # <<<<<<<<<<<<<<
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret
 */
  }

  /* "memory.pxd":145
 *     if unlikely(ret == NULL):
 *         raise MemoryError("failed to allocate %s * %s bytes" % (nmemb, size))
 *     return ret             # <<<<<<<<<<<<<<
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "memory.pxd":135
 * 
 * 
 * cdef inline void* check_calloc(size_t nmemb, size_t size) except? NULL:             # <<<<<<<<<<<<<<
 *     """
 *     Allocate memory for ``nmemb`` elements of size ``size``. The
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cysignals.memory.check_calloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/complex.pxd":19
 * 
 *         @property
 *         cdef inline double real(self):             # <<<<<<<<<<<<<<
 *             return self.cval.real
 * 
 */

static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self) {
  double __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("real", 0);

  /* "cpython/complex.pxd":20
 *         @property
 *         cdef inline double real(self):
 *             return self.cval.real             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = __pyx_v_self->cval.real;
  goto __pyx_L0;

  /* "cpython/complex.pxd":19
 * 
 *         @property
 *         cdef inline double real(self):             # <<<<<<<<<<<<<<
 *             return self.cval.real
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/complex.pxd":23
 * 
 *         @property
 *         cdef inline double imag(self):             # <<<<<<<<<<<<<<
 *             return self.cval.imag
 * 
 */

static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self) {
  double __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("imag", 0);

  /* "cpython/complex.pxd":24
 *         @property
 *         cdef inline double imag(self):
 *             return self.cval.imag             # <<<<<<<<<<<<<<
 * 
 *     # PyTypeObject PyComplex_Type
 */
  __pyx_r = __pyx_v_self->cval.imag;
  goto __pyx_L0;

  /* "cpython/complex.pxd":23
 * 
 *         @property
 *         cdef inline double imag(self):             # <<<<<<<<<<<<<<
 *             return self.cval.imag
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_9cysignals_5tests_DeallocDebug(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  return o;
}

static void __pyx_tp_dealloc_9cysignals_5tests_DeallocDebug(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9cysignals_5tests_12DeallocDebug_1__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_9cysignals_5tests_DeallocDebug[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_12DeallocDebug_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9cysignals_5tests_12DeallocDebug_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
static PyType_Slot __pyx_type_9cysignals_5tests_DeallocDebug_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9cysignals_5tests_DeallocDebug},
  {Py_tp_getattro, (void *)PyObject_GenericGetAttr},
  {Py_tp_methods, (void *)__pyx_methods_9cysignals_5tests_DeallocDebug},
  {Py_tp_new, (void *)__pyx_tp_new_9cysignals_5tests_DeallocDebug},
  {0, 0},
};
static PyType_Spec __pyx_type_9cysignals_5tests_DeallocDebug_spec = {
  "cysignals.tests.DeallocDebug",
  sizeof(struct __pyx_obj_9cysignals_5tests_DeallocDebug),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_9cysignals_5tests_DeallocDebug_slots,
};
#else

static PyTypeObject __pyx_type_9cysignals_5tests_DeallocDebug = {
  PyVarObject_HEAD_INIT(0, 0)
  "cysignals.tests.""DeallocDebug", /*tp_name*/
  sizeof(struct __pyx_obj_9cysignals_5tests_DeallocDebug), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9cysignals_5tests_DeallocDebug, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9cysignals_5tests_DeallocDebug, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9cysignals_5tests_DeallocDebug, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  #if CYTHON_COMPILING_IN_LIMITED_API
  {0, __pyx_k_Are_we_currently_on_the_alterna, sizeof(__pyx_k_Are_we_currently_on_the_alterna), 0, 1, 0, 0},
  {0, __pyx_k_BaseException, sizeof(__pyx_k_BaseException), 0, 0, 1, 1},
  {0, __pyx_k_Call_sig_check_1_million_times, sizeof(__pyx_k_Call_sig_check_1_million_times), 0, 1, 0, 0},
  {0, __pyx_k_Call_sig_on_and_sig_off_1_milli, sizeof(__pyx_k_Call_sig_on_and_sig_off_1_milli), 0, 1, 0, 0},
  {0, __pyx_k_DeallocDebug, sizeof(__pyx_k_DeallocDebug), 0, 0, 1, 1},
  {0, __pyx_k_DeallocDebug___reduce_cython, sizeof(__pyx_k_DeallocDebug___reduce_cython), 0, 0, 1, 1},
  {0, __pyx_k_DeallocDebug___setstate_cython, sizeof(__pyx_k_DeallocDebug___setstate_cython), 0, 0, 1, 1},
  {0, __pyx_k_Decorator_class_which_makes_a_f, sizeof(__pyx_k_Decorator_class_which_makes_a_f), 0, 0, 1, 0},
  {0, __pyx_k_Everything_ok, sizeof(__pyx_k_Everything_ok), 0, 0, 1, 0},
  {0, __pyx_k_GO, sizeof(__pyx_k_GO), 0, 0, 1, 1},
  {0, __pyx_k_Goodbye, sizeof(__pyx_k_Goodbye), 0, 0, 1, 0},
  {0, __pyx_k_Have_p_processes_each_sending_n, sizeof(__pyx_k_Have_p_processes_each_sending_n), 0, 1, 0, 0},
  {0, __pyx_k_Incompatible_checksums_s_vs_0xda, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xda), 0, 0, 1, 0},
  {0, __pyx_k_KeyboardInterrupt, sizeof(__pyx_k_KeyboardInterrupt), 0, 0, 1, 1},
  {0, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {0, __pyx_k_No_current_exception, sizeof(__pyx_k_No_current_exception), 0, 0, 1, 0},
  {0, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
  {0, __pyx_k_PIPE, sizeof(__pyx_k_PIPE), 0, 0, 1, 1},
  {0, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {0, __pyx_k_Popen, sizeof(__pyx_k_Popen), 0, 0, 1, 1},
  {0, __pyx_k_Print_the_exception_which_is_cu, sizeof(__pyx_k_Print_the_exception_which_is_cu), 0, 1, 0, 0},
  {0, __pyx_k_Received, sizeof(__pyx_k_Received), 0, 1, 0, 0},
  {0, __pyx_k_Regression_test_for_https_githu, sizeof(__pyx_k_Regression_test_for_https_githu), 0, 1, 0, 0},
  {0, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {0, __pyx_k_Send_an_interrupt_signal_SIGINT, sizeof(__pyx_k_Send_an_interrupt_signal_SIGINT), 0, 1, 0, 0},
  {0, __pyx_k_Start_a_subprocess_set_up_some, sizeof(__pyx_k_Start_a_subprocess_set_up_some), 0, 1, 0, 0},
  {0, __pyx_k_Success, sizeof(__pyx_k_Success), 0, 0, 1, 1},
  {0, __pyx_k_TESTS_Regression_test_for_https, sizeof(__pyx_k_TESTS_Regression_test_for_https), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_This_test_should_result_i, sizeof(__pyx_k_TESTS_This_test_should_result_i), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_We_run_Python_in_a_subpro, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_We_run_Python_in_a_subpro_2, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_2), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_We_run_Python_in_a_subpro_3, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_3), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_We_run_Python_in_a_subpro_4, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_4), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_We_run_Python_in_a_subpro_5, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_5), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_10, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_10), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_11, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_11), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_12, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_12), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_13, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_13), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_14, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_14), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_15, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_15), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_16, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_16), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_17, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_17), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_18, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_18), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_19, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_19), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_2, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_2), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_20, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_20), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_21, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_21), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_22, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_22), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_23, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_23), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_24, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_24), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_25, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_25), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_26, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_26), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_27, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_27), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_28, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_28), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_29, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_29), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_3, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_3), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_4, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_4), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_5, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_5), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_6, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_6), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_7, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_7), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_8, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_8), 0, 1, 0, 0},
  {0, __pyx_k_TESTS_from_cysignals_tests_impo_9, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_9), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_SIGHUP_and_a_SIGINT_arri, sizeof(__pyx_k_Test_a_SIGHUP_and_a_SIGINT_arri), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_basic_SIGHUP_signal_whic, sizeof(__pyx_k_Test_a_basic_SIGHUP_signal_whic), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_signal_arriving_during_a, sizeof(__pyx_k_Test_a_signal_arriving_during_a), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_try_finally_construct_fo, sizeof(__pyx_k_Test_a_try_finally_construct_fo), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_try_finally_construct_fo_2, sizeof(__pyx_k_Test_a_try_finally_construct_fo_2), 0, 1, 0, 0},
  {0, __pyx_k_Test_a_try_finally_construct_fo_3, sizeof(__pyx_k_Test_a_try_finally_construct_fo_3), 0, 1, 0, 0},
  {0, __pyx_k_Test_that_calling_sig_block_sig, sizeof(__pyx_k_Test_that_calling_sig_block_sig), 0, 1, 0, 0},
  {0, __pyx_k_Unexpected_zero_returned_from_si, sizeof(__pyx_k_Unexpected_zero_returned_from_si), 0, 0, 1, 0},
  {0, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {0, __pyx_k__113, sizeof(__pyx_k__113), 0, 0, 1, 1},
  {0, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {0, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
  {0, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 1},
  {0, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {0, __pyx_k_argv, sizeof(__pyx_k_argv), 0, 0, 1, 1},
  {0, __pyx_k_atexit, sizeof(__pyx_k_atexit), 0, 0, 1, 1},
  {0, __pyx_k_base_delay, sizeof(__pyx_k_base_delay), 0, 0, 1, 1},
  {0, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 0},
  {0, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
  {0, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {0, __pyx_k_command, sizeof(__pyx_k_command), 0, 0, 1, 1},
  {0, __pyx_k_communicate, sizeof(__pyx_k_communicate), 0, 0, 1, 1},
  {0, __pyx_k_cysignals_tests, sizeof(__pyx_k_cysignals_tests), 0, 0, 1, 1},
  {0, __pyx_k_dealloc, sizeof(__pyx_k_dealloc), 0, 0, 1, 0},
  {0, __pyx_k_delay, sizeof(__pyx_k_delay), 0, 0, 1, 1},
  {0, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {0, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
  {0, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {0, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {0, __pyx_k_err, sizeof(__pyx_k_err), 0, 0, 1, 1},
  {0, __pyx_k_exc, sizeof(__pyx_k_exc), 0, 0, 1, 1},
  {0, __pyx_k_executable, sizeof(__pyx_k_executable), 0, 0, 1, 1},
  {0, __pyx_k_failed_to_allocate_s_bytes, sizeof(__pyx_k_failed_to_allocate_s_bytes), 0, 0, 1, 0},
  {0, __pyx_k_failed_to_allocate_s_s_bytes, sizeof(__pyx_k_failed_to_allocate_s_s_bytes), 0, 0, 1, 0},
  {0, __pyx_k_flush, sizeof(__pyx_k_flush), 0, 0, 1, 1},
  {0, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {0, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {0, __pyx_k_goodbye, sizeof(__pyx_k_goodbye), 0, 0, 1, 1},
  {0, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {0, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {0, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {0, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
  {0, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
  {0, __pyx_k_interrupt_after_delay, sizeof(__pyx_k_interrupt_after_delay), 0, 0, 1, 1},
  {0, __pyx_k_interrupt_after_delay_line_154, sizeof(__pyx_k_interrupt_after_delay_line_154), 0, 1, 0, 0},
  {0, __pyx_k_interrupts, sizeof(__pyx_k_interrupts), 0, 1, 0, 0},
  {0, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {0, __pyx_k_kwds, sizeof(__pyx_k_kwds), 0, 0, 1, 1},
  {0, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {0, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {0, __pyx_k_mmap_failed_errno, sizeof(__pyx_k_mmap_failed_errno), 0, 1, 0, 0},
  {0, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {0, __pyx_k_ms_delay, sizeof(__pyx_k_ms_delay), 0, 0, 1, 1},
  {0, __pyx_k_munmap_failed_errno, sizeof(__pyx_k_munmap_failed_errno), 0, 1, 0, 0},
  {0, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {0, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {0, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {0, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {0, __pyx_k_on_stack, sizeof(__pyx_k_on_stack), 0, 0, 1, 1},
  {0, __pyx_k_on_stack_line_182, sizeof(__pyx_k_on_stack_line_182), 0, 1, 0, 0},
  {0, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
  {0, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
  {0, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {0, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {0, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {0, __pyx_k_print_sig_occurred, sizeof(__pyx_k_print_sig_occurred), 0, 0, 1, 1},
  {0, __pyx_k_print_sig_occurred_line_886, sizeof(__pyx_k_print_sig_occurred_line_886), 0, 1, 0, 0},
  {0, __pyx_k_ptr, sizeof(__pyx_k_ptr), 0, 0, 1, 1},
  {0, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {0, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {0, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {0, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {0, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {0, __pyx_k_pyx_unpickle_DeallocDebug, sizeof(__pyx_k_pyx_unpickle_DeallocDebug), 0, 0, 1, 1},
  {0, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {0, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {0, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {0, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {0, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {0, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
  {0, __pyx_k_return_exception, sizeof(__pyx_k_return_exception), 0, 0, 1, 1},
  {0, __pyx_k_return_exception___call, sizeof(__pyx_k_return_exception___call), 0, 0, 1, 1},
  {0, __pyx_k_return_exception___init, sizeof(__pyx_k_return_exception___init), 0, 0, 1, 1},
  {0, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
  {0, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {0, __pyx_k_set_debug_level, sizeof(__pyx_k_set_debug_level), 0, 0, 1, 1},
  {0, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
  {0, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {0, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {0, __pyx_k_sig_check_bench, sizeof(__pyx_k_sig_check_bench), 0, 0, 1, 1},
  {0, __pyx_k_sig_check_bench_line_1193, sizeof(__pyx_k_sig_check_bench_line_1193), 0, 1, 0, 0},
  {0, __pyx_k_sig_on, sizeof(__pyx_k_sig_on), 0, 0, 1, 1},
  {0, __pyx_k_sig_on_bench, sizeof(__pyx_k_sig_on_bench), 0, 0, 1, 1},
  {0, __pyx_k_sig_on_bench_line_1177, sizeof(__pyx_k_sig_on_bench_line_1177), 0, 1, 0, 0},
  {0, __pyx_k_signals, sizeof(__pyx_k_signals), 0, 0, 1, 1},
  {0, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
  {0, __pyx_k_src_cysignals_tests_pyx, sizeof(__pyx_k_src_cysignals_tests_pyx), 0, 0, 1, 0},
  {0, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {0, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
  {0, __pyx_k_stdout, sizeof(__pyx_k_stdout), 0, 0, 1, 1},
  {0, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {0, __pyx_k_subprocess, sizeof(__pyx_k_subprocess), 0, 0, 1, 1},
  {0, __pyx_k_subpython_err, sizeof(__pyx_k_subpython_err), 0, 0, 1, 1},
  {0, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {0, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {0, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {0, __pyx_k_t1, sizeof(__pyx_k_t1), 0, 0, 1, 1},
  {0, __pyx_k_t2, sizeof(__pyx_k_t2), 0, 0, 1, 1},
  {0, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {0, __pyx_k_test_abort, sizeof(__pyx_k_test_abort), 0, 0, 1, 1},
  {0, __pyx_k_test_abort_line_633, sizeof(__pyx_k_test_abort_line_633), 0, 1, 0, 0},
  {0, __pyx_k_test_access_mmap_noreserve, sizeof(__pyx_k_test_access_mmap_noreserve), 0, 0, 1, 1},
  {0, __pyx_k_test_access_mmap_noreserve_line, sizeof(__pyx_k_test_access_mmap_noreserve_line), 0, 1, 0, 0},
  {0, __pyx_k_test_bad_str, sizeof(__pyx_k_test_bad_str), 0, 0, 1, 1},
  {0, __pyx_k_test_bad_str_line_726, sizeof(__pyx_k_test_bad_str_line_726), 0, 1, 0, 0},
  {0, __pyx_k_test_dereference_null_pointer, sizeof(__pyx_k_test_dereference_null_pointer), 0, 0, 1, 1},
  {0, __pyx_k_test_dereference_null_pointer_li, sizeof(__pyx_k_test_dereference_null_pointer_li), 0, 1, 0, 0},
  {0, __pyx_k_test_graceful_exit, sizeof(__pyx_k_test_graceful_exit), 0, 0, 1, 1},
  {0, __pyx_k_test_graceful_exit_line_1255, sizeof(__pyx_k_test_graceful_exit_line_1255), 0, 1, 0, 0},
  {0, __pyx_k_test_graceful_exit_locals_goodby, sizeof(__pyx_k_test_graceful_exit_locals_goodby), 0, 0, 1, 1},
  {0, __pyx_k_test_interrupt_bomb, sizeof(__pyx_k_test_interrupt_bomb), 0, 0, 1, 1},
  {0, __pyx_k_test_interrupt_bomb_line_785, sizeof(__pyx_k_test_interrupt_bomb_line_785), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_block, sizeof(__pyx_k_test_sig_block), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_block_line_1067, sizeof(__pyx_k_test_sig_block_line_1067), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_block_nested, sizeof(__pyx_k_test_sig_block_nested), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_block_nested_line_1093, sizeof(__pyx_k_test_sig_block_nested_line_1093), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_block_outside_sig_on, sizeof(__pyx_k_test_sig_block_outside_sig_on), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_block_outside_sig_on_li, sizeof(__pyx_k_test_sig_block_outside_sig_on_li), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_check, sizeof(__pyx_k_test_sig_check), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_check_inside_sig_on, sizeof(__pyx_k_test_sig_check_inside_sig_on), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_check_inside_sig_on_lin, sizeof(__pyx_k_test_sig_check_inside_sig_on_lin), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_check_line_316, sizeof(__pyx_k_test_sig_check_line_316), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_check_no_except, sizeof(__pyx_k_test_sig_check_no_except), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_check_no_except_line_46, sizeof(__pyx_k_test_sig_check_no_except_line_46), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_error, sizeof(__pyx_k_test_sig_error), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_error_line_390, sizeof(__pyx_k_test_sig_error_line_390), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_occurred_dealloc, sizeof(__pyx_k_test_sig_occurred_dealloc), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_occurred_dealloc_in_gc, sizeof(__pyx_k_test_sig_occurred_dealloc_in_gc), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_occurred_dealloc_in_gc_2, sizeof(__pyx_k_test_sig_occurred_dealloc_in_gc_2), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_occurred_dealloc_line_9, sizeof(__pyx_k_test_sig_occurred_dealloc_line_9), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_occurred_finally, sizeof(__pyx_k_test_sig_occurred_finally), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_occurred_finally_line_9, sizeof(__pyx_k_test_sig_occurred_finally_line_9), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_occurred_live_exception, sizeof(__pyx_k_test_sig_occurred_live_exception), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_occurred_live_exception_2, sizeof(__pyx_k_test_sig_occurred_live_exception_2), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_off, sizeof(__pyx_k_test_sig_off), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_off_line_220, sizeof(__pyx_k_test_sig_off_line_220), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on, sizeof(__pyx_k_test_sig_on), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_cython, sizeof(__pyx_k_test_sig_on_cython), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_cython_after_delay, sizeof(__pyx_k_test_sig_on_cython_after_delay), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_cython_after_delay_l, sizeof(__pyx_k_test_sig_on_cython_after_delay_l), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_cython_except, sizeof(__pyx_k_test_sig_on_cython_except), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_cython_except_all, sizeof(__pyx_k_test_sig_on_cython_except_all), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_cython_except_all_li, sizeof(__pyx_k_test_sig_on_cython_except_all_li), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_cython_except_line_2, sizeof(__pyx_k_test_sig_on_cython_except_line_2), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_cython_line_267, sizeof(__pyx_k_test_sig_on_cython_line_267), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_inside_try, sizeof(__pyx_k_test_sig_on_inside_try), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_inside_try_line_768, sizeof(__pyx_k_test_sig_on_inside_try_line_768), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_line_232, sizeof(__pyx_k_test_sig_on_line_232), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_on_no_except, sizeof(__pyx_k_test_sig_on_no_except), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_on_no_except_line_409, sizeof(__pyx_k_test_sig_on_no_except_line_409), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_retry, sizeof(__pyx_k_test_sig_retry), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_retry_and_signal, sizeof(__pyx_k_test_sig_retry_and_signal), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_retry_and_signal_line_3, sizeof(__pyx_k_test_sig_retry_and_signal_line_3), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_retry_line_351, sizeof(__pyx_k_test_sig_retry_line_351), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_str, sizeof(__pyx_k_test_sig_str), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_str_line_247, sizeof(__pyx_k_test_sig_str_line_247), 0, 1, 0, 0},
  {0, __pyx_k_test_sig_str_no_except, sizeof(__pyx_k_test_sig_str_no_except), 0, 0, 1, 1},
  {0, __pyx_k_test_sig_str_no_except_line_438, sizeof(__pyx_k_test_sig_str_no_except_line_438), 0, 1, 0, 0},
  {0, __pyx_k_test_sighup, sizeof(__pyx_k_test_sighup), 0, 0, 1, 1},
  {0, __pyx_k_test_sighup_and_sigint, sizeof(__pyx_k_test_sighup_and_sigint), 0, 0, 1, 1},
  {0, __pyx_k_test_sighup_and_sigint_line_1230, sizeof(__pyx_k_test_sighup_and_sigint_line_1230), 0, 1, 0, 0},
  {0, __pyx_k_test_sighup_line_1212, sizeof(__pyx_k_test_sighup_line_1212), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_abrt, sizeof(__pyx_k_test_signal_abrt), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_abrt_line_530, sizeof(__pyx_k_test_signal_abrt_line_530), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_bus, sizeof(__pyx_k_test_signal_bus), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_bus_line_546, sizeof(__pyx_k_test_signal_bus_line_546), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_during_malloc, sizeof(__pyx_k_test_signal_during_malloc), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_during_malloc_line_1, sizeof(__pyx_k_test_signal_during_malloc_line_1), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_fpe, sizeof(__pyx_k_test_signal_fpe), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_fpe_line_498, sizeof(__pyx_k_test_signal_fpe_line_498), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_ill, sizeof(__pyx_k_test_signal_ill), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_ill_line_514, sizeof(__pyx_k_test_signal_ill_line_514), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_quit, sizeof(__pyx_k_test_signal_quit), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_quit_line_562, sizeof(__pyx_k_test_signal_quit_line_562), 0, 1, 0, 0},
  {0, __pyx_k_test_signal_segv, sizeof(__pyx_k_test_signal_segv), 0, 0, 1, 1},
  {0, __pyx_k_test_signal_segv_line_482, sizeof(__pyx_k_test_signal_segv_line_482), 0, 1, 0, 0},
  {0, __pyx_k_test_stack_overflow, sizeof(__pyx_k_test_stack_overflow), 0, 0, 1, 1},
  {0, __pyx_k_test_stack_overflow_line_668, sizeof(__pyx_k_test_stack_overflow_line_668), 0, 1, 0, 0},
  {0, __pyx_k_test_thread_sig_block, sizeof(__pyx_k_test_thread_sig_block), 0, 0, 1, 1},
  {0, __pyx_k_test_thread_sig_block_line_1299, sizeof(__pyx_k_test_thread_sig_block_line_1299), 0, 1, 0, 0},
  {0, __pyx_k_test_try_finally_raise, sizeof(__pyx_k_test_try_finally_raise), 0, 0, 1, 1},
  {0, __pyx_k_test_try_finally_raise_line_843, sizeof(__pyx_k_test_try_finally_raise_line_843), 0, 1, 0, 0},
  {0, __pyx_k_test_try_finally_return, sizeof(__pyx_k_test_try_finally_return), 0, 0, 1, 1},
  {0, __pyx_k_test_try_finally_return_line_863, sizeof(__pyx_k_test_try_finally_return_line_863), 0, 1, 0, 0},
  {0, __pyx_k_test_try_finally_signal, sizeof(__pyx_k_test_try_finally_signal), 0, 0, 1, 1},
  {0, __pyx_k_test_try_finally_signal_line_822, sizeof(__pyx_k_test_try_finally_signal_line_822), 0, 1, 0, 0},
  {0, __pyx_k_unguarded_abort, sizeof(__pyx_k_unguarded_abort), 0, 0, 1, 1},
  {0, __pyx_k_unguarded_abort_line_648, sizeof(__pyx_k_unguarded_abort_line_648), 0, 1, 0, 0},
  {0, __pyx_k_unguarded_dereference_null_point, sizeof(__pyx_k_unguarded_dereference_null_point), 0, 0, 1, 1},
  {0, __pyx_k_unguarded_dereference_null_point_2, sizeof(__pyx_k_unguarded_dereference_null_point_2), 0, 1, 0, 0},
  {0, __pyx_k_unguarded_stack_overflow, sizeof(__pyx_k_unguarded_stack_overflow), 0, 0, 1, 1},
  {0, __pyx_k_unguarded_stack_overflow_line_68, sizeof(__pyx_k_unguarded_stack_overflow_line_68), 0, 1, 0, 0},
  {0, __pyx_k_universal_newlines, sizeof(__pyx_k_universal_newlines), 0, 0, 1, 1},
  {0, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {0, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
  {0, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {0, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {0, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  #else
  {&__pyx_kp_u_Are_we_currently_on_the_alterna, __pyx_k_Are_we_currently_on_the_alterna, sizeof(__pyx_k_Are_we_currently_on_the_alterna), 0, 1, 0, 0},
  {&__pyx_n_s_BaseException, __pyx_k_BaseException, sizeof(__pyx_k_BaseException), 0, 0, 1, 1},
  {&__pyx_kp_u_Call_sig_check_1_million_times, __pyx_k_Call_sig_check_1_million_times, sizeof(__pyx_k_Call_sig_check_1_million_times), 0, 1, 0, 0},
  {&__pyx_kp_u_Call_sig_on_and_sig_off_1_milli, __pyx_k_Call_sig_on_and_sig_off_1_milli, sizeof(__pyx_k_Call_sig_on_and_sig_off_1_milli), 0, 1, 0, 0},
  {&__pyx_n_s_DeallocDebug, __pyx_k_DeallocDebug, sizeof(__pyx_k_DeallocDebug), 0, 0, 1, 1},
  {&__pyx_n_s_DeallocDebug___reduce_cython, __pyx_k_DeallocDebug___reduce_cython, sizeof(__pyx_k_DeallocDebug___reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_DeallocDebug___setstate_cython, __pyx_k_DeallocDebug___setstate_cython, sizeof(__pyx_k_DeallocDebug___setstate_cython), 0, 0, 1, 1},
  {&__pyx_kp_s_Decorator_class_which_makes_a_f, __pyx_k_Decorator_class_which_makes_a_f, sizeof(__pyx_k_Decorator_class_which_makes_a_f), 0, 0, 1, 0},
  {&__pyx_kp_s_Everything_ok, __pyx_k_Everything_ok, sizeof(__pyx_k_Everything_ok), 0, 0, 1, 0},
  {&__pyx_n_s_GO, __pyx_k_GO, sizeof(__pyx_k_GO), 0, 0, 1, 1},
  {&__pyx_kp_s_Goodbye, __pyx_k_Goodbye, sizeof(__pyx_k_Goodbye), 0, 0, 1, 0},
  {&__pyx_kp_u_Have_p_processes_each_sending_n, __pyx_k_Have_p_processes_each_sending_n, sizeof(__pyx_k_Have_p_processes_each_sending_n), 0, 1, 0, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xda, __pyx_k_Incompatible_checksums_s_vs_0xda, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xda), 0, 0, 1, 0},
  {&__pyx_n_s_KeyboardInterrupt, __pyx_k_KeyboardInterrupt, sizeof(__pyx_k_KeyboardInterrupt), 0, 0, 1, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_s_No_current_exception, __pyx_k_No_current_exception, sizeof(__pyx_k_No_current_exception), 0, 0, 1, 0},
  {&__pyx_n_s_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
  {&__pyx_n_s_PIPE, __pyx_k_PIPE, sizeof(__pyx_k_PIPE), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_Popen, __pyx_k_Popen, sizeof(__pyx_k_Popen), 0, 0, 1, 1},
  {&__pyx_kp_u_Print_the_exception_which_is_cu, __pyx_k_Print_the_exception_which_is_cu, sizeof(__pyx_k_Print_the_exception_which_is_cu), 0, 1, 0, 0},
  {&__pyx_kp_u_Received, __pyx_k_Received, sizeof(__pyx_k_Received), 0, 1, 0, 0},
  {&__pyx_kp_u_Regression_test_for_https_githu, __pyx_k_Regression_test_for_https_githu, sizeof(__pyx_k_Regression_test_for_https_githu), 0, 1, 0, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Send_an_interrupt_signal_SIGINT, __pyx_k_Send_an_interrupt_signal_SIGINT, sizeof(__pyx_k_Send_an_interrupt_signal_SIGINT), 0, 1, 0, 0},
  {&__pyx_kp_u_Start_a_subprocess_set_up_some, __pyx_k_Start_a_subprocess_set_up_some, sizeof(__pyx_k_Start_a_subprocess_set_up_some), 0, 1, 0, 0},
  {&__pyx_n_s_Success, __pyx_k_Success, sizeof(__pyx_k_Success), 0, 0, 1, 1},
  {&__pyx_kp_u_TESTS_Regression_test_for_https, __pyx_k_TESTS_Regression_test_for_https, sizeof(__pyx_k_TESTS_Regression_test_for_https), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_This_test_should_result_i, __pyx_k_TESTS_This_test_should_result_i, sizeof(__pyx_k_TESTS_This_test_should_result_i), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_We_run_Python_in_a_subpro, __pyx_k_TESTS_We_run_Python_in_a_subpro, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2, __pyx_k_TESTS_We_run_Python_in_a_subpro_2, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_2), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3, __pyx_k_TESTS_We_run_Python_in_a_subpro_3, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_3), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4, __pyx_k_TESTS_We_run_Python_in_a_subpro_4, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_4), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5, __pyx_k_TESTS_We_run_Python_in_a_subpro_5, sizeof(__pyx_k_TESTS_We_run_Python_in_a_subpro_5), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo, __pyx_k_TESTS_from_cysignals_tests_impo, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_10, __pyx_k_TESTS_from_cysignals_tests_impo_10, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_10), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_11, __pyx_k_TESTS_from_cysignals_tests_impo_11, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_11), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_12, __pyx_k_TESTS_from_cysignals_tests_impo_12, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_12), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_13, __pyx_k_TESTS_from_cysignals_tests_impo_13, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_13), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_14, __pyx_k_TESTS_from_cysignals_tests_impo_14, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_14), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_15, __pyx_k_TESTS_from_cysignals_tests_impo_15, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_15), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_16, __pyx_k_TESTS_from_cysignals_tests_impo_16, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_16), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_17, __pyx_k_TESTS_from_cysignals_tests_impo_17, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_17), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_18, __pyx_k_TESTS_from_cysignals_tests_impo_18, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_18), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_19, __pyx_k_TESTS_from_cysignals_tests_impo_19, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_19), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_2, __pyx_k_TESTS_from_cysignals_tests_impo_2, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_2), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_20, __pyx_k_TESTS_from_cysignals_tests_impo_20, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_20), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_21, __pyx_k_TESTS_from_cysignals_tests_impo_21, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_21), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_22, __pyx_k_TESTS_from_cysignals_tests_impo_22, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_22), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_23, __pyx_k_TESTS_from_cysignals_tests_impo_23, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_23), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_24, __pyx_k_TESTS_from_cysignals_tests_impo_24, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_24), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_25, __pyx_k_TESTS_from_cysignals_tests_impo_25, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_25), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_26, __pyx_k_TESTS_from_cysignals_tests_impo_26, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_26), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_27, __pyx_k_TESTS_from_cysignals_tests_impo_27, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_27), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_28, __pyx_k_TESTS_from_cysignals_tests_impo_28, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_28), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_29, __pyx_k_TESTS_from_cysignals_tests_impo_29, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_29), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_3, __pyx_k_TESTS_from_cysignals_tests_impo_3, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_3), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_4, __pyx_k_TESTS_from_cysignals_tests_impo_4, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_4), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_5, __pyx_k_TESTS_from_cysignals_tests_impo_5, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_5), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_6, __pyx_k_TESTS_from_cysignals_tests_impo_6, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_6), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_7, __pyx_k_TESTS_from_cysignals_tests_impo_7, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_7), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_8, __pyx_k_TESTS_from_cysignals_tests_impo_8, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_8), 0, 1, 0, 0},
  {&__pyx_kp_u_TESTS_from_cysignals_tests_impo_9, __pyx_k_TESTS_from_cysignals_tests_impo_9, sizeof(__pyx_k_TESTS_from_cysignals_tests_impo_9), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri, __pyx_k_Test_a_SIGHUP_and_a_SIGINT_arri, sizeof(__pyx_k_Test_a_SIGHUP_and_a_SIGINT_arri), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic, __pyx_k_Test_a_basic_SIGHUP_signal_whic, sizeof(__pyx_k_Test_a_basic_SIGHUP_signal_whic), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_signal_arriving_during_a, __pyx_k_Test_a_signal_arriving_during_a, sizeof(__pyx_k_Test_a_signal_arriving_during_a), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_try_finally_construct_fo, __pyx_k_Test_a_try_finally_construct_fo, sizeof(__pyx_k_Test_a_try_finally_construct_fo), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_try_finally_construct_fo_2, __pyx_k_Test_a_try_finally_construct_fo_2, sizeof(__pyx_k_Test_a_try_finally_construct_fo_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_a_try_finally_construct_fo_3, __pyx_k_Test_a_try_finally_construct_fo_3, sizeof(__pyx_k_Test_a_try_finally_construct_fo_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Test_that_calling_sig_block_sig, __pyx_k_Test_that_calling_sig_block_sig, sizeof(__pyx_k_Test_that_calling_sig_block_sig), 0, 1, 0, 0},
  {&__pyx_kp_s_Unexpected_zero_returned_from_si, __pyx_k_Unexpected_zero_returned_from_si, sizeof(__pyx_k_Unexpected_zero_returned_from_si), 0, 0, 1, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s__113, __pyx_k__113, sizeof(__pyx_k__113), 0, 0, 1, 1},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
  {&__pyx_n_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_argv, __pyx_k_argv, sizeof(__pyx_k_argv), 0, 0, 1, 1},
  {&__pyx_n_s_atexit, __pyx_k_atexit, sizeof(__pyx_k_atexit), 0, 0, 1, 1},
  {&__pyx_n_s_base_delay, __pyx_k_base_delay, sizeof(__pyx_k_base_delay), 0, 0, 1, 1},
  {&__pyx_kp_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 0},
  {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_command, __pyx_k_command, sizeof(__pyx_k_command), 0, 0, 1, 1},
  {&__pyx_n_s_communicate, __pyx_k_communicate, sizeof(__pyx_k_communicate), 0, 0, 1, 1},
  {&__pyx_n_s_cysignals_tests, __pyx_k_cysignals_tests, sizeof(__pyx_k_cysignals_tests), 0, 0, 1, 1},
  {&__pyx_kp_s_dealloc, __pyx_k_dealloc, sizeof(__pyx_k_dealloc), 0, 0, 1, 0},
  {&__pyx_n_s_delay, __pyx_k_delay, sizeof(__pyx_k_delay), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {&__pyx_n_s_err, __pyx_k_err, sizeof(__pyx_k_err), 0, 0, 1, 1},
  {&__pyx_n_s_exc, __pyx_k_exc, sizeof(__pyx_k_exc), 0, 0, 1, 1},
  {&__pyx_n_s_executable, __pyx_k_executable, sizeof(__pyx_k_executable), 0, 0, 1, 1},
  {&__pyx_kp_s_failed_to_allocate_s_bytes, __pyx_k_failed_to_allocate_s_bytes, sizeof(__pyx_k_failed_to_allocate_s_bytes), 0, 0, 1, 0},
  {&__pyx_kp_s_failed_to_allocate_s_s_bytes, __pyx_k_failed_to_allocate_s_s_bytes, sizeof(__pyx_k_failed_to_allocate_s_s_bytes), 0, 0, 1, 0},
  {&__pyx_n_s_flush, __pyx_k_flush, sizeof(__pyx_k_flush), 0, 0, 1, 1},
  {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_goodbye, __pyx_k_goodbye, sizeof(__pyx_k_goodbye), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
  {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
  {&__pyx_n_s_interrupt_after_delay, __pyx_k_interrupt_after_delay, sizeof(__pyx_k_interrupt_after_delay), 0, 0, 1, 1},
  {&__pyx_kp_u_interrupt_after_delay_line_154, __pyx_k_interrupt_after_delay_line_154, sizeof(__pyx_k_interrupt_after_delay_line_154), 0, 1, 0, 0},
  {&__pyx_kp_u_interrupts, __pyx_k_interrupts, sizeof(__pyx_k_interrupts), 0, 1, 0, 0},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_kwds, __pyx_k_kwds, sizeof(__pyx_k_kwds), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_kp_u_mmap_failed_errno, __pyx_k_mmap_failed_errno, sizeof(__pyx_k_mmap_failed_errno), 0, 1, 0, 0},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_ms_delay, __pyx_k_ms_delay, sizeof(__pyx_k_ms_delay), 0, 0, 1, 1},
  {&__pyx_kp_u_munmap_failed_errno, __pyx_k_munmap_failed_errno, sizeof(__pyx_k_munmap_failed_errno), 0, 1, 0, 0},
  {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_n_s_on_stack, __pyx_k_on_stack, sizeof(__pyx_k_on_stack), 0, 0, 1, 1},
  {&__pyx_kp_u_on_stack_line_182, __pyx_k_on_stack_line_182, sizeof(__pyx_k_on_stack_line_182), 0, 1, 0, 0},
  {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
  {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_print_sig_occurred, __pyx_k_print_sig_occurred, sizeof(__pyx_k_print_sig_occurred), 0, 0, 1, 1},
  {&__pyx_kp_u_print_sig_occurred_line_886, __pyx_k_print_sig_occurred_line_886, sizeof(__pyx_k_print_sig_occurred_line_886), 0, 1, 0, 0},
  {&__pyx_n_s_ptr, __pyx_k_ptr, sizeof(__pyx_k_ptr), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_DeallocDebug, __pyx_k_pyx_unpickle_DeallocDebug, sizeof(__pyx_k_pyx_unpickle_DeallocDebug), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
  {&__pyx_n_s_return_exception, __pyx_k_return_exception, sizeof(__pyx_k_return_exception), 0, 0, 1, 1},
  {&__pyx_n_s_return_exception___call, __pyx_k_return_exception___call, sizeof(__pyx_k_return_exception___call), 0, 0, 1, 1},
  {&__pyx_n_s_return_exception___init, __pyx_k_return_exception___init, sizeof(__pyx_k_return_exception___init), 0, 0, 1, 1},
  {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_set_debug_level, __pyx_k_set_debug_level, sizeof(__pyx_k_set_debug_level), 0, 0, 1, 1},
  {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_sig_check_bench, __pyx_k_sig_check_bench, sizeof(__pyx_k_sig_check_bench), 0, 0, 1, 1},
  {&__pyx_kp_u_sig_check_bench_line_1193, __pyx_k_sig_check_bench_line_1193, sizeof(__pyx_k_sig_check_bench_line_1193), 0, 1, 0, 0},
  {&__pyx_n_s_sig_on, __pyx_k_sig_on, sizeof(__pyx_k_sig_on), 0, 0, 1, 1},
  {&__pyx_n_s_sig_on_bench, __pyx_k_sig_on_bench, sizeof(__pyx_k_sig_on_bench), 0, 0, 1, 1},
  {&__pyx_kp_u_sig_on_bench_line_1177, __pyx_k_sig_on_bench_line_1177, sizeof(__pyx_k_sig_on_bench_line_1177), 0, 1, 0, 0},
  {&__pyx_n_s_signals, __pyx_k_signals, sizeof(__pyx_k_signals), 0, 0, 1, 1},
  {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
  {&__pyx_kp_s_src_cysignals_tests_pyx, __pyx_k_src_cysignals_tests_pyx, sizeof(__pyx_k_src_cysignals_tests_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_stderr, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
  {&__pyx_n_s_stdout, __pyx_k_stdout, sizeof(__pyx_k_stdout), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_subprocess, __pyx_k_subprocess, sizeof(__pyx_k_subprocess), 0, 0, 1, 1},
  {&__pyx_n_s_subpython_err, __pyx_k_subpython_err, sizeof(__pyx_k_subpython_err), 0, 0, 1, 1},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {&__pyx_n_s_t1, __pyx_k_t1, sizeof(__pyx_k_t1), 0, 0, 1, 1},
  {&__pyx_n_s_t2, __pyx_k_t2, sizeof(__pyx_k_t2), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_test_abort, __pyx_k_test_abort, sizeof(__pyx_k_test_abort), 0, 0, 1, 1},
  {&__pyx_kp_u_test_abort_line_633, __pyx_k_test_abort_line_633, sizeof(__pyx_k_test_abort_line_633), 0, 1, 0, 0},
  {&__pyx_n_s_test_access_mmap_noreserve, __pyx_k_test_access_mmap_noreserve, sizeof(__pyx_k_test_access_mmap_noreserve), 0, 0, 1, 1},
  {&__pyx_kp_u_test_access_mmap_noreserve_line, __pyx_k_test_access_mmap_noreserve_line, sizeof(__pyx_k_test_access_mmap_noreserve_line), 0, 1, 0, 0},
  {&__pyx_n_s_test_bad_str, __pyx_k_test_bad_str, sizeof(__pyx_k_test_bad_str), 0, 0, 1, 1},
  {&__pyx_kp_u_test_bad_str_line_726, __pyx_k_test_bad_str_line_726, sizeof(__pyx_k_test_bad_str_line_726), 0, 1, 0, 0},
  {&__pyx_n_s_test_dereference_null_pointer, __pyx_k_test_dereference_null_pointer, sizeof(__pyx_k_test_dereference_null_pointer), 0, 0, 1, 1},
  {&__pyx_kp_u_test_dereference_null_pointer_li, __pyx_k_test_dereference_null_pointer_li, sizeof(__pyx_k_test_dereference_null_pointer_li), 0, 1, 0, 0},
  {&__pyx_n_s_test_graceful_exit, __pyx_k_test_graceful_exit, sizeof(__pyx_k_test_graceful_exit), 0, 0, 1, 1},
  {&__pyx_kp_u_test_graceful_exit_line_1255, __pyx_k_test_graceful_exit_line_1255, sizeof(__pyx_k_test_graceful_exit_line_1255), 0, 1, 0, 0},
  {&__pyx_n_s_test_graceful_exit_locals_goodby, __pyx_k_test_graceful_exit_locals_goodby, sizeof(__pyx_k_test_graceful_exit_locals_goodby), 0, 0, 1, 1},
  {&__pyx_n_s_test_interrupt_bomb, __pyx_k_test_interrupt_bomb, sizeof(__pyx_k_test_interrupt_bomb), 0, 0, 1, 1},
  {&__pyx_kp_u_test_interrupt_bomb_line_785, __pyx_k_test_interrupt_bomb_line_785, sizeof(__pyx_k_test_interrupt_bomb_line_785), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_block, __pyx_k_test_sig_block, sizeof(__pyx_k_test_sig_block), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_block_line_1067, __pyx_k_test_sig_block_line_1067, sizeof(__pyx_k_test_sig_block_line_1067), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_block_nested, __pyx_k_test_sig_block_nested, sizeof(__pyx_k_test_sig_block_nested), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_block_nested_line_1093, __pyx_k_test_sig_block_nested_line_1093, sizeof(__pyx_k_test_sig_block_nested_line_1093), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_block_outside_sig_on, __pyx_k_test_sig_block_outside_sig_on, sizeof(__pyx_k_test_sig_block_outside_sig_on), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_block_outside_sig_on_li, __pyx_k_test_sig_block_outside_sig_on_li, sizeof(__pyx_k_test_sig_block_outside_sig_on_li), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_check, __pyx_k_test_sig_check, sizeof(__pyx_k_test_sig_check), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_check_inside_sig_on, __pyx_k_test_sig_check_inside_sig_on, sizeof(__pyx_k_test_sig_check_inside_sig_on), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_check_inside_sig_on_lin, __pyx_k_test_sig_check_inside_sig_on_lin, sizeof(__pyx_k_test_sig_check_inside_sig_on_lin), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_check_line_316, __pyx_k_test_sig_check_line_316, sizeof(__pyx_k_test_sig_check_line_316), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_check_no_except, __pyx_k_test_sig_check_no_except, sizeof(__pyx_k_test_sig_check_no_except), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_check_no_except_line_46, __pyx_k_test_sig_check_no_except_line_46, sizeof(__pyx_k_test_sig_check_no_except_line_46), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_error, __pyx_k_test_sig_error, sizeof(__pyx_k_test_sig_error), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_error_line_390, __pyx_k_test_sig_error_line_390, sizeof(__pyx_k_test_sig_error_line_390), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_occurred_dealloc, __pyx_k_test_sig_occurred_dealloc, sizeof(__pyx_k_test_sig_occurred_dealloc), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_occurred_dealloc_in_gc, __pyx_k_test_sig_occurred_dealloc_in_gc, sizeof(__pyx_k_test_sig_occurred_dealloc_in_gc), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2, __pyx_k_test_sig_occurred_dealloc_in_gc_2, sizeof(__pyx_k_test_sig_occurred_dealloc_in_gc_2), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_occurred_dealloc_line_9, __pyx_k_test_sig_occurred_dealloc_line_9, sizeof(__pyx_k_test_sig_occurred_dealloc_line_9), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_occurred_finally, __pyx_k_test_sig_occurred_finally, sizeof(__pyx_k_test_sig_occurred_finally), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_occurred_finally_line_9, __pyx_k_test_sig_occurred_finally_line_9, sizeof(__pyx_k_test_sig_occurred_finally_line_9), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_occurred_live_exception, __pyx_k_test_sig_occurred_live_exception, sizeof(__pyx_k_test_sig_occurred_live_exception), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_occurred_live_exception_2, __pyx_k_test_sig_occurred_live_exception_2, sizeof(__pyx_k_test_sig_occurred_live_exception_2), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_off, __pyx_k_test_sig_off, sizeof(__pyx_k_test_sig_off), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_off_line_220, __pyx_k_test_sig_off_line_220, sizeof(__pyx_k_test_sig_off_line_220), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_on, __pyx_k_test_sig_on, sizeof(__pyx_k_test_sig_on), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_on_cython, __pyx_k_test_sig_on_cython, sizeof(__pyx_k_test_sig_on_cython), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_on_cython_after_delay, __pyx_k_test_sig_on_cython_after_delay, sizeof(__pyx_k_test_sig_on_cython_after_delay), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_on_cython_after_delay_l, __pyx_k_test_sig_on_cython_after_delay_l, sizeof(__pyx_k_test_sig_on_cython_after_delay_l), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_on_cython_except, __pyx_k_test_sig_on_cython_except, sizeof(__pyx_k_test_sig_on_cython_except), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_on_cython_except_all, __pyx_k_test_sig_on_cython_except_all, sizeof(__pyx_k_test_sig_on_cython_except_all), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_on_cython_except_all_li, __pyx_k_test_sig_on_cython_except_all_li, sizeof(__pyx_k_test_sig_on_cython_except_all_li), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_on_cython_except_line_2, __pyx_k_test_sig_on_cython_except_line_2, sizeof(__pyx_k_test_sig_on_cython_except_line_2), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_on_cython_line_267, __pyx_k_test_sig_on_cython_line_267, sizeof(__pyx_k_test_sig_on_cython_line_267), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_on_inside_try, __pyx_k_test_sig_on_inside_try, sizeof(__pyx_k_test_sig_on_inside_try), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_on_inside_try_line_768, __pyx_k_test_sig_on_inside_try_line_768, sizeof(__pyx_k_test_sig_on_inside_try_line_768), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_on_line_232, __pyx_k_test_sig_on_line_232, sizeof(__pyx_k_test_sig_on_line_232), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_on_no_except, __pyx_k_test_sig_on_no_except, sizeof(__pyx_k_test_sig_on_no_except), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_on_no_except_line_409, __pyx_k_test_sig_on_no_except_line_409, sizeof(__pyx_k_test_sig_on_no_except_line_409), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_retry, __pyx_k_test_sig_retry, sizeof(__pyx_k_test_sig_retry), 0, 0, 1, 1},
  {&__pyx_n_s_test_sig_retry_and_signal, __pyx_k_test_sig_retry_and_signal, sizeof(__pyx_k_test_sig_retry_and_signal), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_retry_and_signal_line_3, __pyx_k_test_sig_retry_and_signal_line_3, sizeof(__pyx_k_test_sig_retry_and_signal_line_3), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sig_retry_line_351, __pyx_k_test_sig_retry_line_351, sizeof(__pyx_k_test_sig_retry_line_351), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_str, __pyx_k_test_sig_str, sizeof(__pyx_k_test_sig_str), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_str_line_247, __pyx_k_test_sig_str_line_247, sizeof(__pyx_k_test_sig_str_line_247), 0, 1, 0, 0},
  {&__pyx_n_s_test_sig_str_no_except, __pyx_k_test_sig_str_no_except, sizeof(__pyx_k_test_sig_str_no_except), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sig_str_no_except_line_438, __pyx_k_test_sig_str_no_except_line_438, sizeof(__pyx_k_test_sig_str_no_except_line_438), 0, 1, 0, 0},
  {&__pyx_n_s_test_sighup, __pyx_k_test_sighup, sizeof(__pyx_k_test_sighup), 0, 0, 1, 1},
  {&__pyx_n_s_test_sighup_and_sigint, __pyx_k_test_sighup_and_sigint, sizeof(__pyx_k_test_sighup_and_sigint), 0, 0, 1, 1},
  {&__pyx_kp_u_test_sighup_and_sigint_line_1230, __pyx_k_test_sighup_and_sigint_line_1230, sizeof(__pyx_k_test_sighup_and_sigint_line_1230), 0, 1, 0, 0},
  {&__pyx_kp_u_test_sighup_line_1212, __pyx_k_test_sighup_line_1212, sizeof(__pyx_k_test_sighup_line_1212), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_abrt, __pyx_k_test_signal_abrt, sizeof(__pyx_k_test_signal_abrt), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_abrt_line_530, __pyx_k_test_signal_abrt_line_530, sizeof(__pyx_k_test_signal_abrt_line_530), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_bus, __pyx_k_test_signal_bus, sizeof(__pyx_k_test_signal_bus), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_bus_line_546, __pyx_k_test_signal_bus_line_546, sizeof(__pyx_k_test_signal_bus_line_546), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_during_malloc, __pyx_k_test_signal_during_malloc, sizeof(__pyx_k_test_signal_during_malloc), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_during_malloc_line_1, __pyx_k_test_signal_during_malloc_line_1, sizeof(__pyx_k_test_signal_during_malloc_line_1), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_fpe, __pyx_k_test_signal_fpe, sizeof(__pyx_k_test_signal_fpe), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_fpe_line_498, __pyx_k_test_signal_fpe_line_498, sizeof(__pyx_k_test_signal_fpe_line_498), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_ill, __pyx_k_test_signal_ill, sizeof(__pyx_k_test_signal_ill), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_ill_line_514, __pyx_k_test_signal_ill_line_514, sizeof(__pyx_k_test_signal_ill_line_514), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_quit, __pyx_k_test_signal_quit, sizeof(__pyx_k_test_signal_quit), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_quit_line_562, __pyx_k_test_signal_quit_line_562, sizeof(__pyx_k_test_signal_quit_line_562), 0, 1, 0, 0},
  {&__pyx_n_s_test_signal_segv, __pyx_k_test_signal_segv, sizeof(__pyx_k_test_signal_segv), 0, 0, 1, 1},
  {&__pyx_kp_u_test_signal_segv_line_482, __pyx_k_test_signal_segv_line_482, sizeof(__pyx_k_test_signal_segv_line_482), 0, 1, 0, 0},
  {&__pyx_n_s_test_stack_overflow, __pyx_k_test_stack_overflow, sizeof(__pyx_k_test_stack_overflow), 0, 0, 1, 1},
  {&__pyx_kp_u_test_stack_overflow_line_668, __pyx_k_test_stack_overflow_line_668, sizeof(__pyx_k_test_stack_overflow_line_668), 0, 1, 0, 0},
  {&__pyx_n_s_test_thread_sig_block, __pyx_k_test_thread_sig_block, sizeof(__pyx_k_test_thread_sig_block), 0, 0, 1, 1},
  {&__pyx_kp_u_test_thread_sig_block_line_1299, __pyx_k_test_thread_sig_block_line_1299, sizeof(__pyx_k_test_thread_sig_block_line_1299), 0, 1, 0, 0},
  {&__pyx_n_s_test_try_finally_raise, __pyx_k_test_try_finally_raise, sizeof(__pyx_k_test_try_finally_raise), 0, 0, 1, 1},
  {&__pyx_kp_u_test_try_finally_raise_line_843, __pyx_k_test_try_finally_raise_line_843, sizeof(__pyx_k_test_try_finally_raise_line_843), 0, 1, 0, 0},
  {&__pyx_n_s_test_try_finally_return, __pyx_k_test_try_finally_return, sizeof(__pyx_k_test_try_finally_return), 0, 0, 1, 1},
  {&__pyx_kp_u_test_try_finally_return_line_863, __pyx_k_test_try_finally_return_line_863, sizeof(__pyx_k_test_try_finally_return_line_863), 0, 1, 0, 0},
  {&__pyx_n_s_test_try_finally_signal, __pyx_k_test_try_finally_signal, sizeof(__pyx_k_test_try_finally_signal), 0, 0, 1, 1},
  {&__pyx_kp_u_test_try_finally_signal_line_822, __pyx_k_test_try_finally_signal_line_822, sizeof(__pyx_k_test_try_finally_signal_line_822), 0, 1, 0, 0},
  {&__pyx_n_s_unguarded_abort, __pyx_k_unguarded_abort, sizeof(__pyx_k_unguarded_abort), 0, 0, 1, 1},
  {&__pyx_kp_u_unguarded_abort_line_648, __pyx_k_unguarded_abort_line_648, sizeof(__pyx_k_unguarded_abort_line_648), 0, 1, 0, 0},
  {&__pyx_n_s_unguarded_dereference_null_point, __pyx_k_unguarded_dereference_null_point, sizeof(__pyx_k_unguarded_dereference_null_point), 0, 0, 1, 1},
  {&__pyx_kp_u_unguarded_dereference_null_point_2, __pyx_k_unguarded_dereference_null_point_2, sizeof(__pyx_k_unguarded_dereference_null_point_2), 0, 1, 0, 0},
  {&__pyx_n_s_unguarded_stack_overflow, __pyx_k_unguarded_stack_overflow, sizeof(__pyx_k_unguarded_stack_overflow), 0, 0, 1, 1},
  {&__pyx_kp_u_unguarded_stack_overflow_line_68, __pyx_k_unguarded_stack_overflow_line_68, sizeof(__pyx_k_unguarded_stack_overflow_line_68), 0, 1, 0, 0},
  {&__pyx_n_s_universal_newlines, __pyx_k_universal_newlines, sizeof(__pyx_k_universal_newlines), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  #endif
  {0, 0, 0, 0, 0, 0, 0}
};
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 129, __pyx_L1_error)
  __pyx_builtin_BaseException = __Pyx_GetBuiltinName(__pyx_n_s_BaseException); if (!__pyx_builtin_BaseException) __PYX_ERR(0, 150, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 402, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 421, __pyx_L1_error)
  __pyx_builtin_KeyboardInterrupt = __Pyx_GetBuiltinName(__pyx_n_s_KeyboardInterrupt); if (!__pyx_builtin_KeyboardInterrupt) __PYX_ERR(0, 433, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 718, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 801, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 87, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cysignals/tests.pyx":421
 *         # We should never get here, because this sig_on_no_except()
 *         # will not catch any signal.
 *         print("Unexpected zero returned from sig_on_no_except()")             # <<<<<<<<<<<<<<
 *     sig_off()
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_Unexpected_zero_returned_from_si); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "cysignals/tests.pyx":938
 *     finally:
 *         if exc is NULL:
 *             print("No current exception")             # <<<<<<<<<<<<<<
 *         else:
 *             e = <object>exc
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_No_current_exception); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "cysignals/tests.pyx":1283
 *     import atexit, sys
 *     def goodbye():
 *         print("Goodbye!")             # <<<<<<<<<<<<<<
 *     atexit.register(goodbye)
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_Goodbye); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "cysignals/tests.pyx":1282
 *     # This code is executed in the subprocess
 *     import atexit, sys
 *     def goodbye():             # <<<<<<<<<<<<<<
 *         print("Goodbye!")
 *     atexit.register(goodbye)
 */
  __pyx_codeobj__7 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_goodbye, 1282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__7)) __PYX_ERR(0, 1282, __pyx_L1_error)

  /* "cysignals/tests.pyx":1287
 * 
 *     # Print something to synchronize with the parent
 *     print("GO")             # <<<<<<<<<<<<<<
 *     sys.stdout.flush()
 * 
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_n_s_GO); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "cysignals/tests.pyx":88
 * 
 * from .signals import set_debug_level
 * set_debug_level(0)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "cysignals/tests.pyx":129
 * ########################################################################
 * 
 * class return_exception(object):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator class which makes a function *return* an exception which
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "cysignals/tests.pyx":144
 * 
 *     """
 *     def __init__ (self, func):             # <<<<<<<<<<<<<<
 *         self.func = func
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_func); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_init, 144, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(0, 144, __pyx_L1_error)

  /* "cysignals/tests.pyx":147
 *         self.func = func
 * 
 *     def __call__ (self, *args):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.func(*args)
 */
  __pyx_tuple__13 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_e); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);
  __pyx_codeobj__14 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_call, 147, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__14)) __PYX_ERR(0, 147, __pyx_L1_error)

  /* "cysignals/tests.pyx":154
 * 
 * 
 * def interrupt_after_delay(ms_delay=500):             # <<<<<<<<<<<<<<
 *     """
 *     Send an interrupt signal (``SIGINT``) to the process after a delay of
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_ms_delay); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_interrupt_after_delay, 154, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(0, 154, __pyx_L1_error)
  __pyx_tuple__17 = PyTuple_Pack(1, ((PyObject *)__pyx_int_500)); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "cysignals/tests.pyx":182
 * 
 * 
 * def on_stack():             # <<<<<<<<<<<<<<
 *     """
 *     Are we currently on the alternate signal stack (see sigaltstack(2))?
 */
  __pyx_codeobj__18 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_on_stack, 182, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__18)) __PYX_ERR(0, 182, __pyx_L1_error)

  /* "cysignals/tests.pyx":196
 * 
 * 
 * def _sig_on():             # <<<<<<<<<<<<<<
 *     """
 *     A single ``sig_on()`` for doctesting purposes. This can never work
 */
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_sig_on, 196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(0, 196, __pyx_L1_error)

  /* "cysignals/tests.pyx":204
 * 
 * 
 * def subpython_err(command, **kwds):             # <<<<<<<<<<<<<<
 *     """
 *     Run ``command`` in a Python subprocess and print the standard error
 */
  __pyx_tuple__20 = PyTuple_Pack(6, __pyx_n_s_command, __pyx_n_s_kwds, __pyx_n_s_argv, __pyx_n_s_P, __pyx_n_s_out, __pyx_n_s_err); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);
  __pyx_codeobj__21 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_subpython_err, 204, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__21)) __PYX_ERR(0, 204, __pyx_L1_error)

  /* "cysignals/tests.pyx":220
 * # (if possible) within a "with nogil" block.                           #
 * ########################################################################
 * def test_sig_off():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__22 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_off, 220, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__22)) __PYX_ERR(0, 220, __pyx_L1_error)

  /* "cysignals/tests.pyx":232
 *         sig_off()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on, 232, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) __PYX_ERR(0, 232, __pyx_L1_error)

  /* "cysignals/tests.pyx":247
 *         infinite_loop()
 * 
 * def test_sig_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__25, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_str, 247, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(0, 247, __pyx_L1_error)

  /* "cysignals/tests.pyx":267
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_cython, 267, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 267, __pyx_L1_error)

  /* "cysignals/tests.pyx":284
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_codeobj__30 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__29, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_cython_except, 284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__30)) __PYX_ERR(0, 284, __pyx_L1_error)

  /* "cysignals/tests.pyx":302
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);
  __pyx_codeobj__32 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_cython_except_all, 302, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__32)) __PYX_ERR(0, 302, __pyx_L1_error)

  /* "cysignals/tests.pyx":316
 *         c_test_sig_on_cython_except_all()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_check, 316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(0, 316, __pyx_L1_error)

  /* "cysignals/tests.pyx":331
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_check_inside_sig_on, 331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(0, 331, __pyx_L1_error)

  /* "cysignals/tests.pyx":351
 * # Test sig_retry() and sig_error()                                     #
 * ########################################################################
 * def test_sig_retry():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_n_s_v); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);
  __pyx_codeobj__38 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__37, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_retry, 351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__38)) __PYX_ERR(0, 351, __pyx_L1_error)

  /* "cysignals/tests.pyx":370
 *     return v
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__39 = PyTuple_Pack(2, __pyx_n_s_delay, __pyx_n_s_v); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__39, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_retry_and_signal, 370, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) __PYX_ERR(0, 370, __pyx_L1_error)

  /* "cysignals/tests.pyx":390
 *         infinite_loop()
 * 
 * def test_sig_error():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_error, 390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 390, __pyx_L1_error)

  /* "cysignals/tests.pyx":409
 * # Test no_except macros                                                #
 * ########################################################################
 * def test_sig_on_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_no_except, 409, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(0, 409, __pyx_L1_error)

  /* "cysignals/tests.pyx":438
 *     infinite_loop()
 * 
 * def test_sig_str_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_str_no_except, 438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(0, 438, __pyx_L1_error)

  /* "cysignals/tests.pyx":461
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__46 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_check_no_except, 461, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 461, __pyx_L1_error)

  /* "cysignals/tests.pyx":482
 * # Test different signals                                               #
 * ########################################################################
 * def test_signal_segv(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__48 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_segv, 482, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 482, __pyx_L1_error)

  /* "cysignals/tests.pyx":498
 *         infinite_loop()
 * 
 * def test_signal_fpe(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_fpe, 498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 498, __pyx_L1_error)

  /* "cysignals/tests.pyx":514
 *         infinite_loop()
 * 
 * def test_signal_ill(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_ill, 514, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 514, __pyx_L1_error)

  /* "cysignals/tests.pyx":530
 *         infinite_loop()
 * 
 * def test_signal_abrt(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__54, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_abrt, 530, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 530, __pyx_L1_error)

  /* "cysignals/tests.pyx":546
 *         infinite_loop()
 * 
 * def test_signal_bus(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__56, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_bus, 546, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 546, __pyx_L1_error)

  /* "cysignals/tests.pyx":562
 *         infinite_loop()
 * 
 * def test_signal_quit(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__58, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_quit, 562, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 562, __pyx_L1_error)

  /* "cysignals/tests.pyx":584
 * # Test with "true" errors (not signals raised by hand)                 #
 * ########################################################################
 * def test_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_dereference_null_pointer, 584, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) __PYX_ERR(0, 584, __pyx_L1_error)

  /* "cysignals/tests.pyx":604
 *         dereference_null_pointer()
 * 
 * def unguarded_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_unguarded_dereference_null_point, 604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(0, 604, __pyx_L1_error)

  /* "cysignals/tests.pyx":633
 * 
 * 
 * def test_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_abort, 633, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(0, 633, __pyx_L1_error)

  /* "cysignals/tests.pyx":648
 *         abort()
 * 
 * def unguarded_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_unguarded_abort, 648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 648, __pyx_L1_error)

  /* "cysignals/tests.pyx":668
 * 
 * 
 * def test_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_stack_overflow, 668, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(0, 668, __pyx_L1_error)

  /* "cysignals/tests.pyx":683
 *         stack_overflow()
 * 
 * def unguarded_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_unguarded_stack_overflow, 683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(0, 683, __pyx_L1_error)

  /* "cysignals/tests.pyx":703
 * 
 * 
 * def test_access_mmap_noreserve():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_n_s_ptr); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);
  __pyx_codeobj__67 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__66, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_access_mmap_noreserve, 703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__67)) __PYX_ERR(0, 703, __pyx_L1_error)

  /* "cysignals/tests.pyx":726
 * 
 * 
 * def test_bad_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_tuple__68 = PyTuple_Pack(2, __pyx_n_s_delay, __pyx_n_s_s); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__68, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_bad_str, 726, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(0, 726, __pyx_L1_error)

  /* "cysignals/tests.pyx":752
 * # Test various usage scenarios for sig_on()/sig_off()                  #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__70 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);
  __pyx_codeobj__71 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__70, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_cython_after_delay, 752, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__71)) __PYX_ERR(0, 752, __pyx_L1_error)

  /* "cysignals/tests.pyx":768
 *         abort()              # This should not be reached
 * 
 * def test_sig_on_inside_try(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__72, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_on_inside_try, 768, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(0, 768, __pyx_L1_error)

  /* "cysignals/tests.pyx":785
 * 
 * 
 * def test_interrupt_bomb(long n=100, long p=10):             # <<<<<<<<<<<<<<
 *     """
 *     Have `p` processes each sending `n` interrupts in very quick
 */
  __pyx_tuple__74 = PyTuple_Pack(4, __pyx_n_s_n, __pyx_n_s_p, __pyx_n_s_i, __pyx_n_s_base_delay); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);
  __pyx_codeobj__75 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__74, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_interrupt_bomb, 785, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__75)) __PYX_ERR(0, 785, __pyx_L1_error)

  /* "cysignals/tests.pyx":822
 * # Special thanks to Robert Bradshaw for suggesting the try/finally
 * # construction. -- Jeroen Demeyer
 * def test_try_finally_signal(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__76, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_try_finally_signal, 822, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(0, 822, __pyx_L1_error)

  /* "cysignals/tests.pyx":843
 *         sig_off()
 * 
 * def test_try_finally_raise():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_try_finally_raise, 843, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(0, 843, __pyx_L1_error)

  /* "cysignals/tests.pyx":863
 *         sig_off()
 * 
 * def test_try_finally_return():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), doing a
 */
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_try_finally_return, 863, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 863, __pyx_L1_error)

  /* "cysignals/tests.pyx":886
 * ########################################################################
 * 
 * def print_sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Print the exception which is currently being handled.
 */
  __pyx_tuple__80 = PyTuple_Pack(3, __pyx_n_s_exc, __pyx_n_s_e, __pyx_n_s_t); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__80, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_print_sig_occurred, 886, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(0, 886, __pyx_L1_error)

  /* "cysignals/tests.pyx":947
 * 
 * 
 * def test_sig_occurred_finally():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__82 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_occurred_finally, 947, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__82)) __PYX_ERR(0, 947, __pyx_L1_error)

  /* "cysignals/tests.pyx":971
 * 
 * 
 * def test_sig_occurred_live_exception():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_occurred_live_exception, 971, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 971, __pyx_L1_error)

  /* "cysignals/tests.pyx":990
 * 
 * 
 * def test_sig_occurred_dealloc():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__84 = PyTuple_Pack(1, __pyx_n_s_x); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_occurred_dealloc, 990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 990, __pyx_L1_error)

  /* "cysignals/tests.pyx":1009
 * 
 * 
 * def test_sig_occurred_dealloc_in_gc():             # <<<<<<<<<<<<<<
 *     """
 *     Regression test for https://github.com/sagemath/cysignals/issues/126
 */
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_occurred_dealloc_in_gc, 1009, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) __PYX_ERR(0, 1009, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__87 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__87, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)
 */
  __pyx_tuple__89 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__89, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "cysignals/tests.pyx":1067
 * # Test sig_block()/sig_unblock()                                       #
 * ########################################################################
 * def test_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__91 = PyTuple_Pack(2, __pyx_n_s_delay, __pyx_n_s_v); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_block, 1067, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(0, 1067, __pyx_L1_error)

  /* "cysignals/tests.pyx":1093
 *     return 1
 * 
 * def test_sig_block_nested(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__93 = PyTuple_Pack(2, __pyx_n_s_delay, __pyx_n_s_v); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_block_nested, 1093, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(0, 1093, __pyx_L1_error)

  /* "cysignals/tests.pyx":1126
 *     return 1
 * 
 * def test_sig_block_outside_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_tuple__95 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sig_block_outside_sig_on, 1126, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(0, 1126, __pyx_L1_error)

  /* "cysignals/tests.pyx":1152
 *     abort()   # This should not be reached
 * 
 * def test_signal_during_malloc(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a signal arriving during a sig_malloc() or sig_free() call.
 */
  __pyx_tuple__97 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_signal_during_malloc, 1152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 1152, __pyx_L1_error)

  /* "cysignals/tests.pyx":1177
 * # Benchmarking functions                                               #
 * ########################################################################
 * def sig_on_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_on()`` and ``sig_off()`` 1 million times.
 */
  __pyx_tuple__99 = PyTuple_Pack(1, __pyx_n_s_i); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_sig_on_bench, 1177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(0, 1177, __pyx_L1_error)

  /* "cysignals/tests.pyx":1193
 *             sig_off()
 * 
 * def sig_check_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_check()`` 1 million times.
 */
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_n_s_i); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);
  __pyx_codeobj__102 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_sig_check_bench, 1193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__102)) __PYX_ERR(0, 1193, __pyx_L1_error)

  /* "cysignals/tests.pyx":1212
 * # Test SIGHUP                                                          #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__103 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__103, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sighup, 1212, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(0, 1212, __pyx_L1_error)

  /* "cysignals/tests.pyx":1230
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_tuple__105 = PyTuple_Pack(1, __pyx_n_s_delay); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__105, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_sighup_and_sigint, 1230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(0, 1230, __pyx_L1_error)

  /* "cysignals/tests.pyx":1255
 *         sig_off()
 * 
 * def test_graceful_exit():             # <<<<<<<<<<<<<<
 *     r"""
 *     Start a subprocess, set up some ``atexit`` handler and kill the
 */
  __pyx_tuple__107 = PyTuple_Pack(4, __pyx_n_s_atexit, __pyx_n_s_sys, __pyx_n_s_goodbye, __pyx_n_s_goodbye); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 1255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_graceful_exit, 1255, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(0, 1255, __pyx_L1_error)

  /* "cysignals/tests.pyx":1299
 * ########################################################################
 * 
 * def test_thread_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test that calling ``sig_block``/``sig_unblock`` is thread-safe.
 */
  __pyx_tuple__109 = PyTuple_Pack(3, __pyx_n_s_delay, __pyx_n_s_t1, __pyx_n_s_t2); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);
  __pyx_codeobj__110 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__109, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_src_cysignals_tests_pyx, __pyx_n_s_test_thread_sig_block, 1299, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__110)) __PYX_ERR(0, 1299, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_DeallocDebug(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__111 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);
  __pyx_codeobj__112 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__111, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_DeallocDebug, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__112)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  #if CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_InitString(__pyx_string_tab[0], &__pyx_kp_u_Are_we_currently_on_the_alterna) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[1], &__pyx_n_s_BaseException) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[2], &__pyx_kp_u_Call_sig_check_1_million_times) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[3], &__pyx_kp_u_Call_sig_on_and_sig_off_1_milli) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[4], &__pyx_n_s_DeallocDebug) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[5], &__pyx_n_s_DeallocDebug___reduce_cython) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[6], &__pyx_n_s_DeallocDebug___setstate_cython) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[7], &__pyx_kp_s_Decorator_class_which_makes_a_f) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[8], &__pyx_kp_s_Everything_ok) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[9], &__pyx_n_s_GO) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[10], &__pyx_kp_s_Goodbye) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[11], &__pyx_kp_u_Have_p_processes_each_sending_n) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[12], &__pyx_kp_s_Incompatible_checksums_s_vs_0xda) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[13], &__pyx_n_s_KeyboardInterrupt) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[14], &__pyx_n_s_MemoryError) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[15], &__pyx_kp_s_No_current_exception) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[16], &__pyx_n_s_P) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[17], &__pyx_n_s_PIPE) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[18], &__pyx_n_s_PickleError) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[19], &__pyx_n_s_Popen) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[20], &__pyx_kp_u_Print_the_exception_which_is_cu) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[21], &__pyx_kp_u_Received) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[22], &__pyx_kp_u_Regression_test_for_https_githu) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[23], &__pyx_n_s_RuntimeError) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[24], &__pyx_kp_u_Send_an_interrupt_signal_SIGINT) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[25], &__pyx_kp_u_Start_a_subprocess_set_up_some) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[26], &__pyx_n_s_Success) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[27], &__pyx_kp_u_TESTS_Regression_test_for_https) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[28], &__pyx_kp_u_TESTS_This_test_should_result_i) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[29], &__pyx_kp_u_TESTS_We_run_Python_in_a_subpro) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[30], &__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[31], &__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[32], &__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[33], &__pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[34], &__pyx_kp_u_TESTS_from_cysignals_tests_impo) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[35], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_10) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[36], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_11) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[37], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_12) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[38], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_13) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[39], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_14) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[40], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_15) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[41], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_16) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[42], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_17) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[43], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_18) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[44], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_19) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[45], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[46], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_20) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[47], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_21) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[48], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_22) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[49], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_23) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[50], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_24) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[51], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_25) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[52], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_26) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[53], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_27) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[54], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_28) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[55], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_29) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[56], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[57], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[58], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[59], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[60], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[61], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_8) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[62], &__pyx_kp_u_TESTS_from_cysignals_tests_impo_9) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[63], &__pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[64], &__pyx_kp_u_Test_a_basic_SIGHUP_signal_whic) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[65], &__pyx_kp_u_Test_a_signal_arriving_during_a) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[66], &__pyx_kp_u_Test_a_try_finally_construct_fo) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[67], &__pyx_kp_u_Test_a_try_finally_construct_fo_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[68], &__pyx_kp_u_Test_a_try_finally_construct_fo_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[69], &__pyx_kp_u_Test_that_calling_sig_block_sig) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[70], &__pyx_kp_s_Unexpected_zero_returned_from_si) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[71], &__pyx_n_s_ValueError) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[72], &__pyx_n_s__113) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[73], &__pyx_kp_u__2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[74], &__pyx_kp_s__4) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[75], &__pyx_n_s__6) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[76], &__pyx_n_s_args) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[77], &__pyx_n_s_argv) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[78], &__pyx_n_s_atexit) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[79], &__pyx_n_s_base_delay) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[80], &__pyx_kp_s_c) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[81], &__pyx_n_s_call) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[82], &__pyx_n_s_cline_in_traceback) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[83], &__pyx_n_s_command) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[84], &__pyx_n_s_communicate) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[85], &__pyx_n_s_cysignals_tests) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[86], &__pyx_kp_s_dealloc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[87], &__pyx_n_s_delay) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[88], &__pyx_n_s_dict) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[89], &__pyx_n_s_dict_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[90], &__pyx_n_s_doc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[91], &__pyx_n_s_e) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[92], &__pyx_n_s_err) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[93], &__pyx_n_s_exc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[94], &__pyx_n_s_executable) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[95], &__pyx_kp_s_failed_to_allocate_s_bytes) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[96], &__pyx_kp_s_failed_to_allocate_s_s_bytes) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[97], &__pyx_n_s_flush) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[98], &__pyx_n_s_func) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[99], &__pyx_n_s_getstate) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[100], &__pyx_n_s_goodbye) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[101], &__pyx_n_s_i) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[102], &__pyx_n_s_import) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[103], &__pyx_n_s_init) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[104], &__pyx_n_s_init_subclass) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[105], &__pyx_n_s_initializing) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[106], &__pyx_n_s_interrupt_after_delay) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[107], &__pyx_kp_u_interrupt_after_delay_line_154) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[108], &__pyx_kp_u_interrupts) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[109], &__pyx_n_s_items) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[110], &__pyx_n_s_kwds) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[111], &__pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[112], &__pyx_n_s_metaclass) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[113], &__pyx_kp_u_mmap_failed_errno) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[114], &__pyx_n_s_module) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[115], &__pyx_n_s_ms_delay) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[116], &__pyx_kp_u_munmap_failed_errno) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[117], &__pyx_n_s_n) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[118], &__pyx_n_s_name) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[119], &__pyx_n_s_new) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[120], &__pyx_n_s_object) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[121], &__pyx_n_s_on_stack) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[122], &__pyx_kp_u_on_stack_line_182) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[123], &__pyx_n_s_out) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[124], &__pyx_n_s_p) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[125], &__pyx_n_s_pickle) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[126], &__pyx_n_s_prepare) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[127], &__pyx_n_s_print) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[128], &__pyx_n_s_print_sig_occurred) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[129], &__pyx_kp_u_print_sig_occurred_line_886) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[130], &__pyx_n_s_ptr) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[131], &__pyx_n_s_pyx_PickleError) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[132], &__pyx_n_s_pyx_checksum) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[133], &__pyx_n_s_pyx_result) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[134], &__pyx_n_s_pyx_state) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[135], &__pyx_n_s_pyx_type) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[136], &__pyx_n_s_pyx_unpickle_DeallocDebug) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[137], &__pyx_n_s_qualname) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[138], &__pyx_n_s_range) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[139], &__pyx_n_s_reduce) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[140], &__pyx_n_s_reduce_cython) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[141], &__pyx_n_s_reduce_ex) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[142], &__pyx_n_s_register) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[143], &__pyx_n_s_return_exception) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[144], &__pyx_n_s_return_exception___call) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[145], &__pyx_n_s_return_exception___init) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[146], &__pyx_n_s_s) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[147], &__pyx_n_s_self) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[148], &__pyx_n_s_set_debug_level) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[149], &__pyx_n_s_set_name) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[150], &__pyx_n_s_setstate) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[151], &__pyx_n_s_setstate_cython) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[152], &__pyx_n_s_sig_check_bench) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[153], &__pyx_kp_u_sig_check_bench_line_1193) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[154], &__pyx_n_s_sig_on) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[155], &__pyx_n_s_sig_on_bench) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[156], &__pyx_kp_u_sig_on_bench_line_1177) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[157], &__pyx_n_s_signals) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[158], &__pyx_n_s_spec) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[159], &__pyx_kp_s_src_cysignals_tests_pyx) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[160], &__pyx_n_s_state) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[161], &__pyx_n_s_stderr) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[162], &__pyx_n_s_stdout) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[163], &__pyx_kp_s_stringsource) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[164], &__pyx_n_s_subprocess) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[165], &__pyx_n_s_subpython_err) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[166], &__pyx_n_s_super) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[167], &__pyx_n_s_sys) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[168], &__pyx_n_s_t) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[169], &__pyx_n_s_t1) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[170], &__pyx_n_s_t2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[171], &__pyx_n_s_test) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[172], &__pyx_n_s_test_abort) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[173], &__pyx_kp_u_test_abort_line_633) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[174], &__pyx_n_s_test_access_mmap_noreserve) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[175], &__pyx_kp_u_test_access_mmap_noreserve_line) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[176], &__pyx_n_s_test_bad_str) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[177], &__pyx_kp_u_test_bad_str_line_726) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[178], &__pyx_n_s_test_dereference_null_pointer) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[179], &__pyx_kp_u_test_dereference_null_pointer_li) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[180], &__pyx_n_s_test_graceful_exit) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[181], &__pyx_kp_u_test_graceful_exit_line_1255) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[182], &__pyx_n_s_test_graceful_exit_locals_goodby) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[183], &__pyx_n_s_test_interrupt_bomb) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[184], &__pyx_kp_u_test_interrupt_bomb_line_785) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[185], &__pyx_n_s_test_sig_block) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[186], &__pyx_kp_u_test_sig_block_line_1067) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[187], &__pyx_n_s_test_sig_block_nested) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[188], &__pyx_kp_u_test_sig_block_nested_line_1093) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[189], &__pyx_n_s_test_sig_block_outside_sig_on) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[190], &__pyx_kp_u_test_sig_block_outside_sig_on_li) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[191], &__pyx_n_s_test_sig_check) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[192], &__pyx_n_s_test_sig_check_inside_sig_on) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[193], &__pyx_kp_u_test_sig_check_inside_sig_on_lin) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[194], &__pyx_kp_u_test_sig_check_line_316) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[195], &__pyx_n_s_test_sig_check_no_except) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[196], &__pyx_kp_u_test_sig_check_no_except_line_46) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[197], &__pyx_n_s_test_sig_error) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[198], &__pyx_kp_u_test_sig_error_line_390) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[199], &__pyx_n_s_test_sig_occurred_dealloc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[200], &__pyx_n_s_test_sig_occurred_dealloc_in_gc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[201], &__pyx_kp_u_test_sig_occurred_dealloc_in_gc_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[202], &__pyx_kp_u_test_sig_occurred_dealloc_line_9) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[203], &__pyx_n_s_test_sig_occurred_finally) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[204], &__pyx_kp_u_test_sig_occurred_finally_line_9) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[205], &__pyx_n_s_test_sig_occurred_live_exception) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[206], &__pyx_kp_u_test_sig_occurred_live_exception_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[207], &__pyx_n_s_test_sig_off) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[208], &__pyx_kp_u_test_sig_off_line_220) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[209], &__pyx_n_s_test_sig_on) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[210], &__pyx_n_s_test_sig_on_cython) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[211], &__pyx_n_s_test_sig_on_cython_after_delay) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[212], &__pyx_kp_u_test_sig_on_cython_after_delay_l) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[213], &__pyx_n_s_test_sig_on_cython_except) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[214], &__pyx_n_s_test_sig_on_cython_except_all) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[215], &__pyx_kp_u_test_sig_on_cython_except_all_li) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[216], &__pyx_kp_u_test_sig_on_cython_except_line_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[217], &__pyx_kp_u_test_sig_on_cython_line_267) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[218], &__pyx_n_s_test_sig_on_inside_try) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[219], &__pyx_kp_u_test_sig_on_inside_try_line_768) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[220], &__pyx_kp_u_test_sig_on_line_232) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[221], &__pyx_n_s_test_sig_on_no_except) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[222], &__pyx_kp_u_test_sig_on_no_except_line_409) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[223], &__pyx_n_s_test_sig_retry) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[224], &__pyx_n_s_test_sig_retry_and_signal) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[225], &__pyx_kp_u_test_sig_retry_and_signal_line_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[226], &__pyx_kp_u_test_sig_retry_line_351) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[227], &__pyx_n_s_test_sig_str) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[228], &__pyx_kp_u_test_sig_str_line_247) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[229], &__pyx_n_s_test_sig_str_no_except) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[230], &__pyx_kp_u_test_sig_str_no_except_line_438) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[231], &__pyx_n_s_test_sighup) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[232], &__pyx_n_s_test_sighup_and_sigint) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[233], &__pyx_kp_u_test_sighup_and_sigint_line_1230) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[234], &__pyx_kp_u_test_sighup_line_1212) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[235], &__pyx_n_s_test_signal_abrt) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[236], &__pyx_kp_u_test_signal_abrt_line_530) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[237], &__pyx_n_s_test_signal_bus) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[238], &__pyx_kp_u_test_signal_bus_line_546) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[239], &__pyx_n_s_test_signal_during_malloc) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[240], &__pyx_kp_u_test_signal_during_malloc_line_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[241], &__pyx_n_s_test_signal_fpe) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[242], &__pyx_kp_u_test_signal_fpe_line_498) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[243], &__pyx_n_s_test_signal_ill) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[244], &__pyx_kp_u_test_signal_ill_line_514) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[245], &__pyx_n_s_test_signal_quit) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[246], &__pyx_kp_u_test_signal_quit_line_562) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[247], &__pyx_n_s_test_signal_segv) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[248], &__pyx_kp_u_test_signal_segv_line_482) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[249], &__pyx_n_s_test_stack_overflow) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[250], &__pyx_kp_u_test_stack_overflow_line_668) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[251], &__pyx_n_s_test_thread_sig_block) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[252], &__pyx_kp_u_test_thread_sig_block_line_1299) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[253], &__pyx_n_s_test_try_finally_raise) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[254], &__pyx_kp_u_test_try_finally_raise_line_843) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[255], &__pyx_n_s_test_try_finally_return) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[256], &__pyx_kp_u_test_try_finally_return_line_863) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[257], &__pyx_n_s_test_try_finally_signal) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[258], &__pyx_kp_u_test_try_finally_signal_line_822) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[259], &__pyx_n_s_unguarded_abort) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[260], &__pyx_kp_u_unguarded_abort_line_648) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[261], &__pyx_n_s_unguarded_dereference_null_point) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[262], &__pyx_kp_u_unguarded_dereference_null_point_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[263], &__pyx_n_s_unguarded_stack_overflow) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[264], &__pyx_kp_u_unguarded_stack_overflow_line_68) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[265], &__pyx_n_s_universal_newlines) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[266], &__pyx_n_s_update) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[267], &__pyx_n_s_use_setstate) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[268], &__pyx_n_s_v) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[269], &__pyx_n_s_write) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  if (__Pyx_InitString(__pyx_string_tab[270], &__pyx_n_s_x) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  #endif
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_42 = PyInt_FromLong(42); if (unlikely(!__pyx_int_42)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_500 = PyInt_FromLong(500); if (unlikely(!__pyx_int_500)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228825662 = PyInt_FromLong(228825662L); if (unlikely(!__pyx_int_228825662)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_COMPILING_IN_LIMITED_API
  __pyx_type_9cysignals_5tests_DeallocDebug = PyType_FromSpec(&__pyx_type_9cysignals_5tests_DeallocDebug_spec); if (unlikely(!__pyx_type_9cysignals_5tests_DeallocDebug)) __PYX_ERR(0, 1058, __pyx_L1_error)
  #else
  if (PyType_Ready(&__pyx_type_9cysignals_5tests_DeallocDebug) < 0) __PYX_ERR(0, 1058, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3
  __pyx_type_9cysignals_5tests_DeallocDebug.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9cysignals_5tests_DeallocDebug.tp_dictoffset && __pyx_type_9cysignals_5tests_DeallocDebug.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9cysignals_5tests_DeallocDebug.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_COMPILING_IN_LIMITED_API
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DeallocDebug, __pyx_type_9cysignals_5tests_DeallocDebug) < 0) __PYX_ERR(0, 1058, __pyx_L1_error)
  #else
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DeallocDebug, (PyObject *)&__pyx_type_9cysignals_5tests_DeallocDebug) < 0) __PYX_ERR(0, 1058, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_9cysignals_5tests_DeallocDebug) < 0) __PYX_ERR(0, 1058, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_9cysignals_5tests_DeallocDebug = (PyTypeObject *)__pyx_type_9cysignals_5tests_DeallocDebug;
  #else
  __pyx_ptype_9cysignals_5tests_DeallocDebug = &__pyx_type_9cysignals_5tests_DeallocDebug;
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(4, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(5, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __pyx_t_1 = PyImport_ImportModule("cysignals.signals"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr(__pyx_t_1, "cysigs", (void **)&__pyx_vp_9cysignals_7signals_cysigs, "cysigs_t") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("cysignals.signals"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction(__pyx_t_1, "verify_exc_value", (void (**)(void))&__pyx_f_9cysignals_7signals_verify_exc_value, "void (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "_sig_on_interrupt_received", (void (**)(void))&_sig_on_interrupt_received, "void (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "_sig_on_recover", (void (**)(void))&_sig_on_recover, "void (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "_sig_off_warning", (void (**)(void))&_sig_off_warning, "void (char const *, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction(__pyx_t_1, "print_backtrace", (void (**)(void))&print_backtrace, "void (void)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_tests(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_tests},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "tests",
      __pyx_k_Test_interrupt_and_signal_handl, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_COMPILING_IN_LIMITED_API
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_COMPILING_IN_LIMITED_API
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC inittests(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC inittests(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_tests(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_tests(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_tests(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'tests' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("tests", __pyx_methods, __pyx_k_Test_interrupt_and_signal_handl, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_COMPILING_IN_LIMITED_API
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyState_AddModule(__pyx_t_1, &__pyx_moduledef) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_tests(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_cysignals__tests) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "cysignals.tests")) {
      if (unlikely(PyDict_SetItemString(modules, "cysignals.tests", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_variable_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_function_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "cysignals/tests.pyx":76
 * 
 * # Default delay in milliseconds before raising signals
 * cdef long DEFAULT_DELAY = 200             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_9cysignals_5tests_DEFAULT_DELAY = 0xC8;

  /* "cysignals/tests.pyx":79
 * 
 * 
 * import sys             # <<<<<<<<<<<<<<
 * from subprocess import Popen, PIPE
 * 
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_sys, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":80
 * 
 * import sys
 * from subprocess import Popen, PIPE             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Popen);
  __Pyx_GIVEREF(__pyx_n_s_Popen);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Popen);
  __Pyx_INCREF(__pyx_n_s_PIPE);
  __Pyx_GIVEREF(__pyx_n_s_PIPE);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_PIPE);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_subprocess, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Popen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Popen, __pyx_t_1) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PIPE, __pyx_t_1) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":87
 * ########################################################################
 * 
 * from .signals import set_debug_level             # <<<<<<<<<<<<<<
 * set_debug_level(0)
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_set_debug_level);
  __Pyx_GIVEREF(__pyx_n_s_set_debug_level);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_set_debug_level);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_signals, __pyx_t_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_set_debug_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_debug_level, __pyx_t_2) < 0) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":88
 * 
 * from .signals import set_debug_level
 * set_debug_level(0)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_set_debug_level); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":129
 * ########################################################################
 * 
 * class return_exception(object):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator class which makes a function *return* an exception which
 */
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_tuple__10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_tuple__10, __pyx_n_s_return_exception, __pyx_n_s_return_exception, (PyObject *) NULL, __pyx_n_s_cysignals_tests, __pyx_kp_s_Decorator_class_which_makes_a_f); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "cysignals/tests.pyx":144
 * 
 *     """
 *     def __init__ (self, func):             # <<<<<<<<<<<<<<
 *         self.func = func
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_16return_exception_1__init__, 0, __pyx_n_s_return_exception___init, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__12)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_init, __pyx_t_3) < 0) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":147
 *         self.func = func
 * 
 *     def __call__ (self, *args):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.func(*args)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_16return_exception_3__call__, 0, __pyx_n_s_return_exception___call, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__14)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_call, __pyx_t_3) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":129
 * ########################################################################
 * 
 * class return_exception(object):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator class which makes a function *return* an exception which
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_return_exception, __pyx_tuple__10, __pyx_t_1, NULL, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_return_exception, __pyx_t_3) < 0) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":154
 * 
 * 
 * def interrupt_after_delay(ms_delay=500):             # <<<<<<<<<<<<<<
 *     """
 *     Send an interrupt signal (``SIGINT``) to the process after a delay of
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_1interrupt_after_delay, 0, __pyx_n_s_interrupt_after_delay, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__17);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_interrupt_after_delay, __pyx_t_2) < 0) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":182
 * 
 * 
 * def on_stack():             # <<<<<<<<<<<<<<
 *     """
 *     Are we currently on the alternate signal stack (see sigaltstack(2))?
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_3on_stack, 0, __pyx_n_s_on_stack, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__18)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_on_stack, __pyx_t_2) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":196
 * 
 * 
 * def _sig_on():             # <<<<<<<<<<<<<<
 *     """
 *     A single ``sig_on()`` for doctesting purposes. This can never work
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_5_sig_on, 0, __pyx_n_s_sig_on, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__19)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sig_on, __pyx_t_2) < 0) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":204
 * 
 * 
 * def subpython_err(command, **kwds):             # <<<<<<<<<<<<<<
 *     """
 *     Run ``command`` in a Python subprocess and print the standard error
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_7subpython_err, 0, __pyx_n_s_subpython_err, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__21)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_subpython_err, __pyx_t_2) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":220
 * # (if possible) within a "with nogil" block.                           #
 * ########################################################################
 * def test_sig_off():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_9test_sig_off, 0, __pyx_n_s_test_sig_off, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__22)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_off, __pyx_t_2) < 0) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":232
 *         sig_off()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_11test_sig_on, 0, __pyx_n_s_test_sig_on, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults), 0)) __PYX_ERR(0, 232, __pyx_L1_error)

  /* "cysignals/tests.pyx":233
 * 
 * @return_exception
 * def test_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_108__defaults__);

  /* "cysignals/tests.pyx":232
 *         sig_off()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on, __pyx_t_3) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":247
 *         infinite_loop()
 * 
 * def test_sig_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_13test_sig_str, 0, __pyx_n_s_test_sig_str, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_3, sizeof(__pyx_defaults1), 0)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_3)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_3, __pyx_pf_9cysignals_5tests_110__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_str, __pyx_t_3) < 0) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":267
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_15test_sig_on_cython, 0, __pyx_n_s_test_sig_on_cython, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults2), 0)) __PYX_ERR(0, 267, __pyx_L1_error)

  /* "cysignals/tests.pyx":268
 * 
 * @return_exception
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_112__defaults__);

  /* "cysignals/tests.pyx":267
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_cython, __pyx_t_2) < 0) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":284
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_17test_sig_on_cython_except, 0, __pyx_n_s_test_sig_on_cython_except, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__30)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults3), 0)) __PYX_ERR(0, 284, __pyx_L1_error)

  /* "cysignals/tests.pyx":285
 * 
 * @return_exception
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_114__defaults__);

  /* "cysignals/tests.pyx":284
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_cython_except, __pyx_t_3) < 0) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":302
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_19test_sig_on_cython_except_all, 0, __pyx_n_s_test_sig_on_cython_except_all, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__32)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults4), 0)) __PYX_ERR(0, 302, __pyx_L1_error)

  /* "cysignals/tests.pyx":303
 * 
 * @return_exception
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_116__defaults__);

  /* "cysignals/tests.pyx":302
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_except_all(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_cython_except_all, __pyx_t_2) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":316
 *         c_test_sig_on_cython_except_all()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_21test_sig_check, 0, __pyx_n_s_test_sig_check, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults5), 0)) __PYX_ERR(0, 316, __pyx_L1_error)

  /* "cysignals/tests.pyx":317
 * 
 * @return_exception
 * def test_sig_check(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_118__defaults__);

  /* "cysignals/tests.pyx":316
 *         c_test_sig_on_cython_except_all()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_check, __pyx_t_3) < 0) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":331
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_23test_sig_check_inside_sig_on, 0, __pyx_n_s_test_sig_check_inside_sig_on, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults6), 0)) __PYX_ERR(0, 331, __pyx_L1_error)

  /* "cysignals/tests.pyx":332
 * 
 * @return_exception
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_120__defaults__);

  /* "cysignals/tests.pyx":331
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_inside_sig_on(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_check_inside_sig_on, __pyx_t_2) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":351
 * # Test sig_retry() and sig_error()                                     #
 * ########################################################################
 * def test_sig_retry():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_25test_sig_retry, 0, __pyx_n_s_test_sig_retry, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__38)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_retry, __pyx_t_2) < 0) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":370
 *     return v
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_27test_sig_retry_and_signal, 0, __pyx_n_s_test_sig_retry_and_signal, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults7), 0)) __PYX_ERR(0, 370, __pyx_L1_error)

  /* "cysignals/tests.pyx":371
 * 
 * @return_exception
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_122__defaults__);

  /* "cysignals/tests.pyx":370
 *     return v
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_retry_and_signal(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_retry_and_signal, __pyx_t_3) < 0) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":390
 *         infinite_loop()
 * 
 * def test_sig_error():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_29test_sig_error, 0, __pyx_n_s_test_sig_error, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_error, __pyx_t_3) < 0) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":409
 * # Test no_except macros                                                #
 * ########################################################################
 * def test_sig_on_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_31test_sig_on_no_except, 0, __pyx_n_s_test_sig_on_no_except, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_3, sizeof(__pyx_defaults8), 0)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_t_3)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_3, __pyx_pf_9cysignals_5tests_124__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_no_except, __pyx_t_3) < 0) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":438
 *     infinite_loop()
 * 
 * def test_sig_str_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_33test_sig_str_no_except, 0, __pyx_n_s_test_sig_str_no_except, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_3, sizeof(__pyx_defaults9), 0)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_t_3)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_3, __pyx_pf_9cysignals_5tests_126__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_str_no_except, __pyx_t_3) < 0) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":461
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_35test_sig_check_no_except, 0, __pyx_n_s_test_sig_check_no_except, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults10), 0)) __PYX_ERR(0, 461, __pyx_L1_error)

  /* "cysignals/tests.pyx":462
 * 
 * @return_exception
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_128__defaults__);

  /* "cysignals/tests.pyx":461
 *     infinite_loop()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_check_no_except(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_check_no_except, __pyx_t_2) < 0) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":482
 * # Test different signals                                               #
 * ########################################################################
 * def test_signal_segv(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_37test_signal_segv, 0, __pyx_n_s_test_signal_segv, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults11), 0)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_130__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_segv, __pyx_t_2) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":498
 *         infinite_loop()
 * 
 * def test_signal_fpe(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_39test_signal_fpe, 0, __pyx_n_s_test_signal_fpe, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults12), 0)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults12, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_132__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_fpe, __pyx_t_2) < 0) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":514
 *         infinite_loop()
 * 
 * def test_signal_ill(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_41test_signal_ill, 0, __pyx_n_s_test_signal_ill, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults13), 0)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults13, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_134__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_ill, __pyx_t_2) < 0) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":530
 *         infinite_loop()
 * 
 * def test_signal_abrt(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_43test_signal_abrt, 0, __pyx_n_s_test_signal_abrt, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults14), 0)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults14, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_136__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_abrt, __pyx_t_2) < 0) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":546
 *         infinite_loop()
 * 
 * def test_signal_bus(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_45test_signal_bus, 0, __pyx_n_s_test_signal_bus, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults15), 0)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults15, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_138__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_bus, __pyx_t_2) < 0) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":562
 *         infinite_loop()
 * 
 * def test_signal_quit(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_47test_signal_quit, 0, __pyx_n_s_test_signal_quit, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults16), 0)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults16, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_140__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_quit, __pyx_t_2) < 0) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":584
 * # Test with "true" errors (not signals raised by hand)                 #
 * ########################################################################
 * def test_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_49test_dereference_null_pointer, 0, __pyx_n_s_test_dereference_null_pointer, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_dereference_null_pointer, __pyx_t_2) < 0) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":604
 *         dereference_null_pointer()
 * 
 * def unguarded_dereference_null_pointer():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_51unguarded_dereference_null_pointer, 0, __pyx_n_s_unguarded_dereference_null_point, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unguarded_dereference_null_point, __pyx_t_2) < 0) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":633
 * 
 * 
 * def test_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_53test_abort, 0, __pyx_n_s_test_abort, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__62)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_abort, __pyx_t_2) < 0) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":648
 *         abort()
 * 
 * def unguarded_abort():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_55unguarded_abort, 0, __pyx_n_s_unguarded_abort, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unguarded_abort, __pyx_t_2) < 0) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":668
 * 
 * 
 * def test_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_57test_stack_overflow, 0, __pyx_n_s_test_stack_overflow, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__64)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_stack_overflow, __pyx_t_2) < 0) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":683
 *         stack_overflow()
 * 
 * def unguarded_stack_overflow():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_59unguarded_stack_overflow, 0, __pyx_n_s_unguarded_stack_overflow, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unguarded_stack_overflow, __pyx_t_2) < 0) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":703
 * 
 * 
 * def test_access_mmap_noreserve():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_61test_access_mmap_noreserve, 0, __pyx_n_s_test_access_mmap_noreserve, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__67)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_access_mmap_noreserve, __pyx_t_2) < 0) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":726
 * 
 * 
 * def test_bad_str(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_63test_bad_str, 0, __pyx_n_s_test_bad_str, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__69)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults17), 0)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_142__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_bad_str, __pyx_t_2) < 0) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cysignals/tests.pyx":752
 * # Test various usage scenarios for sig_on()/sig_off()                  #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_65test_sig_on_cython_after_delay, 0, __pyx_n_s_test_sig_on_cython_after_delay, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__71)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults18), 0)) __PYX_ERR(0, 752, __pyx_L1_error)

  /* "cysignals/tests.pyx":753
 * ########################################################################
 * @return_exception
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_144__defaults__);

  /* "cysignals/tests.pyx":752
 * # Test various usage scenarios for sig_on()/sig_off()                  #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sig_on_cython_after_delay(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_cython_after_delay, __pyx_t_3) < 0) __PYX_ERR(0, 752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":768
 *         abort()              # This should not be reached
 * 
 * def test_sig_on_inside_try(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_67test_sig_on_inside_try, 0, __pyx_n_s_test_sig_on_inside_try, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__73)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_3, sizeof(__pyx_defaults19), 0)) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_t_3)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_3, __pyx_pf_9cysignals_5tests_146__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_on_inside_try, __pyx_t_3) < 0) __PYX_ERR(0, 768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":785
 * 
 * 
 * def test_interrupt_bomb(long n=100, long p=10):             # <<<<<<<<<<<<<<
 *     """
 *     Have `p` processes each sending `n` interrupts in very quick
 */
  __pyx_t_3 = __Pyx_PyInt_From_long(((long)0x64)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyInt_From_long(((long)10)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_69test_interrupt_bomb, 0, __pyx_n_s_test_interrupt_bomb, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__75)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_interrupt_bomb, __pyx_t_1) < 0) __PYX_ERR(0, 785, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":822
 * # Special thanks to Robert Bradshaw for suggesting the try/finally
 * # construction. -- Jeroen Demeyer
 * def test_try_finally_signal(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_71test_try_finally_signal, 0, __pyx_n_s_test_try_finally_signal, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__77)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults20), 0)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_148__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_try_finally_signal, __pyx_t_1) < 0) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":843
 *         sig_off()
 * 
 * def test_try_finally_raise():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), raising
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_73test_try_finally_raise, 0, __pyx_n_s_test_try_finally_raise, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__78)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_try_finally_raise, __pyx_t_1) < 0) __PYX_ERR(0, 843, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":863
 *         sig_off()
 * 
 * def test_try_finally_return():             # <<<<<<<<<<<<<<
 *     """
 *     Test a try/finally construct for sig_on() and sig_off(), doing a
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_75test_try_finally_return, 0, __pyx_n_s_test_try_finally_return, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_try_finally_return, __pyx_t_1) < 0) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":886
 * ########################################################################
 * 
 * def print_sig_occurred():             # <<<<<<<<<<<<<<
 *     """
 *     Print the exception which is currently being handled.
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_77print_sig_occurred, 0, __pyx_n_s_print_sig_occurred, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_print_sig_occurred, __pyx_t_1) < 0) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":947
 * 
 * 
 * def test_sig_occurred_finally():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_79test_sig_occurred_finally, 0, __pyx_n_s_test_sig_occurred_finally, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__82)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_occurred_finally, __pyx_t_1) < 0) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":971
 * 
 * 
 * def test_sig_occurred_live_exception():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_81test_sig_occurred_live_exception, 0, __pyx_n_s_test_sig_occurred_live_exception, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_occurred_live_exception, __pyx_t_1) < 0) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":990
 * 
 * 
 * def test_sig_occurred_dealloc():             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_83test_sig_occurred_dealloc, 0, __pyx_n_s_test_sig_occurred_dealloc, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_occurred_dealloc, __pyx_t_1) < 0) __PYX_ERR(0, 990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1009
 * 
 * 
 * def test_sig_occurred_dealloc_in_gc():             # <<<<<<<<<<<<<<
 *     """
 *     Regression test for https://github.com/sagemath/cysignals/issues/126
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_85test_sig_occurred_dealloc_in_gc, 0, __pyx_n_s_test_sig_occurred_dealloc_in_gc, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_occurred_dealloc_in_gc, __pyx_t_1) < 0) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_12DeallocDebug_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DeallocDebug___reduce_cython, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9cysignals_5tests_DeallocDebug->tp_dict, __pyx_n_s_reduce_cython, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_9cysignals_5tests_DeallocDebug);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_DeallocDebug, (type(self), 0xda39a3e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_DeallocDebug__set_state(self, __pyx_state)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_12DeallocDebug_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_DeallocDebug___setstate_cython, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_9cysignals_5tests_DeallocDebug->tp_dict, __pyx_n_s_setstate_cython, __pyx_t_1) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_9cysignals_5tests_DeallocDebug);

  /* "cysignals/tests.pyx":1067
 * # Test sig_block()/sig_unblock()                                       #
 * ########################################################################
 * def test_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_87test_sig_block, 0, __pyx_n_s_test_sig_block, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults21), 0)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_150__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_block, __pyx_t_1) < 0) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1093
 *     return 1
 * 
 * def test_sig_block_nested(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_89test_sig_block_nested, 0, __pyx_n_s_test_sig_block_nested, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults22), 0)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_152__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_block_nested, __pyx_t_1) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1126
 *     return 1
 * 
 * def test_sig_block_outside_sig_on(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     TESTS::
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_91test_sig_block_outside_sig_on, 0, __pyx_n_s_test_sig_block_outside_sig_on, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults23), 0)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_154__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sig_block_outside_sig_on, __pyx_t_1) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1152
 *     abort()   # This should not be reached
 * 
 * def test_signal_during_malloc(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a signal arriving during a sig_malloc() or sig_free() call.
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_93test_signal_during_malloc, 0, __pyx_n_s_test_signal_during_malloc, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults24), 0)) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_156__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_signal_during_malloc, __pyx_t_1) < 0) __PYX_ERR(0, 1152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1177
 * # Benchmarking functions                                               #
 * ########################################################################
 * def sig_on_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_on()`` and ``sig_off()`` 1 million times.
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_95sig_on_bench, 0, __pyx_n_s_sig_on_bench, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sig_on_bench, __pyx_t_1) < 0) __PYX_ERR(0, 1177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1193
 *             sig_off()
 * 
 * def sig_check_bench():             # <<<<<<<<<<<<<<
 *     """
 *     Call ``sig_check()`` 1 million times.
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_97sig_check_bench, 0, __pyx_n_s_sig_check_bench, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__102)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sig_check_bench, __pyx_t_1) < 0) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1212
 * # Test SIGHUP                                                          #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_99test_sighup, 0, __pyx_n_s_test_sighup, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults25), 0)) __PYX_ERR(0, 1212, __pyx_L1_error)

  /* "cysignals/tests.pyx":1213
 * ########################################################################
 * @return_exception
 * def test_sighup(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a basic SIGHUP signal, which would normally exit the Python interpreter
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_158__defaults__);

  /* "cysignals/tests.pyx":1212
 * # Test SIGHUP                                                          #
 * ########################################################################
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sighup, __pyx_t_3) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cysignals/tests.pyx":1230
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):
 *     """
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_return_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_101test_sighup_and_sigint, 0, __pyx_n_s_test_sighup_and_sigint, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_2, sizeof(__pyx_defaults26), 0)) __PYX_ERR(0, 1230, __pyx_L1_error)

  /* "cysignals/tests.pyx":1231
 * 
 * @return_exception
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test a SIGHUP and a SIGINT arriving at essentially the same time.
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_t_2)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_2, __pyx_pf_9cysignals_5tests_160__defaults__);

  /* "cysignals/tests.pyx":1230
 *             sig_check()
 * 
 * @return_exception             # <<<<<<<<<<<<<<
 * def test_sighup_and_sigint(long delay=DEFAULT_DELAY):
 *     """
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_sighup_and_sigint, __pyx_t_1) < 0) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1255
 *         sig_off()
 * 
 * def test_graceful_exit():             # <<<<<<<<<<<<<<
 *     r"""
 *     Start a subprocess, set up some ``atexit`` handler and kill the
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_103test_graceful_exit, 0, __pyx_n_s_test_graceful_exit, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_graceful_exit, __pyx_t_1) < 0) __PYX_ERR(0, 1255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1299
 * ########################################################################
 * 
 * def test_thread_sig_block(long delay=DEFAULT_DELAY):             # <<<<<<<<<<<<<<
 *     """
 *     Test that calling ``sig_block``/``sig_unblock`` is thread-safe.
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_105test_thread_sig_block, 0, __pyx_n_s_test_thread_sig_block, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__110)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults27), 0)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_t_1)->__pyx_arg_delay = __pyx_v_9cysignals_5tests_DEFAULT_DELAY;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_9cysignals_5tests_162__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_thread_sig_block, __pyx_t_1) < 0) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_DeallocDebug(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9cysignals_5tests_107__pyx_unpickle_DeallocDebug, 0, __pyx_n_s_pyx_unpickle_DeallocDebug, NULL, __pyx_n_s_cysignals_tests, __pyx_d, ((PyObject *)__pyx_codeobj__112)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_DeallocDebug, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cysignals/tests.pyx":1
 * # cython: preliminary_late_includes_cy28=True             # <<<<<<<<<<<<<<
 * """
 * Test interrupt and signal handling
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(51); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_interrupt_after_delay_line_154, __pyx_kp_u_Send_an_interrupt_signal_SIGINT) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_on_stack_line_182, __pyx_kp_u_Are_we_currently_on_the_alterna) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_off_line_220, __pyx_kp_u_TESTS_from_cysignals_tests_impo) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_line_232, __pyx_kp_u_TESTS_from_cysignals_tests_impo_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_str_line_247, __pyx_kp_u_TESTS_from_cysignals_tests_impo_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_cython_line_267, __pyx_kp_u_TESTS_from_cysignals_tests_impo_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_cython_except_line_2, __pyx_kp_u_TESTS_from_cysignals_tests_impo_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_cython_except_all_li, __pyx_kp_u_TESTS_from_cysignals_tests_impo_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_check_line_316, __pyx_kp_u_TESTS_from_cysignals_tests_impo_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_check_inside_sig_on_lin, __pyx_kp_u_TESTS_from_cysignals_tests_impo_8) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_retry_line_351, __pyx_kp_u_TESTS_from_cysignals_tests_impo_9) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_retry_and_signal_line_3, __pyx_kp_u_TESTS_from_cysignals_tests_impo_10) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_error_line_390, __pyx_kp_u_TESTS_from_cysignals_tests_impo_11) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_no_except_line_409, __pyx_kp_u_TESTS_from_cysignals_tests_impo_12) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_str_no_except_line_438, __pyx_kp_u_TESTS_from_cysignals_tests_impo_13) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_check_no_except_line_46, __pyx_kp_u_TESTS_from_cysignals_tests_impo_14) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_segv_line_482, __pyx_kp_u_TESTS_from_cysignals_tests_impo_15) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_fpe_line_498, __pyx_kp_u_TESTS_from_cysignals_tests_impo_16) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_ill_line_514, __pyx_kp_u_TESTS_from_cysignals_tests_impo_17) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_abrt_line_530, __pyx_kp_u_TESTS_from_cysignals_tests_impo_18) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_bus_line_546, __pyx_kp_u_TESTS_from_cysignals_tests_impo_19) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_quit_line_562, __pyx_kp_u_TESTS_We_run_Python_in_a_subpro) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_dereference_null_pointer_li, __pyx_kp_u_TESTS_This_test_should_result_i) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_unguarded_dereference_null_point_2, __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_abort_line_633, __pyx_kp_u_TESTS_from_cysignals_tests_impo_20) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_unguarded_abort_line_648, __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_stack_overflow_line_668, __pyx_kp_u_TESTS_from_cysignals_tests_impo_21) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_unguarded_stack_overflow_line_68, __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_access_mmap_noreserve_line, __pyx_kp_u_TESTS_Regression_test_for_https) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_bad_str_line_726, __pyx_kp_u_TESTS_We_run_Python_in_a_subpro_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_cython_after_delay_l, __pyx_kp_u_TESTS_from_cysignals_tests_impo_22) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_on_inside_try_line_768, __pyx_kp_u_TESTS_from_cysignals_tests_impo_23) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_interrupt_bomb_line_785, __pyx_kp_u_Have_p_processes_each_sending_n) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_try_finally_signal_line_822, __pyx_kp_u_Test_a_try_finally_construct_fo) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_try_finally_raise_line_843, __pyx_kp_u_Test_a_try_finally_construct_fo_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_try_finally_return_line_863, __pyx_kp_u_Test_a_try_finally_construct_fo_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_print_sig_occurred_line_886, __pyx_kp_u_Print_the_exception_which_is_cu) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_occurred_finally_line_9, __pyx_kp_u_TESTS_from_cysignals_tests_impo_24) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_occurred_live_exception_2, __pyx_kp_u_TESTS_from_cysignals_tests_impo_25) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_occurred_dealloc_line_9, __pyx_kp_u_TESTS_from_cysignals_tests_impo_26) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_occurred_dealloc_in_gc_2, __pyx_kp_u_Regression_test_for_https_githu) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_block_line_1067, __pyx_kp_u_TESTS_from_cysignals_tests_impo_27) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_block_nested_line_1093, __pyx_kp_u_TESTS_from_cysignals_tests_impo_28) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sig_block_outside_sig_on_li, __pyx_kp_u_TESTS_from_cysignals_tests_impo_29) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_signal_during_malloc_line_1, __pyx_kp_u_Test_a_signal_arriving_during_a) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_sig_on_bench_line_1177, __pyx_kp_u_Call_sig_on_and_sig_off_1_milli) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_sig_check_bench_line_1193, __pyx_kp_u_Call_sig_check_1_million_times) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sighup_line_1212, __pyx_kp_u_Test_a_basic_SIGHUP_signal_whic) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_sighup_and_sigint_line_1230, __pyx_kp_u_Test_a_SIGHUP_and_a_SIGINT_arri) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_graceful_exit_line_1255, __pyx_kp_u_Start_a_subprocess_set_up_some) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_test_thread_sig_block_line_1299, __pyx_kp_u_Test_that_calling_sig_block_sig) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cpython/complex.pxd":23
 * 
 *         @property
 *         cdef inline double imag(self):             # <<<<<<<<<<<<<<
 *             return self.cval.imag
 * 
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init cysignals.tests", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(__pyx_m);
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cysignals.tests");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        if (kwds_is_tuple) {
            if (pos >= PyTuple_GET_SIZE(kwds)) break;
            key = PyTuple_GET_ITEM(kwds, pos);
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result;
    Py_ssize_t i;
    argstuple = PyTuple_New(nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        PyTuple_SET_ITEM(argstuple, i, args[i]);
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
    Py_DECREF(argstuple);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
#ifdef __Pyx_CyFunction_USED
        if (__Pyx_IsCyOrPyCFunction(func))
#else
        if (PyCFunction_Check(func))
#endif
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
                return __Pyx_PyObject_CallMethO(func, NULL);
            }
        }
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (PyCFunction_Check(func))
        {
            if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
                return __Pyx_PyObject_CallMethO(func, args[0]);
            }
        }
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    #if CYTHON_VECTORCALL
    vectorcallfunc f = _PyVectorcall_Function(func);
    if (f) {
        return f(func, args, nargs, kwargs);
    }
    #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
    if (__Pyx_CyFunction_CheckExact(func)) {
        __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
        if (f) return f(func, args, nargs, kwargs);
    }
    #endif
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    return __Pyx_PyObject_FastCall_fallback(func, args, nargs, kwargs);
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg = NULL;
    return __Pyx_PyObject_FastCall(func, (&arg)+1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* MergeKeywords */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError))) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define GCC_DIAGNOSTIC
#endif
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_8)[digit_pos];
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_10)[digit_pos];
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY ||  CYTHON_COMPILING_IN_LIMITED_API
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* CIntToPyUnicode */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define GCC_DIAGNOSTIC
#endif
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_long(long value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(long)*3+2];
    char *dpos, *end = digits + sizeof(long)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    long remaining;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (long) (remaining / (8*8));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_8)[digit_pos];
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (long) (remaining / (10*10));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_10)[digit_pos];
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (long) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        if (unlikely(PyTuple_GET_SIZE(kw) == 0))
            return 1;
        if (!kw_allowed) {
            key = PyTuple_GET_ITEM(kw, 0);
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < PyTuple_GET_SIZE(kw); pos++) {
            key = PyTuple_GET_ITEM(kw, pos);
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
#endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                #if CYTHON_COMPILING_IN_LIMITED_API
                module = PyImport_ImportModuleLevelObject(
                    name, empty_dict, empty_dict, from_list, 1);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                #endif
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            #if CYTHON_COMPILING_IN_LIMITED_API
            module = PyImport_ImportModuleLevelObject(
                name, empty_dict, empty_dict, from_list, level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        PyObject *sep;
        PyObject *slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, CYTHON_UNUSED PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__6;
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    Py_ssize_t i, nparts;
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (likely(module))
        return module;
    return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FetchCommonType */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    PyObject *abi_module = PyImport_AddModule((char*) __PYX_ABI_MODULE_NAME);
    if (!abi_module) return NULL;
    Py_INCREF(abi_module);
    return abi_module;
}
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, type->tp_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              type->tp_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, type->tp_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *py_basicsize, *cached_type = NULL;
    Py_ssize_t basicsize;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, spec->name);
    if (cached_type) {
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (!py_basicsize) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred()) goto bad;
        if (__Pyx_VerifyCachedType(
              cached_type,
              spec->name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    cached_type = PyType_FromSpecWithBases(spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (PyObject_SetAttrString(abi_module, spec->name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, Py_ssize_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (i = 0; i < nargs; i++) newargs[i] = args[i];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, Py_ssize_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if PY_VERSION_HEX < 0x030500A0
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         cyfunc->func.m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", cyfunc->func.m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = cyfunc->func.m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = cyfunc->func.m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = cyfunc->func.m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = cyfunc->func.m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = cyfunc->func.m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = cyfunc->func.m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(__pyx_CyFunctionObject, func.vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#ifdef _Py_TPFLAGS_HAVE_VECTORCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(void) {
#if CYTHON_COMPILING_IN_LIMITED_API
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(&__pyx_CyFunctionType_spec, NULL);
#else
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if CYTHON_COMPILING_IN_LIMITED_API
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    if (c_line) {
        (void) __pyx_cfilenm;
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    _PyTraceback_Add(funcname, filename, c_line ? -c_line : py_line);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* None */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void) {
  int err;
  #ifdef WITH_THREAD
  PyGILState_STATE _save = PyGILState_Ensure();
  #endif
  err = !!PyErr_Occurred();
  #ifdef WITH_THREAD
  PyGILState_Release(_save);
  #endif
  return err;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_volatile__int(volatile int value) {
    const volatile int neg_one = (volatile int) ((volatile int) 0 - (volatile int) 1), const_zero = (volatile int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(volatile int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(volatile int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(volatile int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(volatile int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(volatile int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(volatile int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if (CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if (CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XSETREF(name, __Pyx_NewRef(__pyx_n_s__113));
    }
    return name;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr
#define __PYX_HAVE_RT_ImportVoidPtr
static int __Pyx_ImportVoidPtr(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C variable %.200s",
                PyModule_GetName(module), name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}
#endif

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
